# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dataWorker.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dataWorker.proto',
  package='coinlib',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x64\x61taWorker.proto\x12\x07\x63oinlib\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x19google/protobuf/any.proto\"P\n\tWorkerJob\x12\x13\n\x0bworkerJobId\x18\x01 \x01(\t\x12\x15\n\rworkerJobType\x18\x02 \x01(\t\x12\x17\n\x0fworkerJobConfig\x18\x03 \x01(\x0c\"k\n\x0eWorkerJobError\x12\x13\n\x0bworkerJobId\x18\x01 \x01(\t\x12\x15\n\rworkerJobType\x18\x02 \x01(\t\x12\x17\n\x0fworkerJobConfig\x18\x03 \x01(\x0c\x12\x14\n\x0c\x65rrorMessage\x18\x04 \x01(\t\"E\n\x16WorkerAvailablePlugins\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xb7\x01\n\x06Worker\x12\x10\n\x08workerId\x18\x01 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x02 \x01(\t\x12\x13\n\x0bworker_mode\x18\x03 \x01(\t\x12\x39\n\x10\x61vailablePlugins\x18\x04 \x03(\x0b\x32\x1f.coinlib.WorkerAvailablePlugins\x12\n\n\x02os\x18\x05 \x01(\t\x12\x13\n\x0bworkspaceId\x18\x06 \x01(\t\x12\x15\n\ractiveModules\x18\x07 \x03(\t\"\x1a\n\x07RowData\x12\x0f\n\x07\x63olumns\x18\x01 \x03(\t\";\n\x15WorkerJobDataResponse\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\"\x16\n\x14WorkerJobDataPartial\"k\n\x1a\x43hartWorkerPartialDataInfo\x12\x11\n\tchartType\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x63olor\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\x02\x12\x0f\n\x07opacity\x18\x05 \x01(\x02\"\xad\x01\n\x1d\x43hartsWorkerPartialDataLayout\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x30\n\tindicator\x18\x02 \x01(\x0b\x32\x1d.coinlib.ChartWorkerIndicator\x12\x36\n\tchartInfo\x18\x03 \x01(\x0b\x32#.coinlib.ChartWorkerPartialDataInfo\"\xcc\x01\n\x14\x43hartWorkerIndicator\x12\x11\n\tchartType\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65\x61ture\x18\x03 \x01(\t\x12\x12\n\nsubfeature\x18\x04 \x01(\t\x12\r\n\x05short\x18\x05 \x01(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\n\n\x02id\x18\x07 \x01(\t\x12\x11\n\telementId\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x11\n\tid_output\x18\n \x01(\t\x12\x10\n\x08\x66inished\x18\x0b \x01(\x08\"\xdc\x02\n ChartWorkerIndicatorRegistration\x12\x11\n\tchartType\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\r\n\x05stage\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x11\n\tid_output\x18\x06 \x01(\t\x12\x0e\n\x06inputs\x18\x07 \x01(\x0c\x12\x0c\n\x04mode\x18\x08 \x01(\t\x12\x19\n\x11short_description\x18\t \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\x12\x0f\n\x07process\x18\x0b \x01(\t\x12\x16\n\x0eunstablePeriod\x18\x0c \x01(\x08\x12\x19\n\x11\x64ynamicTimeseries\x18\r \x01(\x08\x12\x0e\n\x06plugin\x18\x0e \x01(\t\x12\x15\n\rpluginVersion\x18\x0f \x01(\t\x12\x11\n\tcode_type\x18\x10 \x01(\t\x12\x0c\n\x04\x63ode\x18\x11 \x01(\t\"n\n!ChartWorkerIndicatorConfigElement\x12\x30\n\tindicator\x18\x01 \x01(\x0b\x32\x1d.coinlib.ChartWorkerIndicator\x12\x17\n\x0findicatorConfig\x18\x02 \x01(\x0c\"\xac\x01\n\x12\x43hartsWorkerConfig\x12<\n\x08\x65lements\x18\x01 \x03(\x0b\x32*.coinlib.ChartWorkerIndicatorConfigElement\x12-\n\x08\x63hildren\x18\x02 \x01(\x0b\x32\x1b.coinlib.ChartsWorkerConfig\x12)\n\tchartData\x18\x03 \x01(\x0b\x32\x16.coinlib.ChartDataInfo\"-\n\x0eStatisticInput\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"A\n\tDataError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x11\n\terrorCode\x18\x02 \x01(\x03\x12\x10\n\x08\x63ritical\x18\x03 \x01(\x08\"\x89\x01\n\x0eIndicatorError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x30\n\tindicator\x18\x03 \x01(\x0b\x32\x1d.coinlib.ChartWorkerIndicator\"\xa3\x01\n\x1aStatisticRuleFunctionError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12>\n\x11statisticFunction\x18\x03 \x01(\x0b\x32#.coinlib.StatisticsRuleWorkerConfig\"\xa5\x01\n\x1cStatisticMethodFunctionError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12>\n\x11statisticFunction\x18\x03 \x01(\x0b\x32#.coinlib.StatisticsRuleWorkerConfig\"\xb2\x01\n\"StatisticsMethodWorkerWindowConfig\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\x12\x10\n\x08windowId\x18\x03 \x01(\t\x12)\n\tchartData\x18\x04 \x01(\x0b\x32\x16.coinlib.ChartDataInfo\x12/\n\x0eparameterTable\x18\x05 \x01(\x0b\x32\x17.coinlib.ParameterTable\"R\n\x13ParameterTableEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x10\n\x08required\x18\x04 \x01(\x08\"B\n\x0eParameterTable\x12\x30\n\nparameters\x18\x01 \x03(\x0b\x32\x1c.coinlib.ParameterTableEntry\"b\n\rChartDataInfo\x12\x10\n\x08\x63hart_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63hart_prefix\x18\x02 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x63tivity_id\x18\x04 \x01(\t\"\xf6\x02\n\x1aStatisticsRuleWorkerConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x05rules\x18\x02 \x03(\x0b\x32#.coinlib.StatisticsRuleWorkerConfig\x12\x19\n\x11statisticFunction\x18\x03 \x01(\t\x12?\n\x06inputs\x18\x04 \x03(\x0b\x32/.coinlib.StatisticsRuleWorkerConfig.InputsEntry\x12\x12\n\ncombinator\x18\x05 \x01(\t\x12\x16\n\x0e\x63ombinator_not\x18\x06 \x01(\x08\x12\x0c\n\x04type\x18\x07 \x01(\t\x12)\n\tchartData\x18\x08 \x01(\x0b\x32\x16.coinlib.ChartDataInfo\x12\x0f\n\x07\x65nabled\x18\t \x01(\x08\x1a\x46\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.coinlib.StatisticInput:\x02\x38\x01\"\xa8\x01\n\x1eStatisticsRuleWorkerConfigType\x12\x33\n\x04rule\x18\x01 \x01(\x0b\x32#.coinlib.StatisticsRuleWorkerConfigH\x00\x12\x43\n\x0cmethodWindow\x18\x02 \x01(\x0b\x32+.coinlib.StatisticsMethodWorkerWindowConfigH\x00\x42\x0c\n\ntest_oneof\"\xb4\x01\n\x1cStatisticsBulkedWorkerConfig\x12\x38\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32\'.coinlib.StatisticsRuleWorkerConfigType\x12)\n\tchartData\x18\x02 \x01(\x0b\x32\x16.coinlib.ChartDataInfo\x12/\n\x0eparameterTable\x18\x03 \x01(\x0b\x32\x17.coinlib.ParameterTable\"\x9f\x01\n\x16StatisticFunctionError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12>\n\x11statisticFunction\x18\x03 \x01(\x0b\x32#.coinlib.StatisticsRuleWorkerConfig\"\xa7\x01\n\x1cStatisticMethodPartiallyData\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x12\n\ndocumentId\x18\x03 \x01(\t\x12\r\n\x05width\x18\x04 \x01(\t\x12\x0e\n\x06height\x18\x05 \x01(\t\x12\x0e\n\x06\x63olumn\x18\x06 \x01(\t\x12\x10\n\x08windowId\x18\x07 \x01(\t\"\xa6\x01\n\x1aStatisticRulePartiallyData\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12:\n\rstatisticRule\x18\x02 \x01(\x0b\x32#.coinlib.StatisticsRuleWorkerConfig\x12\x14\n\x0c\x63ollectionid\x18\x03 \x01(\t\x12\x12\n\nresultName\x18\x05 \x01(\t\"\xa2\x01\n\x1cStatisticBulkedPartiallyData\x12;\n\nmethodData\x18\x01 \x01(\x0b\x32%.coinlib.StatisticMethodPartiallyDataH\x00\x12\x37\n\x08ruleData\x18\x02 \x01(\x0b\x32#.coinlib.StatisticRulePartiallyDataH\x00\x42\x0c\n\ntest_oneof\"Z\n\x11SymbolBrokerError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\"\x95\x02\n\x16SymbolBrokerMarketData\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x0c\n\x04open\x18\x02 \x01(\x02\x12\r\n\x05\x63lose\x18\x03 \x01(\x02\x12\x0c\n\x04high\x18\x04 \x01(\x02\x12\x0b\n\x03low\x18\x05 \x01(\x02\x12\x0e\n\x06volume\x18\x06 \x01(\x02\x12\r\n\x05trade\x18\x07 \x01(\x02\x12\x10\n\x08\x64\x61tetime\x18\x08 \x01(\t\x12\x11\n\tsymbol_id\x18\t \x01(\t\x12\x0e\n\x06symbol\x18\n \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x0b \x01(\t\x12\x12\n\nevent_time\x18\x0c \x01(\t\x12\x0f\n\x07isFinal\x18\r \x01(\x08\x12\x11\n\tcloseTime\x18\x0e \x01(\t\"\x96\x01\n\x10SymbolBrokerInfo\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x30\n\texchanges\x18\x02 \x03(\x0b\x32\x1d.coinlib.SymbolBrokerExchange\x12,\n\x07symbols\x18\x03 \x03(\x0b\x32\x1b.coinlib.SymbolBrokerSymbol\";\n\x15SymbolBrokerOrderbook\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\"F\n SymbolBrokerHistoricalMarketData\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\"\xba\x01\n\x14SymbolBrokerExchange\x12\x0c\n\x04icon\x18\x01 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07website\x18\x04 \x01(\t\x12\x15\n\rsymbols_count\x18\x05 \x01(\x02\x12\x17\n\x0fvolume_1mth_usd\x18\x06 \x01(\x02\x12\x17\n\x0fvolume_1day_usd\x18\x07 \x01(\x02\x12\x17\n\x0fvolume_1hrs_usd\x18\x08 \x01(\x02\"\x8c\x04\n\x12SymbolBrokerSymbol\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x38\n\tassetType\x18\x04 \x01(\x0e\x32%.coinlib.SymbolBrokerSymbol.AssetType\x12>\n\x0c\x63ontractType\x18\x05 \x01(\x0e\x32(.coinlib.SymbolBrokerSymbol.ContractType\x12\x0c\n\x04\x62\x61se\x18\x06 \x01(\t\x12\r\n\x05quote\x18\x07 \x01(\t\x12\x1a\n\x12\x65xchange_symbol_id\x18\x08 \x01(\t\x12\x16\n\x0esize_precision\x18\t \x01(\x02\x12\x17\n\x0fprice_precision\x18\n \x01(\x02\x12\r\n\x05price\x18\x0b \x01(\x02\x12\x17\n\x0fvolume_1mth_usd\x18\x0c \x01(\x02\x12\x17\n\x0fvolume_1day_usd\x18\r \x01(\x02\x12\x17\n\x0fvolume_1hrs_usd\x18\x0e \x01(\x02\"+\n\tAssetType\x12\x08\n\x04\x43OIN\x10\x00\x12\t\n\x05\x46OREX\x10\x01\x12\t\n\x05STOCK\x10\x02\"S\n\x0c\x43ontractType\x12\x08\n\x04SPOT\x10\x00\x12\n\n\x06\x46UTURE\x10\x01\x12\n\n\x06MARGIN\x10\x02\x12\n\n\x06OPTION\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\n\n\x06\x43REDIT\x10\x05\"O\n\x1cSymbolBrokerBrokerInfoConfig\x12\x0f\n\x07options\x18\x01 \x01(\t\x12\x1e\n\x16symbolBrokerIdentifier\x18\x02 \x01(\t\"\xdd\x03\n#SymbolBrokerConsumeMarketdataConfig\x12\x0f\n\x07options\x18\x01 \x01(\t\x12\x1e\n\x16symbolBrokerIdentifier\x18\x02 \x01(\t\x12\x12\n\nquoteAsset\x18\x03 \x01(\t\x12\x11\n\tbaseAsset\x18\x04 \x01(\t\x12\x18\n\x10\x63lient_symbol_id\x18\x05 \x01(\t\x12\x11\n\ttimeframe\x18\x06 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x07 \x01(\t\x12O\n\x0c\x63ontractType\x18\x08 \x01(\x0e\x32\x39.coinlib.SymbolBrokerConsumeMarketdataConfig.ContractType\x12I\n\tassetType\x18\t \x01(\x0e\x32\x36.coinlib.SymbolBrokerConsumeMarketdataConfig.AssetType\"+\n\tAssetType\x12\x08\n\x04\x43OIN\x10\x00\x12\t\n\x05\x46OREX\x10\x01\x12\t\n\x05STOCK\x10\x02\"S\n\x0c\x43ontractType\x12\x08\n\x04SPOT\x10\x00\x12\n\n\x06\x46UTURE\x10\x01\x12\n\n\x06MARGIN\x10\x02\x12\n\n\x06OPTION\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\n\n\x06\x43REDIT\x10\x05\"\xda\x03\n\"SymbolBrokerConsumeOrderbookConfig\x12\x0f\n\x07options\x18\x01 \x01(\t\x12\x1e\n\x16symbolBrokerIdentifier\x18\x02 \x01(\t\x12\x12\n\nquoteAsset\x18\x03 \x01(\t\x12\x11\n\tbaseAsset\x18\x04 \x01(\t\x12\x18\n\x10\x63lient_symbol_id\x18\x05 \x01(\t\x12\x11\n\ttimeframe\x18\x06 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\x07 \x01(\t\x12N\n\x0c\x63ontractType\x18\x08 \x01(\x0e\x32\x38.coinlib.SymbolBrokerConsumeOrderbookConfig.ContractType\x12H\n\tassetType\x18\t \x01(\x0e\x32\x35.coinlib.SymbolBrokerConsumeOrderbookConfig.AssetType\"+\n\tAssetType\x12\x08\n\x04\x43OIN\x10\x00\x12\t\n\x05\x46OREX\x10\x01\x12\t\n\x05STOCK\x10\x02\"S\n\x0c\x43ontractType\x12\x08\n\x04SPOT\x10\x00\x12\n\n\x06\x46UTURE\x10\x01\x12\n\n\x06MARGIN\x10\x02\x12\n\n\x06OPTION\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\n\n\x06\x43REDIT\x10\x05\"\xa4\x04\n#SymbolBrokerGetHistoricalDataConfig\x12\x0f\n\x07options\x18\x01 \x01(\t\x12\x1e\n\x16symbolBrokerIdentifier\x18\x02 \x01(\t\x12\x12\n\nquoteAsset\x18\x03 \x01(\t\x12\x11\n\tbaseAsset\x18\x04 \x01(\t\x12\x18\n\x10\x63lient_symbol_id\x18\x05 \x01(\t\x12\x11\n\ttimeframe\x18\x06 \x01(\t\x12\r\n\x05start\x18\x07 \x01(\t\x12\x0b\n\x03\x65nd\x18\x08 \x01(\t\x12\x13\n\x0b\x65xchange_id\x18\t \x01(\t\x12)\n\tchartData\x18\n \x01(\x0b\x32\x16.coinlib.ChartDataInfo\x12O\n\x0c\x63ontractType\x18\x0b \x01(\x0e\x32\x39.coinlib.SymbolBrokerGetHistoricalDataConfig.ContractType\x12I\n\tassetType\x18\x0c \x01(\x0e\x32\x36.coinlib.SymbolBrokerGetHistoricalDataConfig.AssetType\"+\n\tAssetType\x12\x08\n\x04\x43OIN\x10\x00\x12\t\n\x05\x46OREX\x10\x01\x12\t\n\x05STOCK\x10\x02\"S\n\x0c\x43ontractType\x12\x08\n\x04SPOT\x10\x00\x12\n\n\x06\x46UTURE\x10\x01\x12\n\n\x06MARGIN\x10\x02\x12\n\n\x06OPTION\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\n\n\x06\x43REDIT\x10\x05\"\xc5\x02\n\x18SymbolBrokerWorkerConfig\x12;\n\ninfoConfig\x18\x01 \x01(\x0b\x32%.coinlib.SymbolBrokerBrokerInfoConfigH\x00\x12\x45\n\rconsumeConfig\x18\x02 \x01(\x0b\x32,.coinlib.SymbolBrokerConsumeMarketdataConfigH\x00\x12M\n\x16\x63onsumeOrderbookConfig\x18\x03 \x01(\x0b\x32+.coinlib.SymbolBrokerConsumeOrderbookConfigH\x00\x12H\n\x10historicalConfig\x18\x04 \x01(\x0b\x32,.coinlib.SymbolBrokerGetHistoricalDataConfigH\x00\x42\x0c\n\ntest_oneof\"F\n SymbolBrokerStopConsumerListener\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\"2\n\x1fSymbolBrokerStopConsumerCommand\x12\x0f\n\x07stopped\x18\x01 \x01(\x08\"u\n$NotificationExtractMessageDataConfig\x12\x0e\n\x06inputs\x18\x01 \x01(\t\x12\x1e\n\x16notificationIdentifier\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\x12\x0f\n\x07options\x18\x04 \x01(\t\"\xd3\x01\n!NotificationSendMessageDataConfig\x12\x0e\n\x06inputs\x18\x01 \x01(\t\x12\x1e\n\x16notificationIdentifier\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06images\x18\x04 \x01(\t\x12\x0f\n\x07\x62uttons\x18\x05 \x01(\t\x12\x0f\n\x07options\x18\x06 \x01(\t\x12\x13\n\x0b\x63\x61llback_id\x18\x07 \x01(\t\x12\x14\n\x0c\x63\x61llback_url\x18\x08 \x01(\t\x12\x10\n\x08\x63hannels\x18\t \x01(\t\"\xbd\x01\n\x18NotificationWorkerConfig\x12G\n\x11sendMessageConfig\x18\x01 \x01(\x0b\x32*.coinlib.NotificationSendMessageDataConfigH\x00\x12J\n\x11\x65xtractDataConfig\x18\x02 \x01(\x0b\x32-.coinlib.NotificationExtractMessageDataConfigH\x00\x42\x0c\n\ntest_oneof\"Z\n\x11NotificationError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\"b\n\x1bNotificationCallbackExtract\x12\x11\n\tbutton_id\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12\"\n\x06worker\x18\x03 \x01(\x0b\x32\x12.coinlib.WorkerJob\"\x82\x01\n\x0eLogicComponent\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x12\n\nidentifier\x18\x02 \x01(\t\x12\x18\n\x10logicComponentId\x18\x03 \x01(\t\x12\x13\n\x0b\x65nvironment\x18\x04 \x01(\t\x12\x0e\n\x06params\x18\x05 \x01(\x0c\x12\x0c\n\x04type\x18\x06 \x01(\t\"\xde\x03\n\x12\x42rokerAccountModel\x12:\n\nbrokerType\x18\x01 \x01(\x0e\x32&.coinlib.BrokerAccountModel.BrokerType\x12\x34\n\x04mode\x18\x02 \x01(\x0e\x32&.coinlib.BrokerAccountModel.BrokerMode\x12\x10\n\x08\x65xchange\x18\x03 \x01(\t\x12\x10\n\x08makerFee\x18\x04 \x01(\x02\x12\x10\n\x08takerFee\x18\x05 \x01(\x02\x12\x39\n\x0cmakerFeeMode\x18\x06 \x01(\x0e\x32#.coinlib.BrokerAccountModel.FeeMode\x12\x39\n\x0ctakerFeeMode\x18\x07 \x01(\x0e\x32#.coinlib.BrokerAccountModel.FeeMode\"Q\n\nBrokerType\x12\x08\n\x04SPOT\x10\x00\x12\n\n\x06\x46UTURE\x10\x01\x12\n\n\x06MARGIN\x10\x02\x12\n\n\x06OPTION\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\n\n\x06\x43REDIT\x10\x05\"1\n\nBrokerMode\x12\x0e\n\nBACKTRADER\x10\x00\x12\t\n\x05PAPER\x10\x01\x12\x08\n\x04LIVE\x10\x02\"$\n\x07\x46\x65\x65Mode\x12\x0e\n\nPERCENTAGE\x10\x00\x12\t\n\x05\x46IXED\x10\x01\"~\n\x0ePortfolioAsset\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x12\x0c\n\x04\x66ree\x18\x03 \x01(\x02\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12\x0e\n\x06locked\x18\x05 \x01(\x02\x12\x11\n\tlastPrice\x18\x06 \x01(\x02\x12\x0c\n\x04\x64\x61te\x18\x07 \x01(\t\"o\n\x13\x43\x61lculatedBaseMoney\x12\r\n\x05total\x18\x01 \x01(\x02\x12\x0c\n\x04\x66ree\x18\x02 \x01(\x02\x12\x0e\n\x06locked\x18\x03 \x01(\x02\x12\x0f\n\x07summary\x18\x04 \x01(\x02\x12\x0c\n\x04\x64\x61te\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"\xc0\x01\n\x0ePortfolioModel\x12\'\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x17.coinlib.PortfolioAsset\x12@\n\x1a\x63urrentCalculatedBaseMoney\x18\x02 \x01(\x0b\x32\x1c.coinlib.CalculatedBaseMoney\x12\x43\n\x1dhistoricalCalculatedBaseMoney\x18\x03 \x03(\x0b\x32\x1c.coinlib.CalculatedBaseMoney\"\xa4\x02\n\x10LogicRunnerLogic\x12)\n\tchartData\x18\x01 \x01(\x0b\x32\x16.coinlib.ChartDataInfo\x12\x30\n\x0flogicComponents\x18\x02 \x03(\x0b\x32\x17.coinlib.LogicComponent\x12\x11\n\tstartDate\x18\x03 \x01(\t\x12\x0f\n\x07\x65ndDate\x18\x04 \x01(\t\x12*\n\tportfolio\x18\x05 \x01(\x0b\x32\x17.coinlib.PortfolioModel\x12\x32\n\rbrokerAccount\x18\x06 \x01(\x0b\x32\x1b.coinlib.BrokerAccountModel\x12/\n\x0eparameterTable\x18\x07 \x01(\x0b\x32\x17.coinlib.ParameterTable\"\xc0\x01\n\x1eLogicRunnerOfflineWorkerConfig\x12,\n\tlogicInfo\x18\x01 \x01(\x0b\x32\x19.coinlib.LogicRunnerLogic\x12)\n\tchartData\x18\x02 \x01(\x0b\x32\x16.coinlib.ChartDataInfo\x12+\n\tportfolio\x18\x03 \x01(\x0b\x32\x18.coinlib.BrokerPortfolio\x12\x18\n\x10\x61\x64vancedDataInfo\x18\x04 \x01(\t\"\xce\x03\n\x15LogicRunnerStatistics\x12\x1f\n\x17highestProfitPercentage\x18\x01 \x01(\x02\x12\x1d\n\x15highestLossPercentage\x18\x02 \x01(\x02\x12\x11\n\tsinceDate\x18\x03 \x01(\t\x12\x0e\n\x06\x61tDate\x18\x04 \x01(\t\x12\x11\n\ttradesCnt\x18\x05 \x01(\x02\x12\x35\n\x0f\x63\x61lculatedMoney\x18\x06 \x01(\x0b\x32\x1c.coinlib.CalculatedBaseMoney\x12\"\n\x1aunrealizedProfitPercentage\x18\x07 \x01(\x02\x12\x0c\n\x04\x66\x65\x65s\x18\x08 \x01(\x02\x12 \n\x18profitCompletePercentage\x18\t \x01(\x02\x12\x1d\n\x15highestProfitPerGroup\x18\n \x01(\x02\x12\x1b\n\x13highestLossPerGroup\x18\x0b \x01(\x02\x12\x18\n\x10slippagePerGroup\x18\x0c \x01(\x02\x12\x1a\n\x12\x61verageAmountQuote\x18\r \x01(\x02\x12\'\n\x1f\x61verageProfitPercentagePergroup\x18\x0e \x01(\x02\x12\x19\n\x11portfolioTimeline\x18\x0f \x01(\t\"\xa6\x01\n%LogicRunnerOfflineWorkerPartiallyData\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x12\n\npercentage\x18\x02 \x01(\x02\x12\x12\n\nsignalData\x18\x03 \x01(\t\x12\x31\n\tstatistic\x18\x05 \x01(\x0b\x32\x1e.coinlib.LogicRunnerStatistics\"w\n\x1dLogicRunnerOfflineWorkerError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x0f\n\x07message\x18\x03 \x01(\t\"\xb4\x01\n$LogicRunnerOfflineWorkerFinishedData\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x12\n\nsignalData\x18\x03 \x01(\t\x12\x31\n\tstatistic\x18\x04 \x01(\x0b\x32\x1e.coinlib.LogicRunnerStatistics\"@\n\x17WorkerPluginInformation\x12%\n\x06plugin\x18\x01 \x03(\x0b\x32\x15.coinlib.PluginConfig\"<\n\x0eWorkerSettings\x12\x15\n\ractiveModules\x18\x01 \x03(\t\x12\x13\n\x0bworker_mode\x18\x02 \x01(\t\"\'\n\x12WorkerRegistration\x12\x11\n\tworker_id\x18\x01 \x01(\t\"t\n\x0cPluginConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0b\x66ilecontent\x18\x04 \x01(\t\x12\x10\n\x08testOnly\x18\x05 \x01(\x08\x12\x10\n\x08\x66iletype\x18\x06 \x01(\t\"U\n\x18PluginInstallationOutput\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x15\n\routputMessage\x18\x02 \x01(\t\"\xcb\x01\n\x1dSimulatorChartConfigIndicator\x12\x0f\n\x07\x66\x65\x61ture\x18\x01 \x01(\t\x12\x12\n\nsubfeature\x18\x02 \x01(\t\x12\x42\n\x06inputs\x18\x03 \x03(\x0b\x32\x32.coinlib.SimulatorChartConfigIndicator.InputsEntry\x12\x12\n\nchartIndex\x18\x04 \x01(\t\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaa\x01\n\x14SimulatorChartConfig\x12\x11\n\tkernel_id\x18\x01 \x01(\t\x12\x0e\n\x06\x62roker\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x11\n\ttimeframe\x18\x04 \x01(\t\x12:\n\nindicators\x18\x05 \x03(\x0b\x32&.coinlib.SimulatorChartConfigIndicator\x12\x10\n\x08workerId\x18\x06 \x01(\t\"\x97\x01\n\x1dSimulatorStatisticChartConfig\x12\x11\n\tkernel_id\x18\x01 \x01(\t\x12\x15\n\rsimulatorName\x18\x02 \x01(\t\x12:\n\nindicators\x18\x05 \x03(\x0b\x32&.coinlib.SimulatorChartConfigIndicator\x12\x10\n\x08workerId\x18\x06 \x01(\t\"\xc7\x01\n\x1eSimulatorMethodCallChartConfig\x12\x11\n\tkernel_id\x18\x01 \x01(\t\x12\x15\n\rsimulatorName\x18\x02 \x01(\t\x12:\n\nindicators\x18\x05 \x03(\x0b\x32&.coinlib.SimulatorChartConfigIndicator\x12\x10\n\x08workerId\x18\x06 \x01(\t\x12-\n\x07methods\x18\x07 \x03(\x0b\x32\x1c.coinlib.SimulatorMethodCall\"(\n\x11SimulatorResponse\x12\x13\n\x0bworkspaceId\x18\x01 \x01(\t\"\x83\x01\n\x1cSymbolBrokerSimulatorRequest\x12\x16\n\x0esymbolBrokerId\x18\x01 \x01(\t\x12\x0f\n\x07options\x18\x02 \x01(\t\x12\x10\n\x08workerId\x18\x03 \x01(\t\x12\x13\n\x0btestSymbol1\x18\x04 \x01(\t\x12\x13\n\x0btestSymbol2\x18\x05 \x01(\t\"g\n\x1dSymbolBrokerSimulatorResponse\x12\x16\n\x0esymbolBrokerId\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x1d\n\x15simulatorResponseText\x18\x03 \x01(\t\"@\n\x1e\x42rokerSimulatorBrokerLoginData\x12\x0e\n\x06\x61pikey\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x95\x01\n\x19\x42rokerSimulatorBrokerData\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12:\n\tloginInfo\x18\x02 \x01(\x0b\x32\'.coinlib.BrokerSimulatorBrokerLoginData\x12\x11\n\tassetType\x18\x03 \x01(\t\x12\x14\n\x0c\x63ontractType\x18\x04 \x01(\t\"\x98\x01\n\x16\x42rokerSimulatorRequest\x12\x10\n\x08\x62rokerId\x18\x01 \x01(\t\x12\x0f\n\x07options\x18\x02 \x01(\t\x12\x10\n\x08workerId\x18\x03 \x01(\t\x12\x36\n\nbrokerInfo\x18\x04 \x01(\x0b\x32\".coinlib.BrokerSimulatorBrokerData\x12\x11\n\tpaperMode\x18\x05 \x01(\x08\"\x9a\x01\n\x17\x42rokerSimulatorResponse\x12\x10\n\x08\x62rokerId\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x1d\n\x15simulatorResponseText\x18\x03 \x01(\t\x12\x11\n\tsessionId\x18\x04 \x01(\t\x12\x13\n\x0bworkspaceId\x18\x05 \x01(\t\x12\x15\n\rtargetdepotId\x18\x06 \x01(\t\"f\n\x1cNotificationSimulatorRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0e\n\x06inputs\x18\x02 \x01(\t\x12\x10\n\x08workerId\x18\x03 \x01(\t\x12\x10\n\x08\x63hannels\x18\x04 \x01(\t\"c\n\x1dNotificationSimulatorResponse\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x1d\n\x15simulatorResponseText\x18\x03 \x01(\t\"P\n\x17\x46\x65\x61tureSimulatorRequest\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0f\n\x07options\x18\x02 \x01(\t\x12\x10\n\x08workerId\x18\x03 \x01(\t\"^\n\x18\x46\x65\x61tureSimulatorResponse\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x1d\n\x15simulatorResponseText\x18\x03 \x01(\t\"c\n\nLogicInput\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ultValue\x18\x04 \x01(\t\x12\x0e\n\x06values\x18\x05 \x01(\t\"\x85\x02\n\x17LogicTraderRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12#\n\x06inputs\x18\x04 \x03(\x0b\x32\x13.coinlib.LogicInput\x12\x0f\n\x07modules\x18\x05 \x03(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x0e\n\x06plugin\x18\x07 \x01(\t\x12\x15\n\rpluginVersion\x18\x08 \x01(\t\x12\x13\n\x0bworkspaceId\x18\t \x01(\t\x12\x11\n\tcode_type\x18\n \x01(\t\x12\x0c\n\x04\x63ode\x18\x0b \x01(\t\x12\x10\n\x08workerId\x18\x0c \x01(\t\"\x84\x02\n\x16LogicAlertRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12#\n\x06inputs\x18\x04 \x03(\x0b\x32\x13.coinlib.LogicInput\x12\x0f\n\x07modules\x18\x05 \x03(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x0e\n\x06plugin\x18\x07 \x01(\t\x12\x15\n\rpluginVersion\x18\x08 \x01(\t\x12\x13\n\x0bworkspaceId\x18\t \x01(\t\x12\x11\n\tcode_type\x18\n \x01(\t\x12\x0c\n\x04\x63ode\x18\x0b \x01(\t\x12\x10\n\x08workerId\x18\x0c \x01(\t\"\x86\x02\n\x18LogicAdvisorRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12#\n\x06inputs\x18\x04 \x03(\x0b\x32\x13.coinlib.LogicInput\x12\x0f\n\x07modules\x18\x05 \x03(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x0e\n\x06plugin\x18\x07 \x01(\t\x12\x15\n\rpluginVersion\x18\x08 \x01(\t\x12\x13\n\x0bworkspaceId\x18\t \x01(\t\x12\x11\n\tcode_type\x18\n \x01(\t\x12\x0c\n\x04\x63ode\x18\x0b \x01(\t\x12\x10\n\x08workerId\x18\x0c \x01(\t\"\x87\x02\n\x19LogicScreenerRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12#\n\x06inputs\x18\x04 \x03(\x0b\x32\x13.coinlib.LogicInput\x12\x0f\n\x07modules\x18\x05 \x03(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x0e\n\x06plugin\x18\x07 \x01(\t\x12\x15\n\rpluginVersion\x18\x08 \x01(\t\x12\x13\n\x0bworkspaceId\x18\t \x01(\t\x12\x11\n\tcode_type\x18\n \x01(\t\x12\x0c\n\x04\x63ode\x18\x0b \x01(\t\x12\x10\n\x08workerId\x18\x0c \x01(\t\"\xe6\x01\n\x1aWorkspaceLogicRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x18\n\x10logicComponentId\x18\x02 \x01(\t\x12\x0e\n\x06params\x18\x03 \x01(\x0c\x12\r\n\x05stage\x18\x04 \x01(\t\x12\x0e\n\x06plugin\x18\x05 \x01(\t\x12\x15\n\rpluginVersion\x18\x06 \x01(\t\x12\x13\n\x0bworkspaceId\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x12\x11\n\tcode_type\x18\t \x01(\t\x12\x0c\n\x04\x63ode\x18\n \x01(\t\x12\x10\n\x08workerId\x18\x0b \x01(\t\"\\\n\x13SymbolBrokerOptions\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ultValue\x18\x04 \x01(\t\"\xe4\x01\n\x18SymbolBrokerRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07iconUrl\x18\x03 \x01(\t\x12-\n\x07options\x18\x04 \x03(\x0b\x32\x1c.coinlib.SymbolBrokerOptions\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x0e\n\x06plugin\x18\x07 \x01(\t\x12\x15\n\rpluginVersion\x18\x08 \x01(\t\x12\x11\n\tcode_type\x18\t \x01(\t\x12\x0c\n\x04\x63ode\x18\n \x01(\t\"V\n\rBrokerOptions\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ultValue\x18\x04 \x01(\t\"\xda\x03\n\x0e\x42rokerExchange\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04icon\x18\x03 \x01(\t\x12\x34\n\tloginMode\x18\x04 \x01(\x0e\x32!.coinlib.BrokerExchange.LoginMode\x12;\n\rcontractTypes\x18\x05 \x03(\x0e\x32$.coinlib.BrokerExchange.ContractType\x12\x35\n\nassetTypes\x18\x06 \x03(\x0e\x32!.coinlib.BrokerExchange.AssetType\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x13\n\x0bsupportDemo\x18\x08 \x01(\x08\x12\x13\n\x0bsupportLive\x18\t \x01(\x08\x12\x1a\n\x12positionModeFuture\x18\n \x01(\t\"\x18\n\tLoginMode\x12\x0b\n\x07\x41PI_KEY\x10\x00\"S\n\x0c\x43ontractType\x12\x08\n\x04SPOT\x10\x00\x12\n\n\x06\x46UTURE\x10\x01\x12\n\n\x06MARGIN\x10\x02\x12\n\n\x06OPTION\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\n\n\x06\x43REDIT\x10\x05\"+\n\tAssetType\x12\x08\n\x04\x43OIN\x10\x00\x12\t\n\x05\x46OREX\x10\x01\x12\t\n\x05STOCK\x10\x02\"\xa8\x03\n\x12\x42rokerRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07iconUrl\x18\x03 \x01(\t\x12\'\n\x07options\x18\x04 \x03(\x0b\x32\x16.coinlib.BrokerOptions\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x0e\n\x06plugin\x18\x07 \x01(\t\x12\x15\n\rpluginVersion\x18\x08 \x01(\t\x12\x11\n\tcode_type\x18\t \x01(\t\x12\x0c\n\x04\x63ode\x18\n \x01(\t\x12*\n\texchanges\x18\x0b \x03(\x0b\x32\x17.coinlib.BrokerExchange\x12\x45\n\x0b\x62rokerTypes\x18\x0c \x03(\x0e\x32\x30.coinlib.BrokerRegistration.SupportedBrokerTypes\"[\n\x14SupportedBrokerTypes\x12\x08\n\x04SPOT\x10\x00\x12\n\n\x06\x46UTURE\x10\x01\x12\n\n\x06MARGIN\x10\x02\x12\n\n\x06OPTION\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\n\n\x06\x43REDIT\x10\x05\"?\n\x0f\x42rokerPortfolio\x12,\n\x05\x61sset\x18\x01 \x03(\x0b\x32\x1d.coinlib.BrokerPortfolioAsset\"Z\n\x14\x42rokerPortfolioAsset\x12\x0c\n\x04\x62\x61se\x18\x01 \x01(\t\x12\x11\n\tavailable\x18\x02 \x01(\x02\x12\x0e\n\x06locked\x18\x03 \x01(\x02\x12\x11\n\tlastPrice\x18\x04 \x01(\x02\"\x84\x03\n\x18\x42rokerSessionAccountInfo\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x44\n\x0c\x63ontractType\x18\x02 \x01(\x0e\x32..coinlib.BrokerSessionAccountInfo.ContractType\x12>\n\tassetType\x18\x03 \x01(\x0e\x32+.coinlib.BrokerSessionAccountInfo.AssetType\x12:\n\tloginInfo\x18\x04 \x01(\x0b\x32\'.coinlib.BrokerSimulatorBrokerLoginData\x12\x0f\n\x07sandbox\x18\x05 \x01(\x08\"S\n\x0c\x43ontractType\x12\x08\n\x04SPOT\x10\x00\x12\n\n\x06\x46UTURE\x10\x01\x12\n\n\x06MARGIN\x10\x02\x12\n\n\x06OPTION\x10\x03\x12\t\n\x05INDEX\x10\x04\x12\n\n\x06\x43REDIT\x10\x05\"+\n\tAssetType\x12\x08\n\x04\x43OIN\x10\x00\x12\t\n\x05\x46OREX\x10\x01\x12\t\n\x05STOCK\x10\x02\"\x9b\x01\n\x1c\x42rokerInfoStartSessionConfig\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\x18\n\x10\x62rokerIdentifier\x18\x02 \x01(\t\x12\x36\n\x0b\x61\x63\x63ountInfo\x18\x03 \x01(\x0b\x32!.coinlib.BrokerSessionAccountInfo\x12\x16\n\x0eshortSessionId\x18\x04 \x01(\t\"\xf4\x01\n\x14\x42rokerInfoTestConfig\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\x18\n\x10\x62rokerIdentifier\x18\x02 \x01(\t\x12\x36\n\x0b\x61\x63\x63ountInfo\x18\x03 \x01(\x0b\x32!.coinlib.BrokerSessionAccountInfo\x12\x16\n\x0eshortSessionId\x18\x04 \x01(\t\x12+\n\tportfolio\x18\x05 \x01(\x0b\x32\x18.coinlib.BrokerPortfolio\x12\x32\n\rbrokerAccount\x18\x06 \x01(\x0b\x32\x1b.coinlib.BrokerAccountModel\"g\n\x12\x42rokerWorkerConfig\x12\x43\n\x12startSessionConfig\x18\x01 \x01(\x0b\x32%.coinlib.BrokerInfoStartSessionConfigH\x00\x42\x0c\n\ntest_oneof\"@\n\x1a\x42rokerStopConsumerListener\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\",\n\x19\x42rokerStopConsumerCommand\x12\x0f\n\x07stopped\x18\x01 \x01(\x08\"\x18\n\x16\x42rokerStartSessionInfo\"T\n\x0b\x42rokerError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\"j\n\x0e\x42rokerCommands\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\x11\n\tcommandId\x18\x02 \x01(\t\x12\x15\n\rbrokerCommand\x18\x03 \x01(\t\x12\x1b\n\x13\x62rokerCommandParams\x18\x04 \x01(\t\".\n\x19\x42rokerSessionRegistration\x12\x11\n\tsessionId\x18\x01 \x01(\t\"P\n\x14\x42rokerCommandsAnswer\x12\x11\n\tcommandId\x18\x01 \x01(\t\x12\x12\n\nanswerData\x18\x02 \x01(\t\x12\x11\n\tsessionId\x18\x03 \x01(\t\"d\n\x19\x42rokerCommandsAnswerError\x12\x11\n\tcommandId\x18\x01 \x01(\t\x12\x12\n\nanswerData\x18\x02 \x01(\t\x12\x11\n\tsessionId\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"e\n\x0f\x42rokerEventData\x12\r\n\x05\x65vent\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12\x11\n\tsessionId\x18\x03 \x01(\t\x12\"\n\x06worker\x18\x04 \x01(\x0b\x32\x12.coinlib.WorkerJob\".\n\x19\x42rokerCommandRegistration\x12\x11\n\tsessionId\x18\x01 \x01(\t\"J\n\x16\x42rokerTestProtocolData\x12\"\n\x06worker\x18\x01 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\x9c\x01\n\x0f\x41ppWorkerConfig\x12\x46\n\x12startSessionConfig\x18\x01 \x01(\x0b\x32(.coinlib.AppWorkerInfoStartSessionConfigH\x00\x12\x33\n\ntestConfig\x18\x02 \x01(\x0b\x32\x1d.coinlib.BrokerInfoTestConfigH\x00\x42\x0c\n\ntest_oneof\"\xa9\x02\n\x1f\x41ppWorkerInfoStartSessionConfig\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\x16\n\x0eshortSessionId\x18\x02 \x01(\t\x12,\n\tlogicInfo\x18\x03 \x01(\x0b\x32\x19.coinlib.LogicRunnerLogic\x12;\n\x0c\x62rokerConfig\x18\x04 \x01(\x0b\x32%.coinlib.BrokerInfoStartSessionConfig\x12+\n\tportfolio\x18\x05 \x01(\x0b\x32\x18.coinlib.BrokerPortfolio\x12\x0c\n\x04\x63ode\x18\x06 \x01(\t\x12\x10\n\x08\x63odeType\x18\x07 \x01(\t\x12\x0e\n\x06\x63odeId\x18\x08 \x01(\t\x12\x13\n\x0b\x63odeVersion\x18\t \x01(\t\"1\n\x1c\x41ppWorkerCommandRegistration\x12\x11\n\tsessionId\x18\x01 \x01(\t\"W\n\x0e\x41ppWorkerError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\"q\n\x11\x41ppWorkerCommands\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\x11\n\tcommandId\x18\x02 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\t\x12\x15\n\rcommandParams\x18\x04 \x01(\t\x12\x0e\n\x06target\x18\x05 \x01(\t\"U\n\x1c\x41ppWorkerSessionRegistration\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\"S\n\x17\x41ppWorkerCommandsAnswer\x12\x11\n\tcommandId\x18\x01 \x01(\t\x12\x12\n\nanswerData\x18\x02 \x01(\t\x12\x11\n\tsessionId\x18\x03 \x01(\t\"g\n\x1c\x41ppWorkerCommandsAnswerError\x12\x11\n\tcommandId\x18\x01 \x01(\t\x12\x12\n\nanswerData\x18\x02 \x01(\t\x12\x11\n\tsessionId\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"h\n\x12\x41ppWorkerEventData\x12\r\n\x05\x65vent\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12\x11\n\tsessionId\x18\x03 \x01(\t\x12\"\n\x06worker\x18\x04 \x01(\x0b\x32\x12.coinlib.WorkerJob\"\x83\x01\n\x16\x41ppWorkerBrokerCommand\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\t\x12\x0e\n\x06params\x18\x04 \x01(\t\x12\x11\n\tcommandId\x18\x05 \x01(\t\"\x9f\x01\n\x1c\x41ppWorkerBrokerCommandAnswer\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x11\n\tcommandId\x18\x03 \x01(\t\x12\x10\n\x08response\x18\x04 \x01(\t\x12\x14\n\x0c\x65rrorMessage\x18\x05 \x01(\t\x12\r\n\x05\x65rror\x18\x06 \x01(\x08\"\x93\x01\n\x16\x41ppWorkerModuleCommand\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x0e\n\x06module\x18\x03 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x0e\n\x06params\x18\x05 \x01(\t\x12\x11\n\tcommandId\x18\x06 \x01(\t\"\xd0\x01\n\x1c\x41ppWorkerModuleCommandAnswer\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x0e\n\x06module\x18\x03 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x0e\n\x06params\x18\x05 \x01(\t\x12\x11\n\tcommandId\x18\x06 \x01(\t\x12\x14\n\x0c\x65rrorMessage\x18\x07 \x01(\t\x12\r\n\x05\x65rror\x18\x08 \x01(\x08\x12\x10\n\x08response\x18\t \x01(\t\"g\n\x1a\x41ppWorkerFinishedStepInfos\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\x12\x12\n\nsignalData\x18\x03 \x01(\t\"\xad\x02\n\x1d\x46\x65\x61tureInfoStartSessionConfig\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\x12\n\nidentifier\x18\x02 \x01(\t\x12\x14\n\x0coptionValues\x18\x03 \x01(\t\x12\x16\n\x0eshortSessionId\x18\x04 \x01(\t\x12\x1c\n\x14targetDatabaseServer\x18\x05 \x01(\t\x12\x18\n\x10targetDatabaseID\x18\x06 \x01(\t\x12\x13\n\x0bsessionData\x18\x07 \x01(\t\x12\x14\n\x0crabbitServer\x18\x08 \x01(\t\x12\x12\n\nrabbitUser\x18\t \x01(\t\x12\x11\n\trabbitPwd\x18\n \x01(\t\x12\x12\n\nrabbitPort\x18\x0b \x01(\t\x12\x19\n\x11rabbitQueuePrefix\x18\x0c \x01(\t\"i\n\x13\x46\x65\x61tureWorkerConfig\x12\x44\n\x12startSessionConfig\x18\x01 \x01(\x0b\x32&.coinlib.FeatureInfoStartSessionConfigH\x00\x42\x0c\n\ntest_oneof\"U\n\x0c\x46\x65\x61tureError\x12!\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x12.coinlib.DataError\x12\"\n\x06worker\x18\x02 \x01(\x0b\x32\x12.coinlib.WorkerJob\"_\n\x0f\x46\x65\x61tureCommands\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12\x11\n\tcommandId\x18\x02 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\t\x12\x15\n\rcommandParams\x18\x04 \x01(\t\"Q\n\x15\x46\x65\x61tureCommandsAnswer\x12\x11\n\tcommandId\x18\x01 \x01(\t\x12\x12\n\nanswerData\x18\x02 \x01(\t\x12\x11\n\tsessionId\x18\x03 \x01(\t\"e\n\x1a\x46\x65\x61tureCommandsAnswerError\x12\x11\n\tcommandId\x18\x01 \x01(\t\x12\x12\n\nanswerData\x18\x02 \x01(\t\x12\x11\n\tsessionId\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"/\n\x1a\x46\x65\x61tureSessionRegistration\x12\x11\n\tsessionId\x18\x01 \x01(\t\"f\n\x10\x46\x65\x61tureEventData\x12\r\n\x05\x65vent\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\x12\x11\n\tsessionId\x18\x03 \x01(\t\x12\"\n\x06worker\x18\x04 \x01(\x0b\x32\x12.coinlib.WorkerJob\">\n\x17RegistrationInformation\x12\x12\n\nduplicated\x18\x01 \x01(\x08\x12\x0f\n\x07success\x18\x02 \x01(\x08\"I\n\x15SymbolDataRequestInfo\x12\x10\n\x08\x65xchange\x18\x01 \x01(\t\x12\x1e\n\x16\x61\x64\x64itionalDataFeatures\x18\x02 \x01(\t\"G\n\x12SymbolDataResponse\x12\x31\n\x07symbols\x18\x01 \x03(\x0b\x32 .coinlib.SymbolBrokerSymbolSmall\"\x19\n\x17\x45xchangeDataRequestInfo\"L\n\x13\x42rokerExchangeSmall\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04mode\x18\x04 \x01(\t\"G\n\x14\x45xchangeDataResponse\x12/\n\texchanges\x18\x02 \x03(\x0b\x32\x1c.coinlib.BrokerExchangeSmall\"\xbe\x01\n\x17SymbolBrokerSymbolSmall\x12\x13\n\x0b\x65xchange_id\x18\x01 \x01(\t\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x11\n\tsymbol_id\x18\x03 \x01(\t\x12\x12\n\naccount_id\x18\x04 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x05 \x01(\t\x12\r\n\x05quote\x18\x06 \x01(\t\x12\x16\n\x0epricePrecision\x18\x07 \x01(\t\x12\x14\n\x0c\x63ontractType\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\"\xb2\x01\n\x11MarketDataRequest\x12\x30\n\x06symbol\x18\x01 \x01(\x0b\x32 .coinlib.SymbolBrokerSymbolSmall\x12\x11\n\tstartDate\x18\x02 \x01(\t\x12\x0f\n\x07\x65ndDate\x18\x03 \x01(\t\x12\x11\n\ttimeframe\x18\x04 \x01(\t\x12\x14\n\x0c\x63ontractType\x18\x05 \x01(\t\x12\x1e\n\x16\x61\x64\x64itionalDataFeatures\x18\x06 \x01(\t\"P\n\x12MarketDataResponse\x12\x13\n\x0b\x64\x61ta_server\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x02 \x01(\t\x12\x10\n\x08\x63hart_id\x18\x03 \x01(\t\"+\n\x13\x46\x65\x61tureDataResponse\x12\x14\n\x0c\x66\x65\x61ture_data\x18\x01 \x01(\t\"[\n\x12\x46\x65\x61tureDataRequest\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x01 \x01(\t\x12\x0c\n\x04\x66rom\x18\x02 \x01(\t\x12\n\n\x02to\x18\x03 \x01(\t\x12\x15\n\rtarget_symbol\x18\x04 \x01(\t\"\x1e\n\x1c\x41\x64\x64itionalDataFeatureRequest\"y\n\x19\x41\x64\x64itionalDataFeatureInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x10\n\x08\x65xchange\x18\x04 \x01(\t\x12\r\n\x05group\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\"Y\n\x1d\x41\x64\x64itionalDataFeatureResponse\x12\x38\n\x0c\x66\x65\x61tureInfos\x18\x01 \x03(\x0b\x32\".coinlib.AdditionalDataFeatureInfo\"\\\n\x13NotificationOptions\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ultValue\x18\x04 \x01(\t\"\x8f\x02\n\x18NotificationRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07iconUrl\x18\x03 \x01(\t\x12,\n\x06inputs\x18\x04 \x03(\x0b\x32\x1c.coinlib.NotificationOptions\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x0e\n\x06plugin\x18\x07 \x01(\t\x12\x15\n\rpluginVersion\x18\x08 \x01(\t\x12\x11\n\tcode_type\x18\t \x01(\t\x12\x0c\n\x04\x63ode\x18\n \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\t\x12\x15\n\risInteractive\x18\x0c \x01(\x08\"W\n\x0e\x46\x65\x61tureOptions\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ultValue\x18\x04 \x01(\t\"\xb3\x02\n\x13\x46\x65\x61tureRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07iconUrl\x18\x03 \x01(\t\x12(\n\x07options\x18\x04 \x03(\x0b\x32\x17.coinlib.FeatureOptions\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x0e\n\x06plugin\x18\x07 \x01(\t\x12\x15\n\rpluginVersion\x18\x08 \x01(\t\x12\x11\n\tcode_type\x18\t \x01(\t\x12\x0c\n\x04\x63ode\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12\x15\n\rfeature_infos\x18\r \x01(\t\x12\x1d\n\x15\x65stimatedDataInterval\x18\x0e \x01(\x03\"5\n\x13SimulatorMethodCall\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\"`\n\x17StatisticFunctionInputs\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ultValue\x18\x04 \x01(\t\"n\n\x15StatisticMethodInputs\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x12\n\nidentifier\x18\x03 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ultValue\x18\x04 \x01(\t\x12\x0e\n\x06values\x18\x05 \x01(\t\"\x9d\x02\n\x1bStatisticMethodRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\trefreshOn\x18\x03 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x1c\n\x14targetPositionLayout\x18\x07 \x01(\t\x12.\n\x06inputs\x18\x08 \x03(\x0b\x32\x1e.coinlib.StatisticMethodInputs\x12\x0e\n\x06plugin\x18\t \x01(\t\x12\x15\n\rpluginVersion\x18\n \x01(\t\x12\x11\n\tcode_type\x18\x0b \x01(\t\x12\x0c\n\x04\x63ode\x18\x0c \x01(\t\"\x83\x02\n!StatisticRuleFunctionRegistration\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\r\n\x05stage\x18\x06 \x01(\t\x12\x30\n\x06inputs\x18\x07 \x03(\x0b\x32 .coinlib.StatisticFunctionInputs\x12\x0e\n\x06plugin\x18\x08 \x01(\t\x12\x15\n\rpluginVersion\x18\t \x01(\t\x12\x11\n\tcode_type\x18\n \x01(\t\x12\x0c\n\x04\x63ode\x18\x0b \x01(\t\"A\n\x15WorkerRegistryRequest\x12\x11\n\tworker_id\x18\x01 \x01(\t\x12\x15\n\ractiveModules\x18\x02 \x03(\t\"D\n\x16WorkerRegistryResponse\x12\x16\n\x0etargetendpoint\x18\x01 \x01(\t\x12\x12\n\ntargetport\x18\x02 \x01(\t2\xf6\x01\n\x0c\x43hartsWorker\x12>\n\tGetConfig\x12\x12.coinlib.WorkerJob\x1a\x1b.coinlib.ChartsWorkerConfig\"\x00\x12L\n\x17OnIndicatorErrorOccured\x12\x17.coinlib.IndicatorError\x1a\x16.google.protobuf.Empty\"\x00\x12X\n\x14OnPartialChartLayout\x12&.coinlib.ChartsWorkerPartialDataLayout\x1a\x16.google.protobuf.Empty\"\x00\x32\x9d\x02\n\x16StatisticsMethodWorker\x12H\n\tGetConfig\x12\x12.coinlib.WorkerJob\x1a%.coinlib.StatisticsBulkedWorkerConfig\"\x00\x12[\n\x18OnStatisticPartiallyData\x12%.coinlib.StatisticBulkedPartiallyData\x1a\x16.google.protobuf.Empty\"\x00\x12\\\n\x1fOnStatisticFunctionErrorOccured\x12\x1f.coinlib.StatisticFunctionError\x1a\x16.google.protobuf.Empty\"\x00\x32\xf7\x04\n\x12SymbolBrokerWorker\x12\x44\n\tGetConfig\x12\x12.coinlib.WorkerJob\x1a!.coinlib.SymbolBrokerWorkerConfig\"\x00\x12o\n\x16waitForConsumerStopped\x12).coinlib.SymbolBrokerStopConsumerListener\x1a(.coinlib.SymbolBrokerStopConsumerCommand\"\x00\x12_\n\x18onHistoricalDataReceived\x12).coinlib.SymbolBrokerHistoricalMarketData\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x1aonBrokerSymbolInfoReceived\x12\x19.coinlib.SymbolBrokerInfo\x1a\x16.google.protobuf.Empty\"\x00\x12Q\n\x14onMarketDataReceived\x12\x1f.coinlib.SymbolBrokerMarketData\x1a\x16.google.protobuf.Empty\"\x00\x12O\n\x13onOrderbookReceived\x12\x1e.coinlib.SymbolBrokerOrderbook\x1a\x16.google.protobuf.Empty\"\x00\x12R\n\x1aOnSymbolBrokerErrorOccured\x12\x1a.coinlib.SymbolBrokerError\x1a\x16.google.protobuf.Empty\"\x00\x32\x89\x02\n\x12NotificationWorker\x12\x44\n\tGetConfig\x12\x12.coinlib.WorkerJob\x1a!.coinlib.NotificationWorkerConfig\"\x00\x12Y\n\x17OnCallbackDataExtracted\x12$.coinlib.NotificationCallbackExtract\x1a\x16.google.protobuf.Empty\"\x00\x12R\n\x1aOnNotificationErrorOccured\x12\x1a.coinlib.NotificationError\x1a\x16.google.protobuf.Empty\"\x00\x32\x89\x03\n\x19LogicRunnerOfflineService\x12J\n\tGetConfig\x12\x12.coinlib.WorkerJob\x1a\'.coinlib.LogicRunnerOfflineWorkerConfig\"\x00\x12\x61\n\x15OnRunnerPartiallyData\x12..coinlib.LogicRunnerOfflineWorkerPartiallyData\x1a\x16.google.protobuf.Empty\"\x00\x12X\n\x14OnRunnerErrorOccured\x12&.coinlib.LogicRunnerOfflineWorkerError\x1a\x16.google.protobuf.Empty\"\x00\x12\x63\n\x18OnRunnerFinishedComplete\x12-.coinlib.LogicRunnerOfflineWorkerFinishedData\x1a\x16.google.protobuf.Empty\"\x00\x32\xb4\x04\n\nDataWorker\x12?\n\x0f\x41\x63\x63\x65ptWorkerJob\x12\x12.coinlib.WorkerJob\x1a\x16.google.protobuf.Empty\"\x00\x12@\n\x10\x44\x65\x63lineWorkerJob\x12\x12.coinlib.WorkerJob\x1a\x16.google.protobuf.Empty\"\x00\x12<\n\x0eRegisterWorker\x12\x0f.coinlib.Worker\x1a\x17.coinlib.WorkerSettings\"\x00\x12\x44\n\rGetAllPlugins\x12\x0f.coinlib.Worker\x1a .coinlib.WorkerPluginInformation\"\x00\x12K\n\x0fUpdateWorkerJob\x12\x1e.coinlib.WorkerJobDataResponse\x1a\x16.google.protobuf.Empty\"\x00\x12H\n\x0fWatchWorkerJobs\x12\x1b.coinlib.WorkerRegistration\x1a\x12.coinlib.WorkerJob\"\x00(\x01\x30\x01\x12\x41\n\x11\x46inishedWorkerJob\x12\x12.coinlib.WorkerJob\x1a\x16.google.protobuf.Empty\"\x00\x12\x45\n\x10\x45rroredWorkerJob\x12\x17.coinlib.WorkerJobError\x1a\x16.google.protobuf.Empty\"\x00\x32\x9f\x01\n\x0cPluginWorker\x12\x38\n\tGetConfig\x12\x12.coinlib.WorkerJob\x1a\x15.coinlib.PluginConfig\"\x00\x12U\n\x14OnInstallationOutput\x12!.coinlib.PluginInstallationOutput\x1a\x16.google.protobuf.Empty\"\x00(\x01\x32\x9b\x05\n\tSimulator\x12X\n\x0fsimulateFeature\x12 .coinlib.FeatureSimulatorRequest\x1a!.coinlib.FeatureSimulatorResponse\"\x00\x12H\n\rsimulateChart\x12\x1d.coinlib.SimulatorChartConfig\x1a\x16.google.protobuf.Empty\"\x00\x12^\n\x16simulateStatisticsRule\x12&.coinlib.SimulatorStatisticChartConfig\x1a\x1a.coinlib.SimulatorResponse\"\x00\x12\x61\n\x18simulateStatisticsMethod\x12\'.coinlib.SimulatorMethodCallChartConfig\x1a\x1a.coinlib.SimulatorResponse\"\x00\x12g\n\x14simulateSymbolBroker\x12%.coinlib.SymbolBrokerSimulatorRequest\x1a&.coinlib.SymbolBrokerSimulatorResponse\"\x00\x12U\n\x0esimulateBroker\x12\x1f.coinlib.BrokerSimulatorRequest\x1a .coinlib.BrokerSimulatorResponse\"\x00\x12g\n\x14simulateNotification\x12%.coinlib.NotificationSimulatorRequest\x1a&.coinlib.NotificationSimulatorResponse\"\x00\x32m\n\tFunctions\x12`\n\x19registerIndicatorFunction\x12).coinlib.ChartWorkerIndicatorRegistration\x1a\x16.google.protobuf.Empty\"\x00\x32\xcd\x02\n\x05Logic\x12L\n\x0eregisterTrader\x12 .coinlib.LogicTraderRegistration\x1a\x16.google.protobuf.Empty\"\x00\x12P\n\x10registerScreener\x12\".coinlib.LogicScreenerRegistration\x1a\x16.google.protobuf.Empty\"\x00\x12N\n\x0fregisterAdvisor\x12!.coinlib.LogicAdvisorRegistration\x1a\x16.google.protobuf.Empty\"\x00\x12T\n\x13\x61\x64\x64LogicToWorkspace\x12#.coinlib.WorkspaceLogicRegistration\x1a\x16.google.protobuf.Empty\"\x00\x32Q\n\x06\x42roker\x12G\n\x0eregisterBroker\x12\x1b.coinlib.BrokerRegistration\x1a\x16.google.protobuf.Empty\"\x00\x32\xb2\x04\n\x0c\x42rokerWorker\x12>\n\tGetConfig\x12\x12.coinlib.WorkerJob\x1a\x1b.coinlib.BrokerWorkerConfig\"\x00\x12\x46\n\x14OnBrokerErrorOccured\x12\x14.coinlib.BrokerError\x1a\x16.google.protobuf.Empty\"\x00\x12X\n\x13WatchBrokerCommands\x12\".coinlib.BrokerCommandRegistration\x1a\x17.coinlib.BrokerCommands\"\x00(\x01\x30\x01\x12L\n\x11SendCommandAnswer\x12\x1d.coinlib.BrokerCommandsAnswer\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x16SendCommandAnswerError\x12\".coinlib.BrokerCommandsAnswerError\x1a\x16.google.protobuf.Empty\"\x00\x12U\n\x15RegisterBrokerSession\x12\".coinlib.BrokerSessionRegistration\x1a\x16.google.protobuf.Empty\"\x00\x12\x43\n\rOnBrokerEvent\x12\x18.coinlib.BrokerEventData\x1a\x16.google.protobuf.Empty\"\x00\x32\x95\x08\n\tAppWorker\x12;\n\tGetConfig\x12\x12.coinlib.WorkerJob\x1a\x18.coinlib.AppWorkerConfig\"\x00\x12L\n\x17OnAppWorkerErrorOccured\x12\x17.coinlib.AppWorkerError\x1a\x16.google.protobuf.Empty\"\x00\x12^\n\x13WatchBrokerCommands\x12%.coinlib.AppWorkerCommandRegistration\x1a\x1a.coinlib.AppWorkerCommands\"\x00(\x01\x30\x01\x12\\\n\x10RunModuleCommand\x12\x1f.coinlib.AppWorkerModuleCommand\x1a%.coinlib.AppWorkerModuleCommandAnswer\"\x00\x12\\\n\x10RunBrokerCommand\x12\x1f.coinlib.AppWorkerBrokerCommand\x1a%.coinlib.AppWorkerBrokerCommandAnswer\"\x00\x12\x61\n\x16WatchAppWorkerCommands\x12%.coinlib.AppWorkerCommandRegistration\x1a\x1a.coinlib.AppWorkerCommands\"\x00(\x01\x30\x01\x12O\n\x11SendCommandAnswer\x12 .coinlib.AppWorkerCommandsAnswer\x1a\x16.google.protobuf.Empty\"\x00\x12Y\n\x16SendCommandAnswerError\x12%.coinlib.AppWorkerCommandsAnswerError\x1a\x16.google.protobuf.Empty\"\x00\x12Y\n\x18OnAppWorkerLogicFinished\x12#.coinlib.AppWorkerFinishedStepInfos\x1a\x16.google.protobuf.Empty\"\x00\x12[\n\x18RegisterAppWorkerSession\x12%.coinlib.AppWorkerSessionRegistration\x1a\x16.google.protobuf.Empty\"\x00\x12I\n\x10OnAppWorkerEvent\x12\x1b.coinlib.AppWorkerEventData\x1a\x16.google.protobuf.Empty\"\x00\x12O\n\x12OnBrokerTestResult\x12\x1f.coinlib.BrokerTestProtocolData\x1a\x16.google.protobuf.Empty\"\x00\x32\xa2\x04\n\rFeatureWorker\x12?\n\tGetConfig\x12\x12.coinlib.WorkerJob\x1a\x1c.coinlib.FeatureWorkerConfig\"\x00\x12\x41\n\x0eOnErrorOccured\x12\x15.coinlib.FeatureError\x1a\x16.google.protobuf.Empty\"\x00\x12I\n\rWatchCommands\x12\x18.coinlib.FeatureCommands\x1a\x18.coinlib.FeatureCommands\"\x00(\x01\x30\x01\x12M\n\x11SendCommandAnswer\x12\x1e.coinlib.FeatureCommandsAnswer\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\x16SendCommandAnswerError\x12#.coinlib.FeatureCommandsAnswerError\x1a\x16.google.protobuf.Empty\"\x00\x12Z\n\x0fRegisterSession\x12#.coinlib.FeatureSessionRegistration\x1a .coinlib.RegistrationInformation\"\x00\x12>\n\x07OnEvent\x12\x19.coinlib.FeatureEventData\x1a\x16.google.protobuf.Empty\"\x00\x32]\n\x06Symbol\x12S\n\x14registerSymbolBroker\x12!.coinlib.SymbolBrokerRegistration\x1a\x16.google.protobuf.Empty\"\x00\x32\xc1\x03\n\x10\x44\x61taLoaderWorker\x12N\n\rgetAllSymbols\x12\x1e.coinlib.SymbolDataRequestInfo\x1a\x1b.coinlib.SymbolDataResponse\"\x00\x12T\n\x0fgetAllExchanges\x12 .coinlib.ExchangeDataRequestInfo\x1a\x1d.coinlib.ExchangeDataResponse\"\x00\x12J\n\rgetMarketData\x12\x1a.coinlib.MarketDataRequest\x1a\x1b.coinlib.MarketDataResponse\"\x00\x12M\n\x0egetFeatureData\x12\x1b.coinlib.FeatureDataRequest\x1a\x1c.coinlib.FeatureDataResponse\"\x00\x12l\n\x19getAdditionalDataFeatures\x12%.coinlib.AdditionalDataFeatureRequest\x1a&.coinlib.AdditionalDataFeatureResponse\"\x00\x32\x63\n\x0cNotification\x12S\n\x14registerNotification\x12!.coinlib.NotificationRegistration\x1a\x16.google.protobuf.Empty\"\x00\x32U\n\x08\x46\x65\x61tures\x12I\n\x0fregisterFeature\x12\x1c.coinlib.FeatureRegistration\x1a\x16.google.protobuf.Empty\"\x00\x32\xce\x01\n\nStatistics\x12\x65\n\x1dregisterStatisticRuleFunction\x12*.coinlib.StatisticRuleFunctionRegistration\x1a\x16.google.protobuf.Empty\"\x00\x12Y\n\x17registerStatisticMethod\x12$.coinlib.StatisticMethodRegistration\x1a\x16.google.protobuf.Empty\"\x00\x32\xc2\x01\n\x12\x44\x61taWorkerRegistry\x12J\n\x16getAllDataWorkerServer\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12`\n\x1bgetDataWorkerServerEndpoint\x12\x1e.coinlib.WorkerRegistryRequest\x1a\x1f.coinlib.WorkerRegistryResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])



_SYMBOLBROKERSYMBOL_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='coinlib.SymbolBrokerSymbol.AssetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOREX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5468,
  serialized_end=5511,
)
_sym_db.RegisterEnumDescriptor(_SYMBOLBROKERSYMBOL_ASSETTYPE)

_SYMBOLBROKERSYMBOL_CONTRACTTYPE = _descriptor.EnumDescriptor(
  name='ContractType',
  full_name='coinlib.SymbolBrokerSymbol.ContractType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FUTURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARGIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5513,
  serialized_end=5596,
)
_sym_db.RegisterEnumDescriptor(_SYMBOLBROKERSYMBOL_CONTRACTTYPE)

_SYMBOLBROKERCONSUMEMARKETDATACONFIG_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.AssetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOREX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5468,
  serialized_end=5511,
)
_sym_db.RegisterEnumDescriptor(_SYMBOLBROKERCONSUMEMARKETDATACONFIG_ASSETTYPE)

_SYMBOLBROKERCONSUMEMARKETDATACONFIG_CONTRACTTYPE = _descriptor.EnumDescriptor(
  name='ContractType',
  full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.ContractType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FUTURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARGIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5513,
  serialized_end=5596,
)
_sym_db.RegisterEnumDescriptor(_SYMBOLBROKERCONSUMEMARKETDATACONFIG_CONTRACTTYPE)

_SYMBOLBROKERCONSUMEORDERBOOKCONFIG_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.AssetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOREX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5468,
  serialized_end=5511,
)
_sym_db.RegisterEnumDescriptor(_SYMBOLBROKERCONSUMEORDERBOOKCONFIG_ASSETTYPE)

_SYMBOLBROKERCONSUMEORDERBOOKCONFIG_CONTRACTTYPE = _descriptor.EnumDescriptor(
  name='ContractType',
  full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.ContractType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FUTURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARGIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5513,
  serialized_end=5596,
)
_sym_db.RegisterEnumDescriptor(_SYMBOLBROKERCONSUMEORDERBOOKCONFIG_CONTRACTTYPE)

_SYMBOLBROKERGETHISTORICALDATACONFIG_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.AssetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOREX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5468,
  serialized_end=5511,
)
_sym_db.RegisterEnumDescriptor(_SYMBOLBROKERGETHISTORICALDATACONFIG_ASSETTYPE)

_SYMBOLBROKERGETHISTORICALDATACONFIG_CONTRACTTYPE = _descriptor.EnumDescriptor(
  name='ContractType',
  full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.ContractType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FUTURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARGIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5513,
  serialized_end=5596,
)
_sym_db.RegisterEnumDescriptor(_SYMBOLBROKERGETHISTORICALDATACONFIG_CONTRACTTYPE)

_BROKERACCOUNTMODEL_BROKERTYPE = _descriptor.EnumDescriptor(
  name='BrokerType',
  full_name='coinlib.BrokerAccountModel.BrokerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FUTURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARGIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8798,
  serialized_end=8879,
)
_sym_db.RegisterEnumDescriptor(_BROKERACCOUNTMODEL_BROKERTYPE)

_BROKERACCOUNTMODEL_BROKERMODE = _descriptor.EnumDescriptor(
  name='BrokerMode',
  full_name='coinlib.BrokerAccountModel.BrokerMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BACKTRADER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAPER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8881,
  serialized_end=8930,
)
_sym_db.RegisterEnumDescriptor(_BROKERACCOUNTMODEL_BROKERMODE)

_BROKERACCOUNTMODEL_FEEMODE = _descriptor.EnumDescriptor(
  name='FeeMode',
  full_name='coinlib.BrokerAccountModel.FeeMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PERCENTAGE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIXED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8932,
  serialized_end=8968,
)
_sym_db.RegisterEnumDescriptor(_BROKERACCOUNTMODEL_FEEMODE)

_BROKEREXCHANGE_LOGINMODE = _descriptor.EnumDescriptor(
  name='LoginMode',
  full_name='coinlib.BrokerExchange.LoginMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='API_KEY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15263,
  serialized_end=15287,
)
_sym_db.RegisterEnumDescriptor(_BROKEREXCHANGE_LOGINMODE)

_BROKEREXCHANGE_CONTRACTTYPE = _descriptor.EnumDescriptor(
  name='ContractType',
  full_name='coinlib.BrokerExchange.ContractType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FUTURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARGIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5513,
  serialized_end=5596,
)
_sym_db.RegisterEnumDescriptor(_BROKEREXCHANGE_CONTRACTTYPE)

_BROKEREXCHANGE_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='coinlib.BrokerExchange.AssetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOREX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5468,
  serialized_end=5511,
)
_sym_db.RegisterEnumDescriptor(_BROKEREXCHANGE_ASSETTYPE)

_BROKERREGISTRATION_SUPPORTEDBROKERTYPES = _descriptor.EnumDescriptor(
  name='SupportedBrokerTypes',
  full_name='coinlib.BrokerRegistration.SupportedBrokerTypes',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FUTURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARGIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15753,
  serialized_end=15844,
)
_sym_db.RegisterEnumDescriptor(_BROKERREGISTRATION_SUPPORTEDBROKERTYPES)

_BROKERSESSIONACCOUNTINFO_CONTRACTTYPE = _descriptor.EnumDescriptor(
  name='ContractType',
  full_name='coinlib.BrokerSessionAccountInfo.ContractType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SPOT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FUTURE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARGIN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5513,
  serialized_end=5596,
)
_sym_db.RegisterEnumDescriptor(_BROKERSESSIONACCOUNTINFO_CONTRACTTYPE)

_BROKERSESSIONACCOUNTINFO_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='coinlib.BrokerSessionAccountInfo.AssetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COIN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOREX', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5468,
  serialized_end=5511,
)
_sym_db.RegisterEnumDescriptor(_BROKERSESSIONACCOUNTINFO_ASSETTYPE)


_WORKERJOB = _descriptor.Descriptor(
  name='WorkerJob',
  full_name='coinlib.WorkerJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workerJobId', full_name='coinlib.WorkerJob.workerJobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerJobType', full_name='coinlib.WorkerJob.workerJobType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerJobConfig', full_name='coinlib.WorkerJob.workerJobConfig', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=195,
)


_WORKERJOBERROR = _descriptor.Descriptor(
  name='WorkerJobError',
  full_name='coinlib.WorkerJobError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workerJobId', full_name='coinlib.WorkerJobError.workerJobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerJobType', full_name='coinlib.WorkerJobError.workerJobType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerJobConfig', full_name='coinlib.WorkerJobError.workerJobConfig', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='coinlib.WorkerJobError.errorMessage', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=304,
)


_WORKERAVAILABLEPLUGINS = _descriptor.Descriptor(
  name='WorkerAvailablePlugins',
  full_name='coinlib.WorkerAvailablePlugins',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.WorkerAvailablePlugins.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.WorkerAvailablePlugins.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='coinlib.WorkerAvailablePlugins.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=375,
)


_WORKER = _descriptor.Descriptor(
  name='Worker',
  full_name='coinlib.Worker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.Worker.workerId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='coinlib.Worker.environment', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_mode', full_name='coinlib.Worker.worker_mode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availablePlugins', full_name='coinlib.Worker.availablePlugins', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os', full_name='coinlib.Worker.os', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='coinlib.Worker.workspaceId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activeModules', full_name='coinlib.Worker.activeModules', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=561,
)


_ROWDATA = _descriptor.Descriptor(
  name='RowData',
  full_name='coinlib.RowData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='coinlib.RowData.columns', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=563,
  serialized_end=589,
)


_WORKERJOBDATARESPONSE = _descriptor.Descriptor(
  name='WorkerJobDataResponse',
  full_name='coinlib.WorkerJobDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.WorkerJobDataResponse.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=591,
  serialized_end=650,
)


_WORKERJOBDATAPARTIAL = _descriptor.Descriptor(
  name='WorkerJobDataPartial',
  full_name='coinlib.WorkerJobDataPartial',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=674,
)


_CHARTWORKERPARTIALDATAINFO = _descriptor.Descriptor(
  name='ChartWorkerPartialDataInfo',
  full_name='coinlib.ChartWorkerPartialDataInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chartType', full_name='coinlib.ChartWorkerPartialDataInfo.chartType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.ChartWorkerPartialDataInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='coinlib.ChartWorkerPartialDataInfo.color', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='coinlib.ChartWorkerPartialDataInfo.size', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opacity', full_name='coinlib.ChartWorkerPartialDataInfo.opacity', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=676,
  serialized_end=783,
)


_CHARTSWORKERPARTIALDATALAYOUT = _descriptor.Descriptor(
  name='ChartsWorkerPartialDataLayout',
  full_name='coinlib.ChartsWorkerPartialDataLayout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.ChartsWorkerPartialDataLayout.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indicator', full_name='coinlib.ChartsWorkerPartialDataLayout.indicator', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartInfo', full_name='coinlib.ChartsWorkerPartialDataLayout.chartInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=786,
  serialized_end=959,
)


_CHARTWORKERINDICATOR = _descriptor.Descriptor(
  name='ChartWorkerIndicator',
  full_name='coinlib.ChartWorkerIndicator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chartType', full_name='coinlib.ChartWorkerIndicator.chartType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.ChartWorkerIndicator.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature', full_name='coinlib.ChartWorkerIndicator.feature', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subfeature', full_name='coinlib.ChartWorkerIndicator.subfeature', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short', full_name='coinlib.ChartWorkerIndicator.short', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.ChartWorkerIndicator.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='coinlib.ChartWorkerIndicator.id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elementId', full_name='coinlib.ChartWorkerIndicator.elementId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.ChartWorkerIndicator.name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id_output', full_name='coinlib.ChartWorkerIndicator.id_output', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished', full_name='coinlib.ChartWorkerIndicator.finished', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=962,
  serialized_end=1166,
)


_CHARTWORKERINDICATORREGISTRATION = _descriptor.Descriptor(
  name='ChartWorkerIndicatorRegistration',
  full_name='coinlib.ChartWorkerIndicatorRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chartType', full_name='coinlib.ChartWorkerIndicatorRegistration.chartType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.ChartWorkerIndicatorRegistration.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='coinlib.ChartWorkerIndicatorRegistration.group', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.ChartWorkerIndicatorRegistration.stage', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.ChartWorkerIndicatorRegistration.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id_output', full_name='coinlib.ChartWorkerIndicatorRegistration.id_output', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.ChartWorkerIndicatorRegistration.inputs', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='coinlib.ChartWorkerIndicatorRegistration.mode', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='short_description', full_name='coinlib.ChartWorkerIndicatorRegistration.short_description', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.ChartWorkerIndicatorRegistration.description', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='process', full_name='coinlib.ChartWorkerIndicatorRegistration.process', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unstablePeriod', full_name='coinlib.ChartWorkerIndicatorRegistration.unstablePeriod', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamicTimeseries', full_name='coinlib.ChartWorkerIndicatorRegistration.dynamicTimeseries', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.ChartWorkerIndicatorRegistration.plugin', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.ChartWorkerIndicatorRegistration.pluginVersion', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.ChartWorkerIndicatorRegistration.code_type', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.ChartWorkerIndicatorRegistration.code', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1169,
  serialized_end=1517,
)


_CHARTWORKERINDICATORCONFIGELEMENT = _descriptor.Descriptor(
  name='ChartWorkerIndicatorConfigElement',
  full_name='coinlib.ChartWorkerIndicatorConfigElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='indicator', full_name='coinlib.ChartWorkerIndicatorConfigElement.indicator', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indicatorConfig', full_name='coinlib.ChartWorkerIndicatorConfigElement.indicatorConfig', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1519,
  serialized_end=1629,
)


_CHARTSWORKERCONFIG = _descriptor.Descriptor(
  name='ChartsWorkerConfig',
  full_name='coinlib.ChartsWorkerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='coinlib.ChartsWorkerConfig.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='children', full_name='coinlib.ChartsWorkerConfig.children', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartData', full_name='coinlib.ChartsWorkerConfig.chartData', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1632,
  serialized_end=1804,
)


_STATISTICINPUT = _descriptor.Descriptor(
  name='StatisticInput',
  full_name='coinlib.StatisticInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.StatisticInput.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='coinlib.StatisticInput.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1851,
)


_DATAERROR = _descriptor.Descriptor(
  name='DataError',
  full_name='coinlib.DataError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='coinlib.DataError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorCode', full_name='coinlib.DataError.errorCode', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='critical', full_name='coinlib.DataError.critical', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1853,
  serialized_end=1918,
)


_INDICATORERROR = _descriptor.Descriptor(
  name='IndicatorError',
  full_name='coinlib.IndicatorError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.IndicatorError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.IndicatorError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indicator', full_name='coinlib.IndicatorError.indicator', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1921,
  serialized_end=2058,
)


_STATISTICRULEFUNCTIONERROR = _descriptor.Descriptor(
  name='StatisticRuleFunctionError',
  full_name='coinlib.StatisticRuleFunctionError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.StatisticRuleFunctionError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.StatisticRuleFunctionError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statisticFunction', full_name='coinlib.StatisticRuleFunctionError.statisticFunction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2061,
  serialized_end=2224,
)


_STATISTICMETHODFUNCTIONERROR = _descriptor.Descriptor(
  name='StatisticMethodFunctionError',
  full_name='coinlib.StatisticMethodFunctionError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.StatisticMethodFunctionError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.StatisticMethodFunctionError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statisticFunction', full_name='coinlib.StatisticMethodFunctionError.statisticFunction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2227,
  serialized_end=2392,
)


_STATISTICSMETHODWORKERWINDOWCONFIG = _descriptor.Descriptor(
  name='StatisticsMethodWorkerWindowConfig',
  full_name='coinlib.StatisticsMethodWorkerWindowConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='coinlib.StatisticsMethodWorkerWindowConfig.method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='coinlib.StatisticsMethodWorkerWindowConfig.params', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='windowId', full_name='coinlib.StatisticsMethodWorkerWindowConfig.windowId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartData', full_name='coinlib.StatisticsMethodWorkerWindowConfig.chartData', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameterTable', full_name='coinlib.StatisticsMethodWorkerWindowConfig.parameterTable', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2395,
  serialized_end=2573,
)


_PARAMETERTABLEENTRY = _descriptor.Descriptor(
  name='ParameterTableEntry',
  full_name='coinlib.ParameterTableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.ParameterTableEntry.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='coinlib.ParameterTableEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.ParameterTableEntry.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='coinlib.ParameterTableEntry.required', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2575,
  serialized_end=2657,
)


_PARAMETERTABLE = _descriptor.Descriptor(
  name='ParameterTable',
  full_name='coinlib.ParameterTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameters', full_name='coinlib.ParameterTable.parameters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2659,
  serialized_end=2725,
)


_CHARTDATAINFO = _descriptor.Descriptor(
  name='ChartDataInfo',
  full_name='coinlib.ChartDataInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart_id', full_name='coinlib.ChartDataInfo.chart_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chart_prefix', full_name='coinlib.ChartDataInfo.chart_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspace_id', full_name='coinlib.ChartDataInfo.workspace_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activity_id', full_name='coinlib.ChartDataInfo.activity_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2727,
  serialized_end=2825,
)


_STATISTICSRULEWORKERCONFIG_INPUTSENTRY = _descriptor.Descriptor(
  name='InputsEntry',
  full_name='coinlib.StatisticsRuleWorkerConfig.InputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='coinlib.StatisticsRuleWorkerConfig.InputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='coinlib.StatisticsRuleWorkerConfig.InputsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3132,
  serialized_end=3202,
)

_STATISTICSRULEWORKERCONFIG = _descriptor.Descriptor(
  name='StatisticsRuleWorkerConfig',
  full_name='coinlib.StatisticsRuleWorkerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='coinlib.StatisticsRuleWorkerConfig.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='coinlib.StatisticsRuleWorkerConfig.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statisticFunction', full_name='coinlib.StatisticsRuleWorkerConfig.statisticFunction', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.StatisticsRuleWorkerConfig.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='combinator', full_name='coinlib.StatisticsRuleWorkerConfig.combinator', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='combinator_not', full_name='coinlib.StatisticsRuleWorkerConfig.combinator_not', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.StatisticsRuleWorkerConfig.type', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartData', full_name='coinlib.StatisticsRuleWorkerConfig.chartData', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='coinlib.StatisticsRuleWorkerConfig.enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATISTICSRULEWORKERCONFIG_INPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2828,
  serialized_end=3202,
)


_STATISTICSRULEWORKERCONFIGTYPE = _descriptor.Descriptor(
  name='StatisticsRuleWorkerConfigType',
  full_name='coinlib.StatisticsRuleWorkerConfigType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rule', full_name='coinlib.StatisticsRuleWorkerConfigType.rule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='methodWindow', full_name='coinlib.StatisticsRuleWorkerConfigType.methodWindow', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='test_oneof', full_name='coinlib.StatisticsRuleWorkerConfigType.test_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3205,
  serialized_end=3373,
)


_STATISTICSBULKEDWORKERCONFIG = _descriptor.Descriptor(
  name='StatisticsBulkedWorkerConfig',
  full_name='coinlib.StatisticsBulkedWorkerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configs', full_name='coinlib.StatisticsBulkedWorkerConfig.configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartData', full_name='coinlib.StatisticsBulkedWorkerConfig.chartData', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameterTable', full_name='coinlib.StatisticsBulkedWorkerConfig.parameterTable', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3376,
  serialized_end=3556,
)


_STATISTICFUNCTIONERROR = _descriptor.Descriptor(
  name='StatisticFunctionError',
  full_name='coinlib.StatisticFunctionError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.StatisticFunctionError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.StatisticFunctionError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statisticFunction', full_name='coinlib.StatisticFunctionError.statisticFunction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3559,
  serialized_end=3718,
)


_STATISTICMETHODPARTIALLYDATA = _descriptor.Descriptor(
  name='StatisticMethodPartiallyData',
  full_name='coinlib.StatisticMethodPartiallyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.StatisticMethodPartiallyData.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='coinlib.StatisticMethodPartiallyData.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='documentId', full_name='coinlib.StatisticMethodPartiallyData.documentId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='coinlib.StatisticMethodPartiallyData.width', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='coinlib.StatisticMethodPartiallyData.height', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column', full_name='coinlib.StatisticMethodPartiallyData.column', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='windowId', full_name='coinlib.StatisticMethodPartiallyData.windowId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3721,
  serialized_end=3888,
)


_STATISTICRULEPARTIALLYDATA = _descriptor.Descriptor(
  name='StatisticRulePartiallyData',
  full_name='coinlib.StatisticRulePartiallyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.StatisticRulePartiallyData.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statisticRule', full_name='coinlib.StatisticRulePartiallyData.statisticRule', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collectionid', full_name='coinlib.StatisticRulePartiallyData.collectionid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resultName', full_name='coinlib.StatisticRulePartiallyData.resultName', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3891,
  serialized_end=4057,
)


_STATISTICBULKEDPARTIALLYDATA = _descriptor.Descriptor(
  name='StatisticBulkedPartiallyData',
  full_name='coinlib.StatisticBulkedPartiallyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='methodData', full_name='coinlib.StatisticBulkedPartiallyData.methodData', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ruleData', full_name='coinlib.StatisticBulkedPartiallyData.ruleData', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='test_oneof', full_name='coinlib.StatisticBulkedPartiallyData.test_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4060,
  serialized_end=4222,
)


_SYMBOLBROKERERROR = _descriptor.Descriptor(
  name='SymbolBrokerError',
  full_name='coinlib.SymbolBrokerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.SymbolBrokerError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.SymbolBrokerError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4224,
  serialized_end=4314,
)


_SYMBOLBROKERMARKETDATA = _descriptor.Descriptor(
  name='SymbolBrokerMarketData',
  full_name='coinlib.SymbolBrokerMarketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.SymbolBrokerMarketData.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='coinlib.SymbolBrokerMarketData.open', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='coinlib.SymbolBrokerMarketData.close', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='coinlib.SymbolBrokerMarketData.high', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='coinlib.SymbolBrokerMarketData.low', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='coinlib.SymbolBrokerMarketData.volume', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade', full_name='coinlib.SymbolBrokerMarketData.trade', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datetime', full_name='coinlib.SymbolBrokerMarketData.datetime', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='coinlib.SymbolBrokerMarketData.symbol_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='coinlib.SymbolBrokerMarketData.symbol', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='coinlib.SymbolBrokerMarketData.exchange_id', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_time', full_name='coinlib.SymbolBrokerMarketData.event_time', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isFinal', full_name='coinlib.SymbolBrokerMarketData.isFinal', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='closeTime', full_name='coinlib.SymbolBrokerMarketData.closeTime', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4317,
  serialized_end=4594,
)


_SYMBOLBROKERINFO = _descriptor.Descriptor(
  name='SymbolBrokerInfo',
  full_name='coinlib.SymbolBrokerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.SymbolBrokerInfo.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchanges', full_name='coinlib.SymbolBrokerInfo.exchanges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbols', full_name='coinlib.SymbolBrokerInfo.symbols', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4597,
  serialized_end=4747,
)


_SYMBOLBROKERORDERBOOK = _descriptor.Descriptor(
  name='SymbolBrokerOrderbook',
  full_name='coinlib.SymbolBrokerOrderbook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.SymbolBrokerOrderbook.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4749,
  serialized_end=4808,
)


_SYMBOLBROKERHISTORICALMARKETDATA = _descriptor.Descriptor(
  name='SymbolBrokerHistoricalMarketData',
  full_name='coinlib.SymbolBrokerHistoricalMarketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.SymbolBrokerHistoricalMarketData.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4810,
  serialized_end=4880,
)


_SYMBOLBROKEREXCHANGE = _descriptor.Descriptor(
  name='SymbolBrokerExchange',
  full_name='coinlib.SymbolBrokerExchange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='icon', full_name='coinlib.SymbolBrokerExchange.icon', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='coinlib.SymbolBrokerExchange.exchange_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.SymbolBrokerExchange.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='website', full_name='coinlib.SymbolBrokerExchange.website', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbols_count', full_name='coinlib.SymbolBrokerExchange.symbols_count', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume_1mth_usd', full_name='coinlib.SymbolBrokerExchange.volume_1mth_usd', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume_1day_usd', full_name='coinlib.SymbolBrokerExchange.volume_1day_usd', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume_1hrs_usd', full_name='coinlib.SymbolBrokerExchange.volume_1hrs_usd', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4883,
  serialized_end=5069,
)


_SYMBOLBROKERSYMBOL = _descriptor.Descriptor(
  name='SymbolBrokerSymbol',
  full_name='coinlib.SymbolBrokerSymbol',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='coinlib.SymbolBrokerSymbol.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='coinlib.SymbolBrokerSymbol.exchange_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='coinlib.SymbolBrokerSymbol.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetType', full_name='coinlib.SymbolBrokerSymbol.assetType', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractType', full_name='coinlib.SymbolBrokerSymbol.contractType', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='coinlib.SymbolBrokerSymbol.base', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='coinlib.SymbolBrokerSymbol.quote', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange_symbol_id', full_name='coinlib.SymbolBrokerSymbol.exchange_symbol_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_precision', full_name='coinlib.SymbolBrokerSymbol.size_precision', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_precision', full_name='coinlib.SymbolBrokerSymbol.price_precision', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='coinlib.SymbolBrokerSymbol.price', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume_1mth_usd', full_name='coinlib.SymbolBrokerSymbol.volume_1mth_usd', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume_1day_usd', full_name='coinlib.SymbolBrokerSymbol.volume_1day_usd', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume_1hrs_usd', full_name='coinlib.SymbolBrokerSymbol.volume_1hrs_usd', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SYMBOLBROKERSYMBOL_ASSETTYPE,
    _SYMBOLBROKERSYMBOL_CONTRACTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5072,
  serialized_end=5596,
)


_SYMBOLBROKERBROKERINFOCONFIG = _descriptor.Descriptor(
  name='SymbolBrokerBrokerInfoConfig',
  full_name='coinlib.SymbolBrokerBrokerInfoConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.SymbolBrokerBrokerInfoConfig.options', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbolBrokerIdentifier', full_name='coinlib.SymbolBrokerBrokerInfoConfig.symbolBrokerIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5598,
  serialized_end=5677,
)


_SYMBOLBROKERCONSUMEMARKETDATACONFIG = _descriptor.Descriptor(
  name='SymbolBrokerConsumeMarketdataConfig',
  full_name='coinlib.SymbolBrokerConsumeMarketdataConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.options', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbolBrokerIdentifier', full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.symbolBrokerIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteAsset', full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.quoteAsset', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseAsset', full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.baseAsset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_symbol_id', full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.client_symbol_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeframe', full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.timeframe', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.exchange_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractType', full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.contractType', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetType', full_name='coinlib.SymbolBrokerConsumeMarketdataConfig.assetType', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SYMBOLBROKERCONSUMEMARKETDATACONFIG_ASSETTYPE,
    _SYMBOLBROKERCONSUMEMARKETDATACONFIG_CONTRACTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5680,
  serialized_end=6157,
)


_SYMBOLBROKERCONSUMEORDERBOOKCONFIG = _descriptor.Descriptor(
  name='SymbolBrokerConsumeOrderbookConfig',
  full_name='coinlib.SymbolBrokerConsumeOrderbookConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.options', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbolBrokerIdentifier', full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.symbolBrokerIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteAsset', full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.quoteAsset', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseAsset', full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.baseAsset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_symbol_id', full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.client_symbol_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeframe', full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.timeframe', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.exchange_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractType', full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.contractType', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetType', full_name='coinlib.SymbolBrokerConsumeOrderbookConfig.assetType', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SYMBOLBROKERCONSUMEORDERBOOKCONFIG_ASSETTYPE,
    _SYMBOLBROKERCONSUMEORDERBOOKCONFIG_CONTRACTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6160,
  serialized_end=6634,
)


_SYMBOLBROKERGETHISTORICALDATACONFIG = _descriptor.Descriptor(
  name='SymbolBrokerGetHistoricalDataConfig',
  full_name='coinlib.SymbolBrokerGetHistoricalDataConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.options', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbolBrokerIdentifier', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.symbolBrokerIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quoteAsset', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.quoteAsset', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseAsset', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.baseAsset', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_symbol_id', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.client_symbol_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeframe', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.timeframe', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.start', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.end', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.exchange_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartData', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.chartData', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractType', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.contractType', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetType', full_name='coinlib.SymbolBrokerGetHistoricalDataConfig.assetType', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SYMBOLBROKERGETHISTORICALDATACONFIG_ASSETTYPE,
    _SYMBOLBROKERGETHISTORICALDATACONFIG_CONTRACTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6637,
  serialized_end=7185,
)


_SYMBOLBROKERWORKERCONFIG = _descriptor.Descriptor(
  name='SymbolBrokerWorkerConfig',
  full_name='coinlib.SymbolBrokerWorkerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='infoConfig', full_name='coinlib.SymbolBrokerWorkerConfig.infoConfig', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumeConfig', full_name='coinlib.SymbolBrokerWorkerConfig.consumeConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumeOrderbookConfig', full_name='coinlib.SymbolBrokerWorkerConfig.consumeOrderbookConfig', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='historicalConfig', full_name='coinlib.SymbolBrokerWorkerConfig.historicalConfig', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='test_oneof', full_name='coinlib.SymbolBrokerWorkerConfig.test_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7188,
  serialized_end=7513,
)


_SYMBOLBROKERSTOPCONSUMERLISTENER = _descriptor.Descriptor(
  name='SymbolBrokerStopConsumerListener',
  full_name='coinlib.SymbolBrokerStopConsumerListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.SymbolBrokerStopConsumerListener.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7515,
  serialized_end=7585,
)


_SYMBOLBROKERSTOPCONSUMERCOMMAND = _descriptor.Descriptor(
  name='SymbolBrokerStopConsumerCommand',
  full_name='coinlib.SymbolBrokerStopConsumerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stopped', full_name='coinlib.SymbolBrokerStopConsumerCommand.stopped', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7587,
  serialized_end=7637,
)


_NOTIFICATIONEXTRACTMESSAGEDATACONFIG = _descriptor.Descriptor(
  name='NotificationExtractMessageDataConfig',
  full_name='coinlib.NotificationExtractMessageDataConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.NotificationExtractMessageDataConfig.inputs', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notificationIdentifier', full_name='coinlib.NotificationExtractMessageDataConfig.notificationIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='coinlib.NotificationExtractMessageDataConfig.data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.NotificationExtractMessageDataConfig.options', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7639,
  serialized_end=7756,
)


_NOTIFICATIONSENDMESSAGEDATACONFIG = _descriptor.Descriptor(
  name='NotificationSendMessageDataConfig',
  full_name='coinlib.NotificationSendMessageDataConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.NotificationSendMessageDataConfig.inputs', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notificationIdentifier', full_name='coinlib.NotificationSendMessageDataConfig.notificationIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='coinlib.NotificationSendMessageDataConfig.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='images', full_name='coinlib.NotificationSendMessageDataConfig.images', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buttons', full_name='coinlib.NotificationSendMessageDataConfig.buttons', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.NotificationSendMessageDataConfig.options', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callback_id', full_name='coinlib.NotificationSendMessageDataConfig.callback_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callback_url', full_name='coinlib.NotificationSendMessageDataConfig.callback_url', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channels', full_name='coinlib.NotificationSendMessageDataConfig.channels', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7759,
  serialized_end=7970,
)


_NOTIFICATIONWORKERCONFIG = _descriptor.Descriptor(
  name='NotificationWorkerConfig',
  full_name='coinlib.NotificationWorkerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sendMessageConfig', full_name='coinlib.NotificationWorkerConfig.sendMessageConfig', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extractDataConfig', full_name='coinlib.NotificationWorkerConfig.extractDataConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='test_oneof', full_name='coinlib.NotificationWorkerConfig.test_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7973,
  serialized_end=8162,
)


_NOTIFICATIONERROR = _descriptor.Descriptor(
  name='NotificationError',
  full_name='coinlib.NotificationError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.NotificationError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.NotificationError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8164,
  serialized_end=8254,
)


_NOTIFICATIONCALLBACKEXTRACT = _descriptor.Descriptor(
  name='NotificationCallbackExtract',
  full_name='coinlib.NotificationCallbackExtract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='button_id', full_name='coinlib.NotificationCallbackExtract.button_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='coinlib.NotificationCallbackExtract.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.NotificationCallbackExtract.worker', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8256,
  serialized_end=8354,
)


_LOGICCOMPONENT = _descriptor.Descriptor(
  name='LogicComponent',
  full_name='coinlib.LogicComponent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='coinlib.LogicComponent.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.LogicComponent.identifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logicComponentId', full_name='coinlib.LogicComponent.logicComponentId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='coinlib.LogicComponent.environment', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='coinlib.LogicComponent.params', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.LogicComponent.type', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8357,
  serialized_end=8487,
)


_BROKERACCOUNTMODEL = _descriptor.Descriptor(
  name='BrokerAccountModel',
  full_name='coinlib.BrokerAccountModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brokerType', full_name='coinlib.BrokerAccountModel.brokerType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='coinlib.BrokerAccountModel.mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='coinlib.BrokerAccountModel.exchange', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='makerFee', full_name='coinlib.BrokerAccountModel.makerFee', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='takerFee', full_name='coinlib.BrokerAccountModel.takerFee', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='makerFeeMode', full_name='coinlib.BrokerAccountModel.makerFeeMode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='takerFeeMode', full_name='coinlib.BrokerAccountModel.takerFeeMode', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BROKERACCOUNTMODEL_BROKERTYPE,
    _BROKERACCOUNTMODEL_BROKERMODE,
    _BROKERACCOUNTMODEL_FEEMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8490,
  serialized_end=8968,
)


_PORTFOLIOASSET = _descriptor.Descriptor(
  name='PortfolioAsset',
  full_name='coinlib.PortfolioAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.PortfolioAsset.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='coinlib.PortfolioAsset.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='free', full_name='coinlib.PortfolioAsset.free', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='coinlib.PortfolioAsset.exchange', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='coinlib.PortfolioAsset.locked', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastPrice', full_name='coinlib.PortfolioAsset.lastPrice', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='coinlib.PortfolioAsset.date', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8970,
  serialized_end=9096,
)


_CALCULATEDBASEMONEY = _descriptor.Descriptor(
  name='CalculatedBaseMoney',
  full_name='coinlib.CalculatedBaseMoney',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='coinlib.CalculatedBaseMoney.total', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='free', full_name='coinlib.CalculatedBaseMoney.free', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='coinlib.CalculatedBaseMoney.locked', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='coinlib.CalculatedBaseMoney.summary', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='coinlib.CalculatedBaseMoney.date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.CalculatedBaseMoney.name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9098,
  serialized_end=9209,
)


_PORTFOLIOMODEL = _descriptor.Descriptor(
  name='PortfolioModel',
  full_name='coinlib.PortfolioModel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assets', full_name='coinlib.PortfolioModel.assets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currentCalculatedBaseMoney', full_name='coinlib.PortfolioModel.currentCalculatedBaseMoney', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='historicalCalculatedBaseMoney', full_name='coinlib.PortfolioModel.historicalCalculatedBaseMoney', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9212,
  serialized_end=9404,
)


_LOGICRUNNERLOGIC = _descriptor.Descriptor(
  name='LogicRunnerLogic',
  full_name='coinlib.LogicRunnerLogic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chartData', full_name='coinlib.LogicRunnerLogic.chartData', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logicComponents', full_name='coinlib.LogicRunnerLogic.logicComponents', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startDate', full_name='coinlib.LogicRunnerLogic.startDate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endDate', full_name='coinlib.LogicRunnerLogic.endDate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portfolio', full_name='coinlib.LogicRunnerLogic.portfolio', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerAccount', full_name='coinlib.LogicRunnerLogic.brokerAccount', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameterTable', full_name='coinlib.LogicRunnerLogic.parameterTable', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9407,
  serialized_end=9699,
)


_LOGICRUNNEROFFLINEWORKERCONFIG = _descriptor.Descriptor(
  name='LogicRunnerOfflineWorkerConfig',
  full_name='coinlib.LogicRunnerOfflineWorkerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='logicInfo', full_name='coinlib.LogicRunnerOfflineWorkerConfig.logicInfo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartData', full_name='coinlib.LogicRunnerOfflineWorkerConfig.chartData', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portfolio', full_name='coinlib.LogicRunnerOfflineWorkerConfig.portfolio', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='advancedDataInfo', full_name='coinlib.LogicRunnerOfflineWorkerConfig.advancedDataInfo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9702,
  serialized_end=9894,
)


_LOGICRUNNERSTATISTICS = _descriptor.Descriptor(
  name='LogicRunnerStatistics',
  full_name='coinlib.LogicRunnerStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='highestProfitPercentage', full_name='coinlib.LogicRunnerStatistics.highestProfitPercentage', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highestLossPercentage', full_name='coinlib.LogicRunnerStatistics.highestLossPercentage', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sinceDate', full_name='coinlib.LogicRunnerStatistics.sinceDate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='atDate', full_name='coinlib.LogicRunnerStatistics.atDate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tradesCnt', full_name='coinlib.LogicRunnerStatistics.tradesCnt', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='calculatedMoney', full_name='coinlib.LogicRunnerStatistics.calculatedMoney', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unrealizedProfitPercentage', full_name='coinlib.LogicRunnerStatistics.unrealizedProfitPercentage', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fees', full_name='coinlib.LogicRunnerStatistics.fees', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profitCompletePercentage', full_name='coinlib.LogicRunnerStatistics.profitCompletePercentage', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highestProfitPerGroup', full_name='coinlib.LogicRunnerStatistics.highestProfitPerGroup', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highestLossPerGroup', full_name='coinlib.LogicRunnerStatistics.highestLossPerGroup', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slippagePerGroup', full_name='coinlib.LogicRunnerStatistics.slippagePerGroup', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='averageAmountQuote', full_name='coinlib.LogicRunnerStatistics.averageAmountQuote', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='averageProfitPercentagePergroup', full_name='coinlib.LogicRunnerStatistics.averageProfitPercentagePergroup', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portfolioTimeline', full_name='coinlib.LogicRunnerStatistics.portfolioTimeline', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9897,
  serialized_end=10359,
)


_LOGICRUNNEROFFLINEWORKERPARTIALLYDATA = _descriptor.Descriptor(
  name='LogicRunnerOfflineWorkerPartiallyData',
  full_name='coinlib.LogicRunnerOfflineWorkerPartiallyData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.LogicRunnerOfflineWorkerPartiallyData.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='percentage', full_name='coinlib.LogicRunnerOfflineWorkerPartiallyData.percentage', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signalData', full_name='coinlib.LogicRunnerOfflineWorkerPartiallyData.signalData', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistic', full_name='coinlib.LogicRunnerOfflineWorkerPartiallyData.statistic', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10362,
  serialized_end=10528,
)


_LOGICRUNNEROFFLINEWORKERERROR = _descriptor.Descriptor(
  name='LogicRunnerOfflineWorkerError',
  full_name='coinlib.LogicRunnerOfflineWorkerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.LogicRunnerOfflineWorkerError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.LogicRunnerOfflineWorkerError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='coinlib.LogicRunnerOfflineWorkerError.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10530,
  serialized_end=10649,
)


_LOGICRUNNEROFFLINEWORKERFINISHEDDATA = _descriptor.Descriptor(
  name='LogicRunnerOfflineWorkerFinishedData',
  full_name='coinlib.LogicRunnerOfflineWorkerFinishedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.LogicRunnerOfflineWorkerFinishedData.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.LogicRunnerOfflineWorkerFinishedData.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signalData', full_name='coinlib.LogicRunnerOfflineWorkerFinishedData.signalData', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='statistic', full_name='coinlib.LogicRunnerOfflineWorkerFinishedData.statistic', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10652,
  serialized_end=10832,
)


_WORKERPLUGININFORMATION = _descriptor.Descriptor(
  name='WorkerPluginInformation',
  full_name='coinlib.WorkerPluginInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.WorkerPluginInformation.plugin', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10834,
  serialized_end=10898,
)


_WORKERSETTINGS = _descriptor.Descriptor(
  name='WorkerSettings',
  full_name='coinlib.WorkerSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activeModules', full_name='coinlib.WorkerSettings.activeModules', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_mode', full_name='coinlib.WorkerSettings.worker_mode', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10900,
  serialized_end=10960,
)


_WORKERREGISTRATION = _descriptor.Descriptor(
  name='WorkerRegistration',
  full_name='coinlib.WorkerRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='coinlib.WorkerRegistration.worker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10962,
  serialized_end=11001,
)


_PLUGINCONFIG = _descriptor.Descriptor(
  name='PluginConfig',
  full_name='coinlib.PluginConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.PluginConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='coinlib.PluginConfig.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.PluginConfig.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filecontent', full_name='coinlib.PluginConfig.filecontent', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testOnly', full_name='coinlib.PluginConfig.testOnly', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filetype', full_name='coinlib.PluginConfig.filetype', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11003,
  serialized_end=11119,
)


_PLUGININSTALLATIONOUTPUT = _descriptor.Descriptor(
  name='PluginInstallationOutput',
  full_name='coinlib.PluginInstallationOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.PluginInstallationOutput.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outputMessage', full_name='coinlib.PluginInstallationOutput.outputMessage', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11121,
  serialized_end=11206,
)


_SIMULATORCHARTCONFIGINDICATOR_INPUTSENTRY = _descriptor.Descriptor(
  name='InputsEntry',
  full_name='coinlib.SimulatorChartConfigIndicator.InputsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='coinlib.SimulatorChartConfigIndicator.InputsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='coinlib.SimulatorChartConfigIndicator.InputsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11367,
  serialized_end=11412,
)

_SIMULATORCHARTCONFIGINDICATOR = _descriptor.Descriptor(
  name='SimulatorChartConfigIndicator',
  full_name='coinlib.SimulatorChartConfigIndicator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature', full_name='coinlib.SimulatorChartConfigIndicator.feature', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subfeature', full_name='coinlib.SimulatorChartConfigIndicator.subfeature', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.SimulatorChartConfigIndicator.inputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chartIndex', full_name='coinlib.SimulatorChartConfigIndicator.chartIndex', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SIMULATORCHARTCONFIGINDICATOR_INPUTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11209,
  serialized_end=11412,
)


_SIMULATORCHARTCONFIG = _descriptor.Descriptor(
  name='SimulatorChartConfig',
  full_name='coinlib.SimulatorChartConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_id', full_name='coinlib.SimulatorChartConfig.kernel_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broker', full_name='coinlib.SimulatorChartConfig.broker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='coinlib.SimulatorChartConfig.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeframe', full_name='coinlib.SimulatorChartConfig.timeframe', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indicators', full_name='coinlib.SimulatorChartConfig.indicators', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.SimulatorChartConfig.workerId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11415,
  serialized_end=11585,
)


_SIMULATORSTATISTICCHARTCONFIG = _descriptor.Descriptor(
  name='SimulatorStatisticChartConfig',
  full_name='coinlib.SimulatorStatisticChartConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_id', full_name='coinlib.SimulatorStatisticChartConfig.kernel_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulatorName', full_name='coinlib.SimulatorStatisticChartConfig.simulatorName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indicators', full_name='coinlib.SimulatorStatisticChartConfig.indicators', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.SimulatorStatisticChartConfig.workerId', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11588,
  serialized_end=11739,
)


_SIMULATORMETHODCALLCHARTCONFIG = _descriptor.Descriptor(
  name='SimulatorMethodCallChartConfig',
  full_name='coinlib.SimulatorMethodCallChartConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kernel_id', full_name='coinlib.SimulatorMethodCallChartConfig.kernel_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulatorName', full_name='coinlib.SimulatorMethodCallChartConfig.simulatorName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indicators', full_name='coinlib.SimulatorMethodCallChartConfig.indicators', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.SimulatorMethodCallChartConfig.workerId', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='methods', full_name='coinlib.SimulatorMethodCallChartConfig.methods', index=4,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11742,
  serialized_end=11941,
)


_SIMULATORRESPONSE = _descriptor.Descriptor(
  name='SimulatorResponse',
  full_name='coinlib.SimulatorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='coinlib.SimulatorResponse.workspaceId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11943,
  serialized_end=11983,
)


_SYMBOLBROKERSIMULATORREQUEST = _descriptor.Descriptor(
  name='SymbolBrokerSimulatorRequest',
  full_name='coinlib.SymbolBrokerSimulatorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbolBrokerId', full_name='coinlib.SymbolBrokerSimulatorRequest.symbolBrokerId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.SymbolBrokerSimulatorRequest.options', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.SymbolBrokerSimulatorRequest.workerId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testSymbol1', full_name='coinlib.SymbolBrokerSimulatorRequest.testSymbol1', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testSymbol2', full_name='coinlib.SymbolBrokerSimulatorRequest.testSymbol2', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11986,
  serialized_end=12117,
)


_SYMBOLBROKERSIMULATORRESPONSE = _descriptor.Descriptor(
  name='SymbolBrokerSimulatorResponse',
  full_name='coinlib.SymbolBrokerSimulatorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbolBrokerId', full_name='coinlib.SymbolBrokerSimulatorResponse.symbolBrokerId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='coinlib.SymbolBrokerSimulatorResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulatorResponseText', full_name='coinlib.SymbolBrokerSimulatorResponse.simulatorResponseText', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12119,
  serialized_end=12222,
)


_BROKERSIMULATORBROKERLOGINDATA = _descriptor.Descriptor(
  name='BrokerSimulatorBrokerLoginData',
  full_name='coinlib.BrokerSimulatorBrokerLoginData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apikey', full_name='coinlib.BrokerSimulatorBrokerLoginData.apikey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='coinlib.BrokerSimulatorBrokerLoginData.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12224,
  serialized_end=12288,
)


_BROKERSIMULATORBROKERDATA = _descriptor.Descriptor(
  name='BrokerSimulatorBrokerData',
  full_name='coinlib.BrokerSimulatorBrokerData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='coinlib.BrokerSimulatorBrokerData.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loginInfo', full_name='coinlib.BrokerSimulatorBrokerData.loginInfo', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetType', full_name='coinlib.BrokerSimulatorBrokerData.assetType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractType', full_name='coinlib.BrokerSimulatorBrokerData.contractType', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12291,
  serialized_end=12440,
)


_BROKERSIMULATORREQUEST = _descriptor.Descriptor(
  name='BrokerSimulatorRequest',
  full_name='coinlib.BrokerSimulatorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brokerId', full_name='coinlib.BrokerSimulatorRequest.brokerId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.BrokerSimulatorRequest.options', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.BrokerSimulatorRequest.workerId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerInfo', full_name='coinlib.BrokerSimulatorRequest.brokerInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paperMode', full_name='coinlib.BrokerSimulatorRequest.paperMode', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12443,
  serialized_end=12595,
)


_BROKERSIMULATORRESPONSE = _descriptor.Descriptor(
  name='BrokerSimulatorResponse',
  full_name='coinlib.BrokerSimulatorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='brokerId', full_name='coinlib.BrokerSimulatorResponse.brokerId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='coinlib.BrokerSimulatorResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulatorResponseText', full_name='coinlib.BrokerSimulatorResponse.simulatorResponseText', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.BrokerSimulatorResponse.sessionId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='coinlib.BrokerSimulatorResponse.workspaceId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetdepotId', full_name='coinlib.BrokerSimulatorResponse.targetdepotId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12598,
  serialized_end=12752,
)


_NOTIFICATIONSIMULATORREQUEST = _descriptor.Descriptor(
  name='NotificationSimulatorRequest',
  full_name='coinlib.NotificationSimulatorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.NotificationSimulatorRequest.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.NotificationSimulatorRequest.inputs', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.NotificationSimulatorRequest.workerId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channels', full_name='coinlib.NotificationSimulatorRequest.channels', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12754,
  serialized_end=12856,
)


_NOTIFICATIONSIMULATORRESPONSE = _descriptor.Descriptor(
  name='NotificationSimulatorResponse',
  full_name='coinlib.NotificationSimulatorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.NotificationSimulatorResponse.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='coinlib.NotificationSimulatorResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulatorResponseText', full_name='coinlib.NotificationSimulatorResponse.simulatorResponseText', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12858,
  serialized_end=12957,
)


_FEATURESIMULATORREQUEST = _descriptor.Descriptor(
  name='FeatureSimulatorRequest',
  full_name='coinlib.FeatureSimulatorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.FeatureSimulatorRequest.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.FeatureSimulatorRequest.options', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.FeatureSimulatorRequest.workerId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12959,
  serialized_end=13039,
)


_FEATURESIMULATORRESPONSE = _descriptor.Descriptor(
  name='FeatureSimulatorResponse',
  full_name='coinlib.FeatureSimulatorResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.FeatureSimulatorResponse.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='coinlib.FeatureSimulatorResponse.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simulatorResponseText', full_name='coinlib.FeatureSimulatorResponse.simulatorResponseText', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13041,
  serialized_end=13135,
)


_LOGICINPUT = _descriptor.Descriptor(
  name='LogicInput',
  full_name='coinlib.LogicInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.LogicInput.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='coinlib.LogicInput.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.LogicInput.identifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultValue', full_name='coinlib.LogicInput.defaultValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='coinlib.LogicInput.values', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13137,
  serialized_end=13236,
)


_LOGICTRADERREGISTRATION = _descriptor.Descriptor(
  name='LogicTraderRegistration',
  full_name='coinlib.LogicTraderRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.LogicTraderRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='coinlib.LogicTraderRegistration.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.LogicTraderRegistration.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.LogicTraderRegistration.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modules', full_name='coinlib.LogicTraderRegistration.modules', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.LogicTraderRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.LogicTraderRegistration.plugin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.LogicTraderRegistration.pluginVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='coinlib.LogicTraderRegistration.workspaceId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.LogicTraderRegistration.code_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.LogicTraderRegistration.code', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.LogicTraderRegistration.workerId', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13239,
  serialized_end=13500,
)


_LOGICALERTREGISTRATION = _descriptor.Descriptor(
  name='LogicAlertRegistration',
  full_name='coinlib.LogicAlertRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.LogicAlertRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='coinlib.LogicAlertRegistration.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.LogicAlertRegistration.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.LogicAlertRegistration.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modules', full_name='coinlib.LogicAlertRegistration.modules', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.LogicAlertRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.LogicAlertRegistration.plugin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.LogicAlertRegistration.pluginVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='coinlib.LogicAlertRegistration.workspaceId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.LogicAlertRegistration.code_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.LogicAlertRegistration.code', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.LogicAlertRegistration.workerId', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13503,
  serialized_end=13763,
)


_LOGICADVISORREGISTRATION = _descriptor.Descriptor(
  name='LogicAdvisorRegistration',
  full_name='coinlib.LogicAdvisorRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.LogicAdvisorRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='coinlib.LogicAdvisorRegistration.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.LogicAdvisorRegistration.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.LogicAdvisorRegistration.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modules', full_name='coinlib.LogicAdvisorRegistration.modules', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.LogicAdvisorRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.LogicAdvisorRegistration.plugin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.LogicAdvisorRegistration.pluginVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='coinlib.LogicAdvisorRegistration.workspaceId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.LogicAdvisorRegistration.code_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.LogicAdvisorRegistration.code', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.LogicAdvisorRegistration.workerId', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13766,
  serialized_end=14028,
)


_LOGICSCREENERREGISTRATION = _descriptor.Descriptor(
  name='LogicScreenerRegistration',
  full_name='coinlib.LogicScreenerRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.LogicScreenerRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='coinlib.LogicScreenerRegistration.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.LogicScreenerRegistration.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.LogicScreenerRegistration.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modules', full_name='coinlib.LogicScreenerRegistration.modules', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.LogicScreenerRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.LogicScreenerRegistration.plugin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.LogicScreenerRegistration.pluginVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='coinlib.LogicScreenerRegistration.workspaceId', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.LogicScreenerRegistration.code_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.LogicScreenerRegistration.code', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.LogicScreenerRegistration.workerId', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14031,
  serialized_end=14294,
)


_WORKSPACELOGICREGISTRATION = _descriptor.Descriptor(
  name='WorkspaceLogicRegistration',
  full_name='coinlib.WorkspaceLogicRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.WorkspaceLogicRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logicComponentId', full_name='coinlib.WorkspaceLogicRegistration.logicComponentId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='coinlib.WorkspaceLogicRegistration.params', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.WorkspaceLogicRegistration.stage', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.WorkspaceLogicRegistration.plugin', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.WorkspaceLogicRegistration.pluginVersion', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workspaceId', full_name='coinlib.WorkspaceLogicRegistration.workspaceId', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.WorkspaceLogicRegistration.type', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.WorkspaceLogicRegistration.code_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.WorkspaceLogicRegistration.code', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workerId', full_name='coinlib.WorkspaceLogicRegistration.workerId', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14297,
  serialized_end=14527,
)


_SYMBOLBROKEROPTIONS = _descriptor.Descriptor(
  name='SymbolBrokerOptions',
  full_name='coinlib.SymbolBrokerOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.SymbolBrokerOptions.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.SymbolBrokerOptions.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='coinlib.SymbolBrokerOptions.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultValue', full_name='coinlib.SymbolBrokerOptions.defaultValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14529,
  serialized_end=14621,
)


_SYMBOLBROKERREGISTRATION = _descriptor.Descriptor(
  name='SymbolBrokerRegistration',
  full_name='coinlib.SymbolBrokerRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.SymbolBrokerRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.SymbolBrokerRegistration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iconUrl', full_name='coinlib.SymbolBrokerRegistration.iconUrl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.SymbolBrokerRegistration.options', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='coinlib.SymbolBrokerRegistration.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.SymbolBrokerRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.SymbolBrokerRegistration.plugin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.SymbolBrokerRegistration.pluginVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.SymbolBrokerRegistration.code_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.SymbolBrokerRegistration.code', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14624,
  serialized_end=14852,
)


_BROKEROPTIONS = _descriptor.Descriptor(
  name='BrokerOptions',
  full_name='coinlib.BrokerOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.BrokerOptions.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.BrokerOptions.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='coinlib.BrokerOptions.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultValue', full_name='coinlib.BrokerOptions.defaultValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14854,
  serialized_end=14940,
)


_BROKEREXCHANGE = _descriptor.Descriptor(
  name='BrokerExchange',
  full_name='coinlib.BrokerExchange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='coinlib.BrokerExchange.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.BrokerExchange.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='coinlib.BrokerExchange.icon', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loginMode', full_name='coinlib.BrokerExchange.loginMode', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractTypes', full_name='coinlib.BrokerExchange.contractTypes', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetTypes', full_name='coinlib.BrokerExchange.assetTypes', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.BrokerExchange.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supportDemo', full_name='coinlib.BrokerExchange.supportDemo', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supportLive', full_name='coinlib.BrokerExchange.supportLive', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='positionModeFuture', full_name='coinlib.BrokerExchange.positionModeFuture', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BROKEREXCHANGE_LOGINMODE,
    _BROKEREXCHANGE_CONTRACTTYPE,
    _BROKEREXCHANGE_ASSETTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14943,
  serialized_end=15417,
)


_BROKERREGISTRATION = _descriptor.Descriptor(
  name='BrokerRegistration',
  full_name='coinlib.BrokerRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.BrokerRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.BrokerRegistration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iconUrl', full_name='coinlib.BrokerRegistration.iconUrl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.BrokerRegistration.options', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='coinlib.BrokerRegistration.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.BrokerRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.BrokerRegistration.plugin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.BrokerRegistration.pluginVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.BrokerRegistration.code_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.BrokerRegistration.code', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchanges', full_name='coinlib.BrokerRegistration.exchanges', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerTypes', full_name='coinlib.BrokerRegistration.brokerTypes', index=11,
      number=12, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BROKERREGISTRATION_SUPPORTEDBROKERTYPES,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15420,
  serialized_end=15844,
)


_BROKERPORTFOLIO = _descriptor.Descriptor(
  name='BrokerPortfolio',
  full_name='coinlib.BrokerPortfolio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset', full_name='coinlib.BrokerPortfolio.asset', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15846,
  serialized_end=15909,
)


_BROKERPORTFOLIOASSET = _descriptor.Descriptor(
  name='BrokerPortfolioAsset',
  full_name='coinlib.BrokerPortfolioAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='coinlib.BrokerPortfolioAsset.base', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available', full_name='coinlib.BrokerPortfolioAsset.available', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locked', full_name='coinlib.BrokerPortfolioAsset.locked', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastPrice', full_name='coinlib.BrokerPortfolioAsset.lastPrice', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15911,
  serialized_end=16001,
)


_BROKERSESSIONACCOUNTINFO = _descriptor.Descriptor(
  name='BrokerSessionAccountInfo',
  full_name='coinlib.BrokerSessionAccountInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='coinlib.BrokerSessionAccountInfo.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractType', full_name='coinlib.BrokerSessionAccountInfo.contractType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assetType', full_name='coinlib.BrokerSessionAccountInfo.assetType', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loginInfo', full_name='coinlib.BrokerSessionAccountInfo.loginInfo', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sandbox', full_name='coinlib.BrokerSessionAccountInfo.sandbox', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BROKERSESSIONACCOUNTINFO_CONTRACTTYPE,
    _BROKERSESSIONACCOUNTINFO_ASSETTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16004,
  serialized_end=16392,
)


_BROKERINFOSTARTSESSIONCONFIG = _descriptor.Descriptor(
  name='BrokerInfoStartSessionConfig',
  full_name='coinlib.BrokerInfoStartSessionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.BrokerInfoStartSessionConfig.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerIdentifier', full_name='coinlib.BrokerInfoStartSessionConfig.brokerIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountInfo', full_name='coinlib.BrokerInfoStartSessionConfig.accountInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortSessionId', full_name='coinlib.BrokerInfoStartSessionConfig.shortSessionId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16395,
  serialized_end=16550,
)


_BROKERINFOTESTCONFIG = _descriptor.Descriptor(
  name='BrokerInfoTestConfig',
  full_name='coinlib.BrokerInfoTestConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.BrokerInfoTestConfig.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerIdentifier', full_name='coinlib.BrokerInfoTestConfig.brokerIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accountInfo', full_name='coinlib.BrokerInfoTestConfig.accountInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortSessionId', full_name='coinlib.BrokerInfoTestConfig.shortSessionId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portfolio', full_name='coinlib.BrokerInfoTestConfig.portfolio', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerAccount', full_name='coinlib.BrokerInfoTestConfig.brokerAccount', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16553,
  serialized_end=16797,
)


_BROKERWORKERCONFIG = _descriptor.Descriptor(
  name='BrokerWorkerConfig',
  full_name='coinlib.BrokerWorkerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='startSessionConfig', full_name='coinlib.BrokerWorkerConfig.startSessionConfig', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='test_oneof', full_name='coinlib.BrokerWorkerConfig.test_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=16799,
  serialized_end=16902,
)


_BROKERSTOPCONSUMERLISTENER = _descriptor.Descriptor(
  name='BrokerStopConsumerListener',
  full_name='coinlib.BrokerStopConsumerListener',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.BrokerStopConsumerListener.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16904,
  serialized_end=16968,
)


_BROKERSTOPCONSUMERCOMMAND = _descriptor.Descriptor(
  name='BrokerStopConsumerCommand',
  full_name='coinlib.BrokerStopConsumerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stopped', full_name='coinlib.BrokerStopConsumerCommand.stopped', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16970,
  serialized_end=17014,
)


_BROKERSTARTSESSIONINFO = _descriptor.Descriptor(
  name='BrokerStartSessionInfo',
  full_name='coinlib.BrokerStartSessionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17016,
  serialized_end=17040,
)


_BROKERERROR = _descriptor.Descriptor(
  name='BrokerError',
  full_name='coinlib.BrokerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.BrokerError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.BrokerError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17042,
  serialized_end=17126,
)


_BROKERCOMMANDS = _descriptor.Descriptor(
  name='BrokerCommands',
  full_name='coinlib.BrokerCommands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.BrokerCommands.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.BrokerCommands.commandId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerCommand', full_name='coinlib.BrokerCommands.brokerCommand', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerCommandParams', full_name='coinlib.BrokerCommands.brokerCommandParams', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17128,
  serialized_end=17234,
)


_BROKERSESSIONREGISTRATION = _descriptor.Descriptor(
  name='BrokerSessionRegistration',
  full_name='coinlib.BrokerSessionRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.BrokerSessionRegistration.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17236,
  serialized_end=17282,
)


_BROKERCOMMANDSANSWER = _descriptor.Descriptor(
  name='BrokerCommandsAnswer',
  full_name='coinlib.BrokerCommandsAnswer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.BrokerCommandsAnswer.commandId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answerData', full_name='coinlib.BrokerCommandsAnswer.answerData', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.BrokerCommandsAnswer.sessionId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17284,
  serialized_end=17364,
)


_BROKERCOMMANDSANSWERERROR = _descriptor.Descriptor(
  name='BrokerCommandsAnswerError',
  full_name='coinlib.BrokerCommandsAnswerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.BrokerCommandsAnswerError.commandId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answerData', full_name='coinlib.BrokerCommandsAnswerError.answerData', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.BrokerCommandsAnswerError.sessionId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.BrokerCommandsAnswerError.error', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17366,
  serialized_end=17466,
)


_BROKEREVENTDATA = _descriptor.Descriptor(
  name='BrokerEventData',
  full_name='coinlib.BrokerEventData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='coinlib.BrokerEventData.event', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='coinlib.BrokerEventData.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.BrokerEventData.sessionId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.BrokerEventData.worker', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17468,
  serialized_end=17569,
)


_BROKERCOMMANDREGISTRATION = _descriptor.Descriptor(
  name='BrokerCommandRegistration',
  full_name='coinlib.BrokerCommandRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.BrokerCommandRegistration.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17571,
  serialized_end=17617,
)


_BROKERTESTPROTOCOLDATA = _descriptor.Descriptor(
  name='BrokerTestProtocolData',
  full_name='coinlib.BrokerTestProtocolData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.BrokerTestProtocolData.worker', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='coinlib.BrokerTestProtocolData.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17619,
  serialized_end=17693,
)


_APPWORKERCONFIG = _descriptor.Descriptor(
  name='AppWorkerConfig',
  full_name='coinlib.AppWorkerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='startSessionConfig', full_name='coinlib.AppWorkerConfig.startSessionConfig', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testConfig', full_name='coinlib.AppWorkerConfig.testConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='test_oneof', full_name='coinlib.AppWorkerConfig.test_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=17696,
  serialized_end=17852,
)


_APPWORKERINFOSTARTSESSIONCONFIG = _descriptor.Descriptor(
  name='AppWorkerInfoStartSessionConfig',
  full_name='coinlib.AppWorkerInfoStartSessionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerInfoStartSessionConfig.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortSessionId', full_name='coinlib.AppWorkerInfoStartSessionConfig.shortSessionId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logicInfo', full_name='coinlib.AppWorkerInfoStartSessionConfig.logicInfo', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerConfig', full_name='coinlib.AppWorkerInfoStartSessionConfig.brokerConfig', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portfolio', full_name='coinlib.AppWorkerInfoStartSessionConfig.portfolio', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.AppWorkerInfoStartSessionConfig.code', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codeType', full_name='coinlib.AppWorkerInfoStartSessionConfig.codeType', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codeId', full_name='coinlib.AppWorkerInfoStartSessionConfig.codeId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codeVersion', full_name='coinlib.AppWorkerInfoStartSessionConfig.codeVersion', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17855,
  serialized_end=18152,
)


_APPWORKERCOMMANDREGISTRATION = _descriptor.Descriptor(
  name='AppWorkerCommandRegistration',
  full_name='coinlib.AppWorkerCommandRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerCommandRegistration.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18154,
  serialized_end=18203,
)


_APPWORKERERROR = _descriptor.Descriptor(
  name='AppWorkerError',
  full_name='coinlib.AppWorkerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.AppWorkerError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.AppWorkerError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18205,
  serialized_end=18292,
)


_APPWORKERCOMMANDS = _descriptor.Descriptor(
  name='AppWorkerCommands',
  full_name='coinlib.AppWorkerCommands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerCommands.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.AppWorkerCommands.commandId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='coinlib.AppWorkerCommands.command', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commandParams', full_name='coinlib.AppWorkerCommands.commandParams', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='coinlib.AppWorkerCommands.target', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18294,
  serialized_end=18407,
)


_APPWORKERSESSIONREGISTRATION = _descriptor.Descriptor(
  name='AppWorkerSessionRegistration',
  full_name='coinlib.AppWorkerSessionRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerSessionRegistration.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.AppWorkerSessionRegistration.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18409,
  serialized_end=18494,
)


_APPWORKERCOMMANDSANSWER = _descriptor.Descriptor(
  name='AppWorkerCommandsAnswer',
  full_name='coinlib.AppWorkerCommandsAnswer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.AppWorkerCommandsAnswer.commandId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answerData', full_name='coinlib.AppWorkerCommandsAnswer.answerData', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerCommandsAnswer.sessionId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18496,
  serialized_end=18579,
)


_APPWORKERCOMMANDSANSWERERROR = _descriptor.Descriptor(
  name='AppWorkerCommandsAnswerError',
  full_name='coinlib.AppWorkerCommandsAnswerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.AppWorkerCommandsAnswerError.commandId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answerData', full_name='coinlib.AppWorkerCommandsAnswerError.answerData', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerCommandsAnswerError.sessionId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.AppWorkerCommandsAnswerError.error', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18581,
  serialized_end=18684,
)


_APPWORKEREVENTDATA = _descriptor.Descriptor(
  name='AppWorkerEventData',
  full_name='coinlib.AppWorkerEventData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='coinlib.AppWorkerEventData.event', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='coinlib.AppWorkerEventData.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerEventData.sessionId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.AppWorkerEventData.worker', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18686,
  serialized_end=18790,
)


_APPWORKERBROKERCOMMAND = _descriptor.Descriptor(
  name='AppWorkerBrokerCommand',
  full_name='coinlib.AppWorkerBrokerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerBrokerCommand.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.AppWorkerBrokerCommand.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='coinlib.AppWorkerBrokerCommand.command', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='coinlib.AppWorkerBrokerCommand.params', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.AppWorkerBrokerCommand.commandId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18793,
  serialized_end=18924,
)


_APPWORKERBROKERCOMMANDANSWER = _descriptor.Descriptor(
  name='AppWorkerBrokerCommandAnswer',
  full_name='coinlib.AppWorkerBrokerCommandAnswer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerBrokerCommandAnswer.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.AppWorkerBrokerCommandAnswer.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.AppWorkerBrokerCommandAnswer.commandId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='coinlib.AppWorkerBrokerCommandAnswer.response', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='coinlib.AppWorkerBrokerCommandAnswer.errorMessage', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.AppWorkerBrokerCommandAnswer.error', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18927,
  serialized_end=19086,
)


_APPWORKERMODULECOMMAND = _descriptor.Descriptor(
  name='AppWorkerModuleCommand',
  full_name='coinlib.AppWorkerModuleCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerModuleCommand.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.AppWorkerModuleCommand.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module', full_name='coinlib.AppWorkerModuleCommand.module', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='coinlib.AppWorkerModuleCommand.command', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='coinlib.AppWorkerModuleCommand.params', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.AppWorkerModuleCommand.commandId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19089,
  serialized_end=19236,
)


_APPWORKERMODULECOMMANDANSWER = _descriptor.Descriptor(
  name='AppWorkerModuleCommandAnswer',
  full_name='coinlib.AppWorkerModuleCommandAnswer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerModuleCommandAnswer.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.AppWorkerModuleCommandAnswer.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='module', full_name='coinlib.AppWorkerModuleCommandAnswer.module', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='coinlib.AppWorkerModuleCommandAnswer.command', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='coinlib.AppWorkerModuleCommandAnswer.params', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.AppWorkerModuleCommandAnswer.commandId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='coinlib.AppWorkerModuleCommandAnswer.errorMessage', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.AppWorkerModuleCommandAnswer.error', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response', full_name='coinlib.AppWorkerModuleCommandAnswer.response', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19239,
  serialized_end=19447,
)


_APPWORKERFINISHEDSTEPINFOS = _descriptor.Descriptor(
  name='AppWorkerFinishedStepInfos',
  full_name='coinlib.AppWorkerFinishedStepInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.AppWorkerFinishedStepInfos.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.AppWorkerFinishedStepInfos.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signalData', full_name='coinlib.AppWorkerFinishedStepInfos.signalData', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19449,
  serialized_end=19552,
)


_FEATUREINFOSTARTSESSIONCONFIG = _descriptor.Descriptor(
  name='FeatureInfoStartSessionConfig',
  full_name='coinlib.FeatureInfoStartSessionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.FeatureInfoStartSessionConfig.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.FeatureInfoStartSessionConfig.identifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optionValues', full_name='coinlib.FeatureInfoStartSessionConfig.optionValues', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shortSessionId', full_name='coinlib.FeatureInfoStartSessionConfig.shortSessionId', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetDatabaseServer', full_name='coinlib.FeatureInfoStartSessionConfig.targetDatabaseServer', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetDatabaseID', full_name='coinlib.FeatureInfoStartSessionConfig.targetDatabaseID', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionData', full_name='coinlib.FeatureInfoStartSessionConfig.sessionData', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rabbitServer', full_name='coinlib.FeatureInfoStartSessionConfig.rabbitServer', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rabbitUser', full_name='coinlib.FeatureInfoStartSessionConfig.rabbitUser', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rabbitPwd', full_name='coinlib.FeatureInfoStartSessionConfig.rabbitPwd', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rabbitPort', full_name='coinlib.FeatureInfoStartSessionConfig.rabbitPort', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rabbitQueuePrefix', full_name='coinlib.FeatureInfoStartSessionConfig.rabbitQueuePrefix', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19555,
  serialized_end=19856,
)


_FEATUREWORKERCONFIG = _descriptor.Descriptor(
  name='FeatureWorkerConfig',
  full_name='coinlib.FeatureWorkerConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='startSessionConfig', full_name='coinlib.FeatureWorkerConfig.startSessionConfig', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='test_oneof', full_name='coinlib.FeatureWorkerConfig.test_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=19858,
  serialized_end=19963,
)


_FEATUREERROR = _descriptor.Descriptor(
  name='FeatureError',
  full_name='coinlib.FeatureError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.FeatureError.error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.FeatureError.worker', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19965,
  serialized_end=20050,
)


_FEATURECOMMANDS = _descriptor.Descriptor(
  name='FeatureCommands',
  full_name='coinlib.FeatureCommands',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.FeatureCommands.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.FeatureCommands.commandId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='coinlib.FeatureCommands.command', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commandParams', full_name='coinlib.FeatureCommands.commandParams', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20052,
  serialized_end=20147,
)


_FEATURECOMMANDSANSWER = _descriptor.Descriptor(
  name='FeatureCommandsAnswer',
  full_name='coinlib.FeatureCommandsAnswer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.FeatureCommandsAnswer.commandId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answerData', full_name='coinlib.FeatureCommandsAnswer.answerData', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.FeatureCommandsAnswer.sessionId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20149,
  serialized_end=20230,
)


_FEATURECOMMANDSANSWERERROR = _descriptor.Descriptor(
  name='FeatureCommandsAnswerError',
  full_name='coinlib.FeatureCommandsAnswerError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commandId', full_name='coinlib.FeatureCommandsAnswerError.commandId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='answerData', full_name='coinlib.FeatureCommandsAnswerError.answerData', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.FeatureCommandsAnswerError.sessionId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='coinlib.FeatureCommandsAnswerError.error', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20232,
  serialized_end=20333,
)


_FEATURESESSIONREGISTRATION = _descriptor.Descriptor(
  name='FeatureSessionRegistration',
  full_name='coinlib.FeatureSessionRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.FeatureSessionRegistration.sessionId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20335,
  serialized_end=20382,
)


_FEATUREEVENTDATA = _descriptor.Descriptor(
  name='FeatureEventData',
  full_name='coinlib.FeatureEventData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='coinlib.FeatureEventData.event', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='coinlib.FeatureEventData.data', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionId', full_name='coinlib.FeatureEventData.sessionId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker', full_name='coinlib.FeatureEventData.worker', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20384,
  serialized_end=20486,
)


_REGISTRATIONINFORMATION = _descriptor.Descriptor(
  name='RegistrationInformation',
  full_name='coinlib.RegistrationInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='duplicated', full_name='coinlib.RegistrationInformation.duplicated', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='success', full_name='coinlib.RegistrationInformation.success', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20488,
  serialized_end=20550,
)


_SYMBOLDATAREQUESTINFO = _descriptor.Descriptor(
  name='SymbolDataRequestInfo',
  full_name='coinlib.SymbolDataRequestInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange', full_name='coinlib.SymbolDataRequestInfo.exchange', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additionalDataFeatures', full_name='coinlib.SymbolDataRequestInfo.additionalDataFeatures', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20552,
  serialized_end=20625,
)


_SYMBOLDATARESPONSE = _descriptor.Descriptor(
  name='SymbolDataResponse',
  full_name='coinlib.SymbolDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbols', full_name='coinlib.SymbolDataResponse.symbols', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20627,
  serialized_end=20698,
)


_EXCHANGEDATAREQUESTINFO = _descriptor.Descriptor(
  name='ExchangeDataRequestInfo',
  full_name='coinlib.ExchangeDataRequestInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20700,
  serialized_end=20725,
)


_BROKEREXCHANGESMALL = _descriptor.Descriptor(
  name='BrokerExchangeSmall',
  full_name='coinlib.BrokerExchangeSmall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='coinlib.BrokerExchangeSmall.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.BrokerExchangeSmall.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.BrokerExchangeSmall.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='coinlib.BrokerExchangeSmall.mode', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20727,
  serialized_end=20803,
)


_EXCHANGEDATARESPONSE = _descriptor.Descriptor(
  name='ExchangeDataResponse',
  full_name='coinlib.ExchangeDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchanges', full_name='coinlib.ExchangeDataResponse.exchanges', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20805,
  serialized_end=20876,
)


_SYMBOLBROKERSYMBOLSMALL = _descriptor.Descriptor(
  name='SymbolBrokerSymbolSmall',
  full_name='coinlib.SymbolBrokerSymbolSmall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exchange_id', full_name='coinlib.SymbolBrokerSymbolSmall.exchange_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='coinlib.SymbolBrokerSymbolSmall.symbol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol_id', full_name='coinlib.SymbolBrokerSymbolSmall.symbol_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_id', full_name='coinlib.SymbolBrokerSymbolSmall.account_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='coinlib.SymbolBrokerSymbolSmall.base', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote', full_name='coinlib.SymbolBrokerSymbolSmall.quote', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pricePrecision', full_name='coinlib.SymbolBrokerSymbolSmall.pricePrecision', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractType', full_name='coinlib.SymbolBrokerSymbolSmall.contractType', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.SymbolBrokerSymbolSmall.name', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20879,
  serialized_end=21069,
)


_MARKETDATAREQUEST = _descriptor.Descriptor(
  name='MarketDataRequest',
  full_name='coinlib.MarketDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symbol', full_name='coinlib.MarketDataRequest.symbol', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startDate', full_name='coinlib.MarketDataRequest.startDate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endDate', full_name='coinlib.MarketDataRequest.endDate', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeframe', full_name='coinlib.MarketDataRequest.timeframe', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contractType', full_name='coinlib.MarketDataRequest.contractType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='additionalDataFeatures', full_name='coinlib.MarketDataRequest.additionalDataFeatures', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21072,
  serialized_end=21250,
)


_MARKETDATARESPONSE = _descriptor.Descriptor(
  name='MarketDataResponse',
  full_name='coinlib.MarketDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_server', full_name='coinlib.MarketDataResponse.data_server', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='database_id', full_name='coinlib.MarketDataResponse.database_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chart_id', full_name='coinlib.MarketDataResponse.chart_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21252,
  serialized_end=21332,
)


_FEATUREDATARESPONSE = _descriptor.Descriptor(
  name='FeatureDataResponse',
  full_name='coinlib.FeatureDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_data', full_name='coinlib.FeatureDataResponse.feature_data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21334,
  serialized_end=21377,
)


_FEATUREDATAREQUEST = _descriptor.Descriptor(
  name='FeatureDataRequest',
  full_name='coinlib.FeatureDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_name', full_name='coinlib.FeatureDataRequest.feature_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from', full_name='coinlib.FeatureDataRequest.from', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='coinlib.FeatureDataRequest.to', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_symbol', full_name='coinlib.FeatureDataRequest.target_symbol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21379,
  serialized_end=21470,
)


_ADDITIONALDATAFEATUREREQUEST = _descriptor.Descriptor(
  name='AdditionalDataFeatureRequest',
  full_name='coinlib.AdditionalDataFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21472,
  serialized_end=21502,
)


_ADDITIONALDATAFEATUREINFO = _descriptor.Descriptor(
  name='AdditionalDataFeatureInfo',
  full_name='coinlib.AdditionalDataFeatureInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='coinlib.AdditionalDataFeatureInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.AdditionalDataFeatureInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.AdditionalDataFeatureInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='coinlib.AdditionalDataFeatureInfo.exchange', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='coinlib.AdditionalDataFeatureInfo.group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.AdditionalDataFeatureInfo.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21504,
  serialized_end=21625,
)


_ADDITIONALDATAFEATURERESPONSE = _descriptor.Descriptor(
  name='AdditionalDataFeatureResponse',
  full_name='coinlib.AdditionalDataFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='featureInfos', full_name='coinlib.AdditionalDataFeatureResponse.featureInfos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21627,
  serialized_end=21716,
)


_NOTIFICATIONOPTIONS = _descriptor.Descriptor(
  name='NotificationOptions',
  full_name='coinlib.NotificationOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.NotificationOptions.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.NotificationOptions.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='coinlib.NotificationOptions.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultValue', full_name='coinlib.NotificationOptions.defaultValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21718,
  serialized_end=21810,
)


_NOTIFICATIONREGISTRATION = _descriptor.Descriptor(
  name='NotificationRegistration',
  full_name='coinlib.NotificationRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.NotificationRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.NotificationRegistration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iconUrl', full_name='coinlib.NotificationRegistration.iconUrl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.NotificationRegistration.inputs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='coinlib.NotificationRegistration.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.NotificationRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.NotificationRegistration.plugin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.NotificationRegistration.pluginVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.NotificationRegistration.code_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.NotificationRegistration.code', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.NotificationRegistration.description', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isInteractive', full_name='coinlib.NotificationRegistration.isInteractive', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21813,
  serialized_end=22084,
)


_FEATUREOPTIONS = _descriptor.Descriptor(
  name='FeatureOptions',
  full_name='coinlib.FeatureOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.FeatureOptions.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.FeatureOptions.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='coinlib.FeatureOptions.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultValue', full_name='coinlib.FeatureOptions.defaultValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22086,
  serialized_end=22173,
)


_FEATUREREGISTRATION = _descriptor.Descriptor(
  name='FeatureRegistration',
  full_name='coinlib.FeatureRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.FeatureRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.FeatureRegistration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iconUrl', full_name='coinlib.FeatureRegistration.iconUrl', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='coinlib.FeatureRegistration.options', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='coinlib.FeatureRegistration.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.FeatureRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.FeatureRegistration.plugin', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.FeatureRegistration.pluginVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.FeatureRegistration.code_type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.FeatureRegistration.code', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.FeatureRegistration.type', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.FeatureRegistration.description', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_infos', full_name='coinlib.FeatureRegistration.feature_infos', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estimatedDataInterval', full_name='coinlib.FeatureRegistration.estimatedDataInterval', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22176,
  serialized_end=22483,
)


_SIMULATORMETHODCALL = _descriptor.Descriptor(
  name='SimulatorMethodCall',
  full_name='coinlib.SimulatorMethodCall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='coinlib.SimulatorMethodCall.method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='coinlib.SimulatorMethodCall.params', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22485,
  serialized_end=22538,
)


_STATISTICFUNCTIONINPUTS = _descriptor.Descriptor(
  name='StatisticFunctionInputs',
  full_name='coinlib.StatisticFunctionInputs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.StatisticFunctionInputs.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='coinlib.StatisticFunctionInputs.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.StatisticFunctionInputs.identifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultValue', full_name='coinlib.StatisticFunctionInputs.defaultValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22540,
  serialized_end=22636,
)


_STATISTICMETHODINPUTS = _descriptor.Descriptor(
  name='StatisticMethodInputs',
  full_name='coinlib.StatisticMethodInputs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='coinlib.StatisticMethodInputs.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='coinlib.StatisticMethodInputs.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.StatisticMethodInputs.identifier', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultValue', full_name='coinlib.StatisticMethodInputs.defaultValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='coinlib.StatisticMethodInputs.values', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22638,
  serialized_end=22748,
)


_STATISTICMETHODREGISTRATION = _descriptor.Descriptor(
  name='StatisticMethodRegistration',
  full_name='coinlib.StatisticMethodRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.StatisticMethodRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.StatisticMethodRegistration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='refreshOn', full_name='coinlib.StatisticMethodRegistration.refreshOn', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.StatisticMethodRegistration.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='coinlib.StatisticMethodRegistration.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.StatisticMethodRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPositionLayout', full_name='coinlib.StatisticMethodRegistration.targetPositionLayout', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.StatisticMethodRegistration.inputs', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.StatisticMethodRegistration.plugin', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.StatisticMethodRegistration.pluginVersion', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.StatisticMethodRegistration.code_type', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.StatisticMethodRegistration.code', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22751,
  serialized_end=23036,
)


_STATISTICRULEFUNCTIONREGISTRATION = _descriptor.Descriptor(
  name='StatisticRuleFunctionRegistration',
  full_name='coinlib.StatisticRuleFunctionRegistration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='coinlib.StatisticRuleFunctionRegistration.identifier', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='coinlib.StatisticRuleFunctionRegistration.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='coinlib.StatisticRuleFunctionRegistration.group', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='coinlib.StatisticRuleFunctionRegistration.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='coinlib.StatisticRuleFunctionRegistration.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='coinlib.StatisticRuleFunctionRegistration.stage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='coinlib.StatisticRuleFunctionRegistration.inputs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plugin', full_name='coinlib.StatisticRuleFunctionRegistration.plugin', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pluginVersion', full_name='coinlib.StatisticRuleFunctionRegistration.pluginVersion', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_type', full_name='coinlib.StatisticRuleFunctionRegistration.code_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='coinlib.StatisticRuleFunctionRegistration.code', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23039,
  serialized_end=23298,
)


_WORKERREGISTRYREQUEST = _descriptor.Descriptor(
  name='WorkerRegistryRequest',
  full_name='coinlib.WorkerRegistryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='coinlib.WorkerRegistryRequest.worker_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activeModules', full_name='coinlib.WorkerRegistryRequest.activeModules', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23300,
  serialized_end=23365,
)


_WORKERREGISTRYRESPONSE = _descriptor.Descriptor(
  name='WorkerRegistryResponse',
  full_name='coinlib.WorkerRegistryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetendpoint', full_name='coinlib.WorkerRegistryResponse.targetendpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetport', full_name='coinlib.WorkerRegistryResponse.targetport', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23367,
  serialized_end=23435,
)

_WORKER.fields_by_name['availablePlugins'].message_type = _WORKERAVAILABLEPLUGINS
_WORKERJOBDATARESPONSE.fields_by_name['worker'].message_type = _WORKERJOB
_CHARTSWORKERPARTIALDATALAYOUT.fields_by_name['worker'].message_type = _WORKERJOB
_CHARTSWORKERPARTIALDATALAYOUT.fields_by_name['indicator'].message_type = _CHARTWORKERINDICATOR
_CHARTSWORKERPARTIALDATALAYOUT.fields_by_name['chartInfo'].message_type = _CHARTWORKERPARTIALDATAINFO
_CHARTWORKERINDICATORCONFIGELEMENT.fields_by_name['indicator'].message_type = _CHARTWORKERINDICATOR
_CHARTSWORKERCONFIG.fields_by_name['elements'].message_type = _CHARTWORKERINDICATORCONFIGELEMENT
_CHARTSWORKERCONFIG.fields_by_name['children'].message_type = _CHARTSWORKERCONFIG
_CHARTSWORKERCONFIG.fields_by_name['chartData'].message_type = _CHARTDATAINFO
_INDICATORERROR.fields_by_name['error'].message_type = _DATAERROR
_INDICATORERROR.fields_by_name['worker'].message_type = _WORKERJOB
_INDICATORERROR.fields_by_name['indicator'].message_type = _CHARTWORKERINDICATOR
_STATISTICRULEFUNCTIONERROR.fields_by_name['error'].message_type = _DATAERROR
_STATISTICRULEFUNCTIONERROR.fields_by_name['worker'].message_type = _WORKERJOB
_STATISTICRULEFUNCTIONERROR.fields_by_name['statisticFunction'].message_type = _STATISTICSRULEWORKERCONFIG
_STATISTICMETHODFUNCTIONERROR.fields_by_name['error'].message_type = _DATAERROR
_STATISTICMETHODFUNCTIONERROR.fields_by_name['worker'].message_type = _WORKERJOB
_STATISTICMETHODFUNCTIONERROR.fields_by_name['statisticFunction'].message_type = _STATISTICSRULEWORKERCONFIG
_STATISTICSMETHODWORKERWINDOWCONFIG.fields_by_name['chartData'].message_type = _CHARTDATAINFO
_STATISTICSMETHODWORKERWINDOWCONFIG.fields_by_name['parameterTable'].message_type = _PARAMETERTABLE
_PARAMETERTABLE.fields_by_name['parameters'].message_type = _PARAMETERTABLEENTRY
_STATISTICSRULEWORKERCONFIG_INPUTSENTRY.fields_by_name['value'].message_type = _STATISTICINPUT
_STATISTICSRULEWORKERCONFIG_INPUTSENTRY.containing_type = _STATISTICSRULEWORKERCONFIG
_STATISTICSRULEWORKERCONFIG.fields_by_name['rules'].message_type = _STATISTICSRULEWORKERCONFIG
_STATISTICSRULEWORKERCONFIG.fields_by_name['inputs'].message_type = _STATISTICSRULEWORKERCONFIG_INPUTSENTRY
_STATISTICSRULEWORKERCONFIG.fields_by_name['chartData'].message_type = _CHARTDATAINFO
_STATISTICSRULEWORKERCONFIGTYPE.fields_by_name['rule'].message_type = _STATISTICSRULEWORKERCONFIG
_STATISTICSRULEWORKERCONFIGTYPE.fields_by_name['methodWindow'].message_type = _STATISTICSMETHODWORKERWINDOWCONFIG
_STATISTICSRULEWORKERCONFIGTYPE.oneofs_by_name['test_oneof'].fields.append(
  _STATISTICSRULEWORKERCONFIGTYPE.fields_by_name['rule'])
_STATISTICSRULEWORKERCONFIGTYPE.fields_by_name['rule'].containing_oneof = _STATISTICSRULEWORKERCONFIGTYPE.oneofs_by_name['test_oneof']
_STATISTICSRULEWORKERCONFIGTYPE.oneofs_by_name['test_oneof'].fields.append(
  _STATISTICSRULEWORKERCONFIGTYPE.fields_by_name['methodWindow'])
_STATISTICSRULEWORKERCONFIGTYPE.fields_by_name['methodWindow'].containing_oneof = _STATISTICSRULEWORKERCONFIGTYPE.oneofs_by_name['test_oneof']
_STATISTICSBULKEDWORKERCONFIG.fields_by_name['configs'].message_type = _STATISTICSRULEWORKERCONFIGTYPE
_STATISTICSBULKEDWORKERCONFIG.fields_by_name['chartData'].message_type = _CHARTDATAINFO
_STATISTICSBULKEDWORKERCONFIG.fields_by_name['parameterTable'].message_type = _PARAMETERTABLE
_STATISTICFUNCTIONERROR.fields_by_name['error'].message_type = _DATAERROR
_STATISTICFUNCTIONERROR.fields_by_name['worker'].message_type = _WORKERJOB
_STATISTICFUNCTIONERROR.fields_by_name['statisticFunction'].message_type = _STATISTICSRULEWORKERCONFIG
_STATISTICMETHODPARTIALLYDATA.fields_by_name['worker'].message_type = _WORKERJOB
_STATISTICRULEPARTIALLYDATA.fields_by_name['worker'].message_type = _WORKERJOB
_STATISTICRULEPARTIALLYDATA.fields_by_name['statisticRule'].message_type = _STATISTICSRULEWORKERCONFIG
_STATISTICBULKEDPARTIALLYDATA.fields_by_name['methodData'].message_type = _STATISTICMETHODPARTIALLYDATA
_STATISTICBULKEDPARTIALLYDATA.fields_by_name['ruleData'].message_type = _STATISTICRULEPARTIALLYDATA
_STATISTICBULKEDPARTIALLYDATA.oneofs_by_name['test_oneof'].fields.append(
  _STATISTICBULKEDPARTIALLYDATA.fields_by_name['methodData'])
_STATISTICBULKEDPARTIALLYDATA.fields_by_name['methodData'].containing_oneof = _STATISTICBULKEDPARTIALLYDATA.oneofs_by_name['test_oneof']
_STATISTICBULKEDPARTIALLYDATA.oneofs_by_name['test_oneof'].fields.append(
  _STATISTICBULKEDPARTIALLYDATA.fields_by_name['ruleData'])
_STATISTICBULKEDPARTIALLYDATA.fields_by_name['ruleData'].containing_oneof = _STATISTICBULKEDPARTIALLYDATA.oneofs_by_name['test_oneof']
_SYMBOLBROKERERROR.fields_by_name['error'].message_type = _DATAERROR
_SYMBOLBROKERERROR.fields_by_name['worker'].message_type = _WORKERJOB
_SYMBOLBROKERMARKETDATA.fields_by_name['worker'].message_type = _WORKERJOB
_SYMBOLBROKERINFO.fields_by_name['worker'].message_type = _WORKERJOB
_SYMBOLBROKERINFO.fields_by_name['exchanges'].message_type = _SYMBOLBROKEREXCHANGE
_SYMBOLBROKERINFO.fields_by_name['symbols'].message_type = _SYMBOLBROKERSYMBOL
_SYMBOLBROKERORDERBOOK.fields_by_name['worker'].message_type = _WORKERJOB
_SYMBOLBROKERHISTORICALMARKETDATA.fields_by_name['worker'].message_type = _WORKERJOB
_SYMBOLBROKERSYMBOL.fields_by_name['assetType'].enum_type = _SYMBOLBROKERSYMBOL_ASSETTYPE
_SYMBOLBROKERSYMBOL.fields_by_name['contractType'].enum_type = _SYMBOLBROKERSYMBOL_CONTRACTTYPE
_SYMBOLBROKERSYMBOL_ASSETTYPE.containing_type = _SYMBOLBROKERSYMBOL
_SYMBOLBROKERSYMBOL_CONTRACTTYPE.containing_type = _SYMBOLBROKERSYMBOL
_SYMBOLBROKERCONSUMEMARKETDATACONFIG.fields_by_name['contractType'].enum_type = _SYMBOLBROKERCONSUMEMARKETDATACONFIG_CONTRACTTYPE
_SYMBOLBROKERCONSUMEMARKETDATACONFIG.fields_by_name['assetType'].enum_type = _SYMBOLBROKERCONSUMEMARKETDATACONFIG_ASSETTYPE
_SYMBOLBROKERCONSUMEMARKETDATACONFIG_ASSETTYPE.containing_type = _SYMBOLBROKERCONSUMEMARKETDATACONFIG
_SYMBOLBROKERCONSUMEMARKETDATACONFIG_CONTRACTTYPE.containing_type = _SYMBOLBROKERCONSUMEMARKETDATACONFIG
_SYMBOLBROKERCONSUMEORDERBOOKCONFIG.fields_by_name['contractType'].enum_type = _SYMBOLBROKERCONSUMEORDERBOOKCONFIG_CONTRACTTYPE
_SYMBOLBROKERCONSUMEORDERBOOKCONFIG.fields_by_name['assetType'].enum_type = _SYMBOLBROKERCONSUMEORDERBOOKCONFIG_ASSETTYPE
_SYMBOLBROKERCONSUMEORDERBOOKCONFIG_ASSETTYPE.containing_type = _SYMBOLBROKERCONSUMEORDERBOOKCONFIG
_SYMBOLBROKERCONSUMEORDERBOOKCONFIG_CONTRACTTYPE.containing_type = _SYMBOLBROKERCONSUMEORDERBOOKCONFIG
_SYMBOLBROKERGETHISTORICALDATACONFIG.fields_by_name['chartData'].message_type = _CHARTDATAINFO
_SYMBOLBROKERGETHISTORICALDATACONFIG.fields_by_name['contractType'].enum_type = _SYMBOLBROKERGETHISTORICALDATACONFIG_CONTRACTTYPE
_SYMBOLBROKERGETHISTORICALDATACONFIG.fields_by_name['assetType'].enum_type = _SYMBOLBROKERGETHISTORICALDATACONFIG_ASSETTYPE
_SYMBOLBROKERGETHISTORICALDATACONFIG_ASSETTYPE.containing_type = _SYMBOLBROKERGETHISTORICALDATACONFIG
_SYMBOLBROKERGETHISTORICALDATACONFIG_CONTRACTTYPE.containing_type = _SYMBOLBROKERGETHISTORICALDATACONFIG
_SYMBOLBROKERWORKERCONFIG.fields_by_name['infoConfig'].message_type = _SYMBOLBROKERBROKERINFOCONFIG
_SYMBOLBROKERWORKERCONFIG.fields_by_name['consumeConfig'].message_type = _SYMBOLBROKERCONSUMEMARKETDATACONFIG
_SYMBOLBROKERWORKERCONFIG.fields_by_name['consumeOrderbookConfig'].message_type = _SYMBOLBROKERCONSUMEORDERBOOKCONFIG
_SYMBOLBROKERWORKERCONFIG.fields_by_name['historicalConfig'].message_type = _SYMBOLBROKERGETHISTORICALDATACONFIG
_SYMBOLBROKERWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _SYMBOLBROKERWORKERCONFIG.fields_by_name['infoConfig'])
_SYMBOLBROKERWORKERCONFIG.fields_by_name['infoConfig'].containing_oneof = _SYMBOLBROKERWORKERCONFIG.oneofs_by_name['test_oneof']
_SYMBOLBROKERWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _SYMBOLBROKERWORKERCONFIG.fields_by_name['consumeConfig'])
_SYMBOLBROKERWORKERCONFIG.fields_by_name['consumeConfig'].containing_oneof = _SYMBOLBROKERWORKERCONFIG.oneofs_by_name['test_oneof']
_SYMBOLBROKERWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _SYMBOLBROKERWORKERCONFIG.fields_by_name['consumeOrderbookConfig'])
_SYMBOLBROKERWORKERCONFIG.fields_by_name['consumeOrderbookConfig'].containing_oneof = _SYMBOLBROKERWORKERCONFIG.oneofs_by_name['test_oneof']
_SYMBOLBROKERWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _SYMBOLBROKERWORKERCONFIG.fields_by_name['historicalConfig'])
_SYMBOLBROKERWORKERCONFIG.fields_by_name['historicalConfig'].containing_oneof = _SYMBOLBROKERWORKERCONFIG.oneofs_by_name['test_oneof']
_SYMBOLBROKERSTOPCONSUMERLISTENER.fields_by_name['worker'].message_type = _WORKERJOB
_NOTIFICATIONWORKERCONFIG.fields_by_name['sendMessageConfig'].message_type = _NOTIFICATIONSENDMESSAGEDATACONFIG
_NOTIFICATIONWORKERCONFIG.fields_by_name['extractDataConfig'].message_type = _NOTIFICATIONEXTRACTMESSAGEDATACONFIG
_NOTIFICATIONWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _NOTIFICATIONWORKERCONFIG.fields_by_name['sendMessageConfig'])
_NOTIFICATIONWORKERCONFIG.fields_by_name['sendMessageConfig'].containing_oneof = _NOTIFICATIONWORKERCONFIG.oneofs_by_name['test_oneof']
_NOTIFICATIONWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _NOTIFICATIONWORKERCONFIG.fields_by_name['extractDataConfig'])
_NOTIFICATIONWORKERCONFIG.fields_by_name['extractDataConfig'].containing_oneof = _NOTIFICATIONWORKERCONFIG.oneofs_by_name['test_oneof']
_NOTIFICATIONERROR.fields_by_name['error'].message_type = _DATAERROR
_NOTIFICATIONERROR.fields_by_name['worker'].message_type = _WORKERJOB
_NOTIFICATIONCALLBACKEXTRACT.fields_by_name['worker'].message_type = _WORKERJOB
_BROKERACCOUNTMODEL.fields_by_name['brokerType'].enum_type = _BROKERACCOUNTMODEL_BROKERTYPE
_BROKERACCOUNTMODEL.fields_by_name['mode'].enum_type = _BROKERACCOUNTMODEL_BROKERMODE
_BROKERACCOUNTMODEL.fields_by_name['makerFeeMode'].enum_type = _BROKERACCOUNTMODEL_FEEMODE
_BROKERACCOUNTMODEL.fields_by_name['takerFeeMode'].enum_type = _BROKERACCOUNTMODEL_FEEMODE
_BROKERACCOUNTMODEL_BROKERTYPE.containing_type = _BROKERACCOUNTMODEL
_BROKERACCOUNTMODEL_BROKERMODE.containing_type = _BROKERACCOUNTMODEL
_BROKERACCOUNTMODEL_FEEMODE.containing_type = _BROKERACCOUNTMODEL
_PORTFOLIOMODEL.fields_by_name['assets'].message_type = _PORTFOLIOASSET
_PORTFOLIOMODEL.fields_by_name['currentCalculatedBaseMoney'].message_type = _CALCULATEDBASEMONEY
_PORTFOLIOMODEL.fields_by_name['historicalCalculatedBaseMoney'].message_type = _CALCULATEDBASEMONEY
_LOGICRUNNERLOGIC.fields_by_name['chartData'].message_type = _CHARTDATAINFO
_LOGICRUNNERLOGIC.fields_by_name['logicComponents'].message_type = _LOGICCOMPONENT
_LOGICRUNNERLOGIC.fields_by_name['portfolio'].message_type = _PORTFOLIOMODEL
_LOGICRUNNERLOGIC.fields_by_name['brokerAccount'].message_type = _BROKERACCOUNTMODEL
_LOGICRUNNERLOGIC.fields_by_name['parameterTable'].message_type = _PARAMETERTABLE
_LOGICRUNNEROFFLINEWORKERCONFIG.fields_by_name['logicInfo'].message_type = _LOGICRUNNERLOGIC
_LOGICRUNNEROFFLINEWORKERCONFIG.fields_by_name['chartData'].message_type = _CHARTDATAINFO
_LOGICRUNNEROFFLINEWORKERCONFIG.fields_by_name['portfolio'].message_type = _BROKERPORTFOLIO
_LOGICRUNNERSTATISTICS.fields_by_name['calculatedMoney'].message_type = _CALCULATEDBASEMONEY
_LOGICRUNNEROFFLINEWORKERPARTIALLYDATA.fields_by_name['worker'].message_type = _WORKERJOB
_LOGICRUNNEROFFLINEWORKERPARTIALLYDATA.fields_by_name['statistic'].message_type = _LOGICRUNNERSTATISTICS
_LOGICRUNNEROFFLINEWORKERERROR.fields_by_name['error'].message_type = _DATAERROR
_LOGICRUNNEROFFLINEWORKERERROR.fields_by_name['worker'].message_type = _WORKERJOB
_LOGICRUNNEROFFLINEWORKERFINISHEDDATA.fields_by_name['error'].message_type = _DATAERROR
_LOGICRUNNEROFFLINEWORKERFINISHEDDATA.fields_by_name['worker'].message_type = _WORKERJOB
_LOGICRUNNEROFFLINEWORKERFINISHEDDATA.fields_by_name['statistic'].message_type = _LOGICRUNNERSTATISTICS
_WORKERPLUGININFORMATION.fields_by_name['plugin'].message_type = _PLUGINCONFIG
_PLUGININSTALLATIONOUTPUT.fields_by_name['worker'].message_type = _WORKERJOB
_SIMULATORCHARTCONFIGINDICATOR_INPUTSENTRY.containing_type = _SIMULATORCHARTCONFIGINDICATOR
_SIMULATORCHARTCONFIGINDICATOR.fields_by_name['inputs'].message_type = _SIMULATORCHARTCONFIGINDICATOR_INPUTSENTRY
_SIMULATORCHARTCONFIG.fields_by_name['indicators'].message_type = _SIMULATORCHARTCONFIGINDICATOR
_SIMULATORSTATISTICCHARTCONFIG.fields_by_name['indicators'].message_type = _SIMULATORCHARTCONFIGINDICATOR
_SIMULATORMETHODCALLCHARTCONFIG.fields_by_name['indicators'].message_type = _SIMULATORCHARTCONFIGINDICATOR
_SIMULATORMETHODCALLCHARTCONFIG.fields_by_name['methods'].message_type = _SIMULATORMETHODCALL
_BROKERSIMULATORBROKERDATA.fields_by_name['loginInfo'].message_type = _BROKERSIMULATORBROKERLOGINDATA
_BROKERSIMULATORREQUEST.fields_by_name['brokerInfo'].message_type = _BROKERSIMULATORBROKERDATA
_LOGICTRADERREGISTRATION.fields_by_name['inputs'].message_type = _LOGICINPUT
_LOGICALERTREGISTRATION.fields_by_name['inputs'].message_type = _LOGICINPUT
_LOGICADVISORREGISTRATION.fields_by_name['inputs'].message_type = _LOGICINPUT
_LOGICSCREENERREGISTRATION.fields_by_name['inputs'].message_type = _LOGICINPUT
_SYMBOLBROKERREGISTRATION.fields_by_name['options'].message_type = _SYMBOLBROKEROPTIONS
_BROKEREXCHANGE.fields_by_name['loginMode'].enum_type = _BROKEREXCHANGE_LOGINMODE
_BROKEREXCHANGE.fields_by_name['contractTypes'].enum_type = _BROKEREXCHANGE_CONTRACTTYPE
_BROKEREXCHANGE.fields_by_name['assetTypes'].enum_type = _BROKEREXCHANGE_ASSETTYPE
_BROKEREXCHANGE_LOGINMODE.containing_type = _BROKEREXCHANGE
_BROKEREXCHANGE_CONTRACTTYPE.containing_type = _BROKEREXCHANGE
_BROKEREXCHANGE_ASSETTYPE.containing_type = _BROKEREXCHANGE
_BROKERREGISTRATION.fields_by_name['options'].message_type = _BROKEROPTIONS
_BROKERREGISTRATION.fields_by_name['exchanges'].message_type = _BROKEREXCHANGE
_BROKERREGISTRATION.fields_by_name['brokerTypes'].enum_type = _BROKERREGISTRATION_SUPPORTEDBROKERTYPES
_BROKERREGISTRATION_SUPPORTEDBROKERTYPES.containing_type = _BROKERREGISTRATION
_BROKERPORTFOLIO.fields_by_name['asset'].message_type = _BROKERPORTFOLIOASSET
_BROKERSESSIONACCOUNTINFO.fields_by_name['contractType'].enum_type = _BROKERSESSIONACCOUNTINFO_CONTRACTTYPE
_BROKERSESSIONACCOUNTINFO.fields_by_name['assetType'].enum_type = _BROKERSESSIONACCOUNTINFO_ASSETTYPE
_BROKERSESSIONACCOUNTINFO.fields_by_name['loginInfo'].message_type = _BROKERSIMULATORBROKERLOGINDATA
_BROKERSESSIONACCOUNTINFO_CONTRACTTYPE.containing_type = _BROKERSESSIONACCOUNTINFO
_BROKERSESSIONACCOUNTINFO_ASSETTYPE.containing_type = _BROKERSESSIONACCOUNTINFO
_BROKERINFOSTARTSESSIONCONFIG.fields_by_name['accountInfo'].message_type = _BROKERSESSIONACCOUNTINFO
_BROKERINFOTESTCONFIG.fields_by_name['accountInfo'].message_type = _BROKERSESSIONACCOUNTINFO
_BROKERINFOTESTCONFIG.fields_by_name['portfolio'].message_type = _BROKERPORTFOLIO
_BROKERINFOTESTCONFIG.fields_by_name['brokerAccount'].message_type = _BROKERACCOUNTMODEL
_BROKERWORKERCONFIG.fields_by_name['startSessionConfig'].message_type = _BROKERINFOSTARTSESSIONCONFIG
_BROKERWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _BROKERWORKERCONFIG.fields_by_name['startSessionConfig'])
_BROKERWORKERCONFIG.fields_by_name['startSessionConfig'].containing_oneof = _BROKERWORKERCONFIG.oneofs_by_name['test_oneof']
_BROKERSTOPCONSUMERLISTENER.fields_by_name['worker'].message_type = _WORKERJOB
_BROKERERROR.fields_by_name['error'].message_type = _DATAERROR
_BROKERERROR.fields_by_name['worker'].message_type = _WORKERJOB
_BROKEREVENTDATA.fields_by_name['worker'].message_type = _WORKERJOB
_BROKERTESTPROTOCOLDATA.fields_by_name['worker'].message_type = _WORKERJOB
_APPWORKERCONFIG.fields_by_name['startSessionConfig'].message_type = _APPWORKERINFOSTARTSESSIONCONFIG
_APPWORKERCONFIG.fields_by_name['testConfig'].message_type = _BROKERINFOTESTCONFIG
_APPWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _APPWORKERCONFIG.fields_by_name['startSessionConfig'])
_APPWORKERCONFIG.fields_by_name['startSessionConfig'].containing_oneof = _APPWORKERCONFIG.oneofs_by_name['test_oneof']
_APPWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _APPWORKERCONFIG.fields_by_name['testConfig'])
_APPWORKERCONFIG.fields_by_name['testConfig'].containing_oneof = _APPWORKERCONFIG.oneofs_by_name['test_oneof']
_APPWORKERINFOSTARTSESSIONCONFIG.fields_by_name['logicInfo'].message_type = _LOGICRUNNERLOGIC
_APPWORKERINFOSTARTSESSIONCONFIG.fields_by_name['brokerConfig'].message_type = _BROKERINFOSTARTSESSIONCONFIG
_APPWORKERINFOSTARTSESSIONCONFIG.fields_by_name['portfolio'].message_type = _BROKERPORTFOLIO
_APPWORKERERROR.fields_by_name['error'].message_type = _DATAERROR
_APPWORKERERROR.fields_by_name['worker'].message_type = _WORKERJOB
_APPWORKERSESSIONREGISTRATION.fields_by_name['worker'].message_type = _WORKERJOB
_APPWORKEREVENTDATA.fields_by_name['worker'].message_type = _WORKERJOB
_APPWORKERBROKERCOMMAND.fields_by_name['worker'].message_type = _WORKERJOB
_APPWORKERBROKERCOMMANDANSWER.fields_by_name['worker'].message_type = _WORKERJOB
_APPWORKERMODULECOMMAND.fields_by_name['worker'].message_type = _WORKERJOB
_APPWORKERMODULECOMMANDANSWER.fields_by_name['worker'].message_type = _WORKERJOB
_APPWORKERFINISHEDSTEPINFOS.fields_by_name['worker'].message_type = _WORKERJOB
_FEATUREWORKERCONFIG.fields_by_name['startSessionConfig'].message_type = _FEATUREINFOSTARTSESSIONCONFIG
_FEATUREWORKERCONFIG.oneofs_by_name['test_oneof'].fields.append(
  _FEATUREWORKERCONFIG.fields_by_name['startSessionConfig'])
_FEATUREWORKERCONFIG.fields_by_name['startSessionConfig'].containing_oneof = _FEATUREWORKERCONFIG.oneofs_by_name['test_oneof']
_FEATUREERROR.fields_by_name['error'].message_type = _DATAERROR
_FEATUREERROR.fields_by_name['worker'].message_type = _WORKERJOB
_FEATUREEVENTDATA.fields_by_name['worker'].message_type = _WORKERJOB
_SYMBOLDATARESPONSE.fields_by_name['symbols'].message_type = _SYMBOLBROKERSYMBOLSMALL
_EXCHANGEDATARESPONSE.fields_by_name['exchanges'].message_type = _BROKEREXCHANGESMALL
_MARKETDATAREQUEST.fields_by_name['symbol'].message_type = _SYMBOLBROKERSYMBOLSMALL
_ADDITIONALDATAFEATURERESPONSE.fields_by_name['featureInfos'].message_type = _ADDITIONALDATAFEATUREINFO
_NOTIFICATIONREGISTRATION.fields_by_name['inputs'].message_type = _NOTIFICATIONOPTIONS
_FEATUREREGISTRATION.fields_by_name['options'].message_type = _FEATUREOPTIONS
_STATISTICMETHODREGISTRATION.fields_by_name['inputs'].message_type = _STATISTICMETHODINPUTS
_STATISTICRULEFUNCTIONREGISTRATION.fields_by_name['inputs'].message_type = _STATISTICFUNCTIONINPUTS
DESCRIPTOR.message_types_by_name['WorkerJob'] = _WORKERJOB
DESCRIPTOR.message_types_by_name['WorkerJobError'] = _WORKERJOBERROR
DESCRIPTOR.message_types_by_name['WorkerAvailablePlugins'] = _WORKERAVAILABLEPLUGINS
DESCRIPTOR.message_types_by_name['Worker'] = _WORKER
DESCRIPTOR.message_types_by_name['RowData'] = _ROWDATA
DESCRIPTOR.message_types_by_name['WorkerJobDataResponse'] = _WORKERJOBDATARESPONSE
DESCRIPTOR.message_types_by_name['WorkerJobDataPartial'] = _WORKERJOBDATAPARTIAL
DESCRIPTOR.message_types_by_name['ChartWorkerPartialDataInfo'] = _CHARTWORKERPARTIALDATAINFO
DESCRIPTOR.message_types_by_name['ChartsWorkerPartialDataLayout'] = _CHARTSWORKERPARTIALDATALAYOUT
DESCRIPTOR.message_types_by_name['ChartWorkerIndicator'] = _CHARTWORKERINDICATOR
DESCRIPTOR.message_types_by_name['ChartWorkerIndicatorRegistration'] = _CHARTWORKERINDICATORREGISTRATION
DESCRIPTOR.message_types_by_name['ChartWorkerIndicatorConfigElement'] = _CHARTWORKERINDICATORCONFIGELEMENT
DESCRIPTOR.message_types_by_name['ChartsWorkerConfig'] = _CHARTSWORKERCONFIG
DESCRIPTOR.message_types_by_name['StatisticInput'] = _STATISTICINPUT
DESCRIPTOR.message_types_by_name['DataError'] = _DATAERROR
DESCRIPTOR.message_types_by_name['IndicatorError'] = _INDICATORERROR
DESCRIPTOR.message_types_by_name['StatisticRuleFunctionError'] = _STATISTICRULEFUNCTIONERROR
DESCRIPTOR.message_types_by_name['StatisticMethodFunctionError'] = _STATISTICMETHODFUNCTIONERROR
DESCRIPTOR.message_types_by_name['StatisticsMethodWorkerWindowConfig'] = _STATISTICSMETHODWORKERWINDOWCONFIG
DESCRIPTOR.message_types_by_name['ParameterTableEntry'] = _PARAMETERTABLEENTRY
DESCRIPTOR.message_types_by_name['ParameterTable'] = _PARAMETERTABLE
DESCRIPTOR.message_types_by_name['ChartDataInfo'] = _CHARTDATAINFO
DESCRIPTOR.message_types_by_name['StatisticsRuleWorkerConfig'] = _STATISTICSRULEWORKERCONFIG
DESCRIPTOR.message_types_by_name['StatisticsRuleWorkerConfigType'] = _STATISTICSRULEWORKERCONFIGTYPE
DESCRIPTOR.message_types_by_name['StatisticsBulkedWorkerConfig'] = _STATISTICSBULKEDWORKERCONFIG
DESCRIPTOR.message_types_by_name['StatisticFunctionError'] = _STATISTICFUNCTIONERROR
DESCRIPTOR.message_types_by_name['StatisticMethodPartiallyData'] = _STATISTICMETHODPARTIALLYDATA
DESCRIPTOR.message_types_by_name['StatisticRulePartiallyData'] = _STATISTICRULEPARTIALLYDATA
DESCRIPTOR.message_types_by_name['StatisticBulkedPartiallyData'] = _STATISTICBULKEDPARTIALLYDATA
DESCRIPTOR.message_types_by_name['SymbolBrokerError'] = _SYMBOLBROKERERROR
DESCRIPTOR.message_types_by_name['SymbolBrokerMarketData'] = _SYMBOLBROKERMARKETDATA
DESCRIPTOR.message_types_by_name['SymbolBrokerInfo'] = _SYMBOLBROKERINFO
DESCRIPTOR.message_types_by_name['SymbolBrokerOrderbook'] = _SYMBOLBROKERORDERBOOK
DESCRIPTOR.message_types_by_name['SymbolBrokerHistoricalMarketData'] = _SYMBOLBROKERHISTORICALMARKETDATA
DESCRIPTOR.message_types_by_name['SymbolBrokerExchange'] = _SYMBOLBROKEREXCHANGE
DESCRIPTOR.message_types_by_name['SymbolBrokerSymbol'] = _SYMBOLBROKERSYMBOL
DESCRIPTOR.message_types_by_name['SymbolBrokerBrokerInfoConfig'] = _SYMBOLBROKERBROKERINFOCONFIG
DESCRIPTOR.message_types_by_name['SymbolBrokerConsumeMarketdataConfig'] = _SYMBOLBROKERCONSUMEMARKETDATACONFIG
DESCRIPTOR.message_types_by_name['SymbolBrokerConsumeOrderbookConfig'] = _SYMBOLBROKERCONSUMEORDERBOOKCONFIG
DESCRIPTOR.message_types_by_name['SymbolBrokerGetHistoricalDataConfig'] = _SYMBOLBROKERGETHISTORICALDATACONFIG
DESCRIPTOR.message_types_by_name['SymbolBrokerWorkerConfig'] = _SYMBOLBROKERWORKERCONFIG
DESCRIPTOR.message_types_by_name['SymbolBrokerStopConsumerListener'] = _SYMBOLBROKERSTOPCONSUMERLISTENER
DESCRIPTOR.message_types_by_name['SymbolBrokerStopConsumerCommand'] = _SYMBOLBROKERSTOPCONSUMERCOMMAND
DESCRIPTOR.message_types_by_name['NotificationExtractMessageDataConfig'] = _NOTIFICATIONEXTRACTMESSAGEDATACONFIG
DESCRIPTOR.message_types_by_name['NotificationSendMessageDataConfig'] = _NOTIFICATIONSENDMESSAGEDATACONFIG
DESCRIPTOR.message_types_by_name['NotificationWorkerConfig'] = _NOTIFICATIONWORKERCONFIG
DESCRIPTOR.message_types_by_name['NotificationError'] = _NOTIFICATIONERROR
DESCRIPTOR.message_types_by_name['NotificationCallbackExtract'] = _NOTIFICATIONCALLBACKEXTRACT
DESCRIPTOR.message_types_by_name['LogicComponent'] = _LOGICCOMPONENT
DESCRIPTOR.message_types_by_name['BrokerAccountModel'] = _BROKERACCOUNTMODEL
DESCRIPTOR.message_types_by_name['PortfolioAsset'] = _PORTFOLIOASSET
DESCRIPTOR.message_types_by_name['CalculatedBaseMoney'] = _CALCULATEDBASEMONEY
DESCRIPTOR.message_types_by_name['PortfolioModel'] = _PORTFOLIOMODEL
DESCRIPTOR.message_types_by_name['LogicRunnerLogic'] = _LOGICRUNNERLOGIC
DESCRIPTOR.message_types_by_name['LogicRunnerOfflineWorkerConfig'] = _LOGICRUNNEROFFLINEWORKERCONFIG
DESCRIPTOR.message_types_by_name['LogicRunnerStatistics'] = _LOGICRUNNERSTATISTICS
DESCRIPTOR.message_types_by_name['LogicRunnerOfflineWorkerPartiallyData'] = _LOGICRUNNEROFFLINEWORKERPARTIALLYDATA
DESCRIPTOR.message_types_by_name['LogicRunnerOfflineWorkerError'] = _LOGICRUNNEROFFLINEWORKERERROR
DESCRIPTOR.message_types_by_name['LogicRunnerOfflineWorkerFinishedData'] = _LOGICRUNNEROFFLINEWORKERFINISHEDDATA
DESCRIPTOR.message_types_by_name['WorkerPluginInformation'] = _WORKERPLUGININFORMATION
DESCRIPTOR.message_types_by_name['WorkerSettings'] = _WORKERSETTINGS
DESCRIPTOR.message_types_by_name['WorkerRegistration'] = _WORKERREGISTRATION
DESCRIPTOR.message_types_by_name['PluginConfig'] = _PLUGINCONFIG
DESCRIPTOR.message_types_by_name['PluginInstallationOutput'] = _PLUGININSTALLATIONOUTPUT
DESCRIPTOR.message_types_by_name['SimulatorChartConfigIndicator'] = _SIMULATORCHARTCONFIGINDICATOR
DESCRIPTOR.message_types_by_name['SimulatorChartConfig'] = _SIMULATORCHARTCONFIG
DESCRIPTOR.message_types_by_name['SimulatorStatisticChartConfig'] = _SIMULATORSTATISTICCHARTCONFIG
DESCRIPTOR.message_types_by_name['SimulatorMethodCallChartConfig'] = _SIMULATORMETHODCALLCHARTCONFIG
DESCRIPTOR.message_types_by_name['SimulatorResponse'] = _SIMULATORRESPONSE
DESCRIPTOR.message_types_by_name['SymbolBrokerSimulatorRequest'] = _SYMBOLBROKERSIMULATORREQUEST
DESCRIPTOR.message_types_by_name['SymbolBrokerSimulatorResponse'] = _SYMBOLBROKERSIMULATORRESPONSE
DESCRIPTOR.message_types_by_name['BrokerSimulatorBrokerLoginData'] = _BROKERSIMULATORBROKERLOGINDATA
DESCRIPTOR.message_types_by_name['BrokerSimulatorBrokerData'] = _BROKERSIMULATORBROKERDATA
DESCRIPTOR.message_types_by_name['BrokerSimulatorRequest'] = _BROKERSIMULATORREQUEST
DESCRIPTOR.message_types_by_name['BrokerSimulatorResponse'] = _BROKERSIMULATORRESPONSE
DESCRIPTOR.message_types_by_name['NotificationSimulatorRequest'] = _NOTIFICATIONSIMULATORREQUEST
DESCRIPTOR.message_types_by_name['NotificationSimulatorResponse'] = _NOTIFICATIONSIMULATORRESPONSE
DESCRIPTOR.message_types_by_name['FeatureSimulatorRequest'] = _FEATURESIMULATORREQUEST
DESCRIPTOR.message_types_by_name['FeatureSimulatorResponse'] = _FEATURESIMULATORRESPONSE
DESCRIPTOR.message_types_by_name['LogicInput'] = _LOGICINPUT
DESCRIPTOR.message_types_by_name['LogicTraderRegistration'] = _LOGICTRADERREGISTRATION
DESCRIPTOR.message_types_by_name['LogicAlertRegistration'] = _LOGICALERTREGISTRATION
DESCRIPTOR.message_types_by_name['LogicAdvisorRegistration'] = _LOGICADVISORREGISTRATION
DESCRIPTOR.message_types_by_name['LogicScreenerRegistration'] = _LOGICSCREENERREGISTRATION
DESCRIPTOR.message_types_by_name['WorkspaceLogicRegistration'] = _WORKSPACELOGICREGISTRATION
DESCRIPTOR.message_types_by_name['SymbolBrokerOptions'] = _SYMBOLBROKEROPTIONS
DESCRIPTOR.message_types_by_name['SymbolBrokerRegistration'] = _SYMBOLBROKERREGISTRATION
DESCRIPTOR.message_types_by_name['BrokerOptions'] = _BROKEROPTIONS
DESCRIPTOR.message_types_by_name['BrokerExchange'] = _BROKEREXCHANGE
DESCRIPTOR.message_types_by_name['BrokerRegistration'] = _BROKERREGISTRATION
DESCRIPTOR.message_types_by_name['BrokerPortfolio'] = _BROKERPORTFOLIO
DESCRIPTOR.message_types_by_name['BrokerPortfolioAsset'] = _BROKERPORTFOLIOASSET
DESCRIPTOR.message_types_by_name['BrokerSessionAccountInfo'] = _BROKERSESSIONACCOUNTINFO
DESCRIPTOR.message_types_by_name['BrokerInfoStartSessionConfig'] = _BROKERINFOSTARTSESSIONCONFIG
DESCRIPTOR.message_types_by_name['BrokerInfoTestConfig'] = _BROKERINFOTESTCONFIG
DESCRIPTOR.message_types_by_name['BrokerWorkerConfig'] = _BROKERWORKERCONFIG
DESCRIPTOR.message_types_by_name['BrokerStopConsumerListener'] = _BROKERSTOPCONSUMERLISTENER
DESCRIPTOR.message_types_by_name['BrokerStopConsumerCommand'] = _BROKERSTOPCONSUMERCOMMAND
DESCRIPTOR.message_types_by_name['BrokerStartSessionInfo'] = _BROKERSTARTSESSIONINFO
DESCRIPTOR.message_types_by_name['BrokerError'] = _BROKERERROR
DESCRIPTOR.message_types_by_name['BrokerCommands'] = _BROKERCOMMANDS
DESCRIPTOR.message_types_by_name['BrokerSessionRegistration'] = _BROKERSESSIONREGISTRATION
DESCRIPTOR.message_types_by_name['BrokerCommandsAnswer'] = _BROKERCOMMANDSANSWER
DESCRIPTOR.message_types_by_name['BrokerCommandsAnswerError'] = _BROKERCOMMANDSANSWERERROR
DESCRIPTOR.message_types_by_name['BrokerEventData'] = _BROKEREVENTDATA
DESCRIPTOR.message_types_by_name['BrokerCommandRegistration'] = _BROKERCOMMANDREGISTRATION
DESCRIPTOR.message_types_by_name['BrokerTestProtocolData'] = _BROKERTESTPROTOCOLDATA
DESCRIPTOR.message_types_by_name['AppWorkerConfig'] = _APPWORKERCONFIG
DESCRIPTOR.message_types_by_name['AppWorkerInfoStartSessionConfig'] = _APPWORKERINFOSTARTSESSIONCONFIG
DESCRIPTOR.message_types_by_name['AppWorkerCommandRegistration'] = _APPWORKERCOMMANDREGISTRATION
DESCRIPTOR.message_types_by_name['AppWorkerError'] = _APPWORKERERROR
DESCRIPTOR.message_types_by_name['AppWorkerCommands'] = _APPWORKERCOMMANDS
DESCRIPTOR.message_types_by_name['AppWorkerSessionRegistration'] = _APPWORKERSESSIONREGISTRATION
DESCRIPTOR.message_types_by_name['AppWorkerCommandsAnswer'] = _APPWORKERCOMMANDSANSWER
DESCRIPTOR.message_types_by_name['AppWorkerCommandsAnswerError'] = _APPWORKERCOMMANDSANSWERERROR
DESCRIPTOR.message_types_by_name['AppWorkerEventData'] = _APPWORKEREVENTDATA
DESCRIPTOR.message_types_by_name['AppWorkerBrokerCommand'] = _APPWORKERBROKERCOMMAND
DESCRIPTOR.message_types_by_name['AppWorkerBrokerCommandAnswer'] = _APPWORKERBROKERCOMMANDANSWER
DESCRIPTOR.message_types_by_name['AppWorkerModuleCommand'] = _APPWORKERMODULECOMMAND
DESCRIPTOR.message_types_by_name['AppWorkerModuleCommandAnswer'] = _APPWORKERMODULECOMMANDANSWER
DESCRIPTOR.message_types_by_name['AppWorkerFinishedStepInfos'] = _APPWORKERFINISHEDSTEPINFOS
DESCRIPTOR.message_types_by_name['FeatureInfoStartSessionConfig'] = _FEATUREINFOSTARTSESSIONCONFIG
DESCRIPTOR.message_types_by_name['FeatureWorkerConfig'] = _FEATUREWORKERCONFIG
DESCRIPTOR.message_types_by_name['FeatureError'] = _FEATUREERROR
DESCRIPTOR.message_types_by_name['FeatureCommands'] = _FEATURECOMMANDS
DESCRIPTOR.message_types_by_name['FeatureCommandsAnswer'] = _FEATURECOMMANDSANSWER
DESCRIPTOR.message_types_by_name['FeatureCommandsAnswerError'] = _FEATURECOMMANDSANSWERERROR
DESCRIPTOR.message_types_by_name['FeatureSessionRegistration'] = _FEATURESESSIONREGISTRATION
DESCRIPTOR.message_types_by_name['FeatureEventData'] = _FEATUREEVENTDATA
DESCRIPTOR.message_types_by_name['RegistrationInformation'] = _REGISTRATIONINFORMATION
DESCRIPTOR.message_types_by_name['SymbolDataRequestInfo'] = _SYMBOLDATAREQUESTINFO
DESCRIPTOR.message_types_by_name['SymbolDataResponse'] = _SYMBOLDATARESPONSE
DESCRIPTOR.message_types_by_name['ExchangeDataRequestInfo'] = _EXCHANGEDATAREQUESTINFO
DESCRIPTOR.message_types_by_name['BrokerExchangeSmall'] = _BROKEREXCHANGESMALL
DESCRIPTOR.message_types_by_name['ExchangeDataResponse'] = _EXCHANGEDATARESPONSE
DESCRIPTOR.message_types_by_name['SymbolBrokerSymbolSmall'] = _SYMBOLBROKERSYMBOLSMALL
DESCRIPTOR.message_types_by_name['MarketDataRequest'] = _MARKETDATAREQUEST
DESCRIPTOR.message_types_by_name['MarketDataResponse'] = _MARKETDATARESPONSE
DESCRIPTOR.message_types_by_name['FeatureDataResponse'] = _FEATUREDATARESPONSE
DESCRIPTOR.message_types_by_name['FeatureDataRequest'] = _FEATUREDATAREQUEST
DESCRIPTOR.message_types_by_name['AdditionalDataFeatureRequest'] = _ADDITIONALDATAFEATUREREQUEST
DESCRIPTOR.message_types_by_name['AdditionalDataFeatureInfo'] = _ADDITIONALDATAFEATUREINFO
DESCRIPTOR.message_types_by_name['AdditionalDataFeatureResponse'] = _ADDITIONALDATAFEATURERESPONSE
DESCRIPTOR.message_types_by_name['NotificationOptions'] = _NOTIFICATIONOPTIONS
DESCRIPTOR.message_types_by_name['NotificationRegistration'] = _NOTIFICATIONREGISTRATION
DESCRIPTOR.message_types_by_name['FeatureOptions'] = _FEATUREOPTIONS
DESCRIPTOR.message_types_by_name['FeatureRegistration'] = _FEATUREREGISTRATION
DESCRIPTOR.message_types_by_name['SimulatorMethodCall'] = _SIMULATORMETHODCALL
DESCRIPTOR.message_types_by_name['StatisticFunctionInputs'] = _STATISTICFUNCTIONINPUTS
DESCRIPTOR.message_types_by_name['StatisticMethodInputs'] = _STATISTICMETHODINPUTS
DESCRIPTOR.message_types_by_name['StatisticMethodRegistration'] = _STATISTICMETHODREGISTRATION
DESCRIPTOR.message_types_by_name['StatisticRuleFunctionRegistration'] = _STATISTICRULEFUNCTIONREGISTRATION
DESCRIPTOR.message_types_by_name['WorkerRegistryRequest'] = _WORKERREGISTRYREQUEST
DESCRIPTOR.message_types_by_name['WorkerRegistryResponse'] = _WORKERREGISTRYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WorkerJob = _reflection.GeneratedProtocolMessageType('WorkerJob', (_message.Message,), {
  'DESCRIPTOR' : _WORKERJOB,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerJob)
  })
_sym_db.RegisterMessage(WorkerJob)

WorkerJobError = _reflection.GeneratedProtocolMessageType('WorkerJobError', (_message.Message,), {
  'DESCRIPTOR' : _WORKERJOBERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerJobError)
  })
_sym_db.RegisterMessage(WorkerJobError)

WorkerAvailablePlugins = _reflection.GeneratedProtocolMessageType('WorkerAvailablePlugins', (_message.Message,), {
  'DESCRIPTOR' : _WORKERAVAILABLEPLUGINS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerAvailablePlugins)
  })
_sym_db.RegisterMessage(WorkerAvailablePlugins)

Worker = _reflection.GeneratedProtocolMessageType('Worker', (_message.Message,), {
  'DESCRIPTOR' : _WORKER,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.Worker)
  })
_sym_db.RegisterMessage(Worker)

RowData = _reflection.GeneratedProtocolMessageType('RowData', (_message.Message,), {
  'DESCRIPTOR' : _ROWDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.RowData)
  })
_sym_db.RegisterMessage(RowData)

WorkerJobDataResponse = _reflection.GeneratedProtocolMessageType('WorkerJobDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKERJOBDATARESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerJobDataResponse)
  })
_sym_db.RegisterMessage(WorkerJobDataResponse)

WorkerJobDataPartial = _reflection.GeneratedProtocolMessageType('WorkerJobDataPartial', (_message.Message,), {
  'DESCRIPTOR' : _WORKERJOBDATAPARTIAL,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerJobDataPartial)
  })
_sym_db.RegisterMessage(WorkerJobDataPartial)

ChartWorkerPartialDataInfo = _reflection.GeneratedProtocolMessageType('ChartWorkerPartialDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _CHARTWORKERPARTIALDATAINFO,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ChartWorkerPartialDataInfo)
  })
_sym_db.RegisterMessage(ChartWorkerPartialDataInfo)

ChartsWorkerPartialDataLayout = _reflection.GeneratedProtocolMessageType('ChartsWorkerPartialDataLayout', (_message.Message,), {
  'DESCRIPTOR' : _CHARTSWORKERPARTIALDATALAYOUT,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ChartsWorkerPartialDataLayout)
  })
_sym_db.RegisterMessage(ChartsWorkerPartialDataLayout)

ChartWorkerIndicator = _reflection.GeneratedProtocolMessageType('ChartWorkerIndicator', (_message.Message,), {
  'DESCRIPTOR' : _CHARTWORKERINDICATOR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ChartWorkerIndicator)
  })
_sym_db.RegisterMessage(ChartWorkerIndicator)

ChartWorkerIndicatorRegistration = _reflection.GeneratedProtocolMessageType('ChartWorkerIndicatorRegistration', (_message.Message,), {
  'DESCRIPTOR' : _CHARTWORKERINDICATORREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ChartWorkerIndicatorRegistration)
  })
_sym_db.RegisterMessage(ChartWorkerIndicatorRegistration)

ChartWorkerIndicatorConfigElement = _reflection.GeneratedProtocolMessageType('ChartWorkerIndicatorConfigElement', (_message.Message,), {
  'DESCRIPTOR' : _CHARTWORKERINDICATORCONFIGELEMENT,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ChartWorkerIndicatorConfigElement)
  })
_sym_db.RegisterMessage(ChartWorkerIndicatorConfigElement)

ChartsWorkerConfig = _reflection.GeneratedProtocolMessageType('ChartsWorkerConfig', (_message.Message,), {
  'DESCRIPTOR' : _CHARTSWORKERCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ChartsWorkerConfig)
  })
_sym_db.RegisterMessage(ChartsWorkerConfig)

StatisticInput = _reflection.GeneratedProtocolMessageType('StatisticInput', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICINPUT,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticInput)
  })
_sym_db.RegisterMessage(StatisticInput)

DataError = _reflection.GeneratedProtocolMessageType('DataError', (_message.Message,), {
  'DESCRIPTOR' : _DATAERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.DataError)
  })
_sym_db.RegisterMessage(DataError)

IndicatorError = _reflection.GeneratedProtocolMessageType('IndicatorError', (_message.Message,), {
  'DESCRIPTOR' : _INDICATORERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.IndicatorError)
  })
_sym_db.RegisterMessage(IndicatorError)

StatisticRuleFunctionError = _reflection.GeneratedProtocolMessageType('StatisticRuleFunctionError', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICRULEFUNCTIONERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticRuleFunctionError)
  })
_sym_db.RegisterMessage(StatisticRuleFunctionError)

StatisticMethodFunctionError = _reflection.GeneratedProtocolMessageType('StatisticMethodFunctionError', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICMETHODFUNCTIONERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticMethodFunctionError)
  })
_sym_db.RegisterMessage(StatisticMethodFunctionError)

StatisticsMethodWorkerWindowConfig = _reflection.GeneratedProtocolMessageType('StatisticsMethodWorkerWindowConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICSMETHODWORKERWINDOWCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticsMethodWorkerWindowConfig)
  })
_sym_db.RegisterMessage(StatisticsMethodWorkerWindowConfig)

ParameterTableEntry = _reflection.GeneratedProtocolMessageType('ParameterTableEntry', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERTABLEENTRY,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ParameterTableEntry)
  })
_sym_db.RegisterMessage(ParameterTableEntry)

ParameterTable = _reflection.GeneratedProtocolMessageType('ParameterTable', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERTABLE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ParameterTable)
  })
_sym_db.RegisterMessage(ParameterTable)

ChartDataInfo = _reflection.GeneratedProtocolMessageType('ChartDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _CHARTDATAINFO,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ChartDataInfo)
  })
_sym_db.RegisterMessage(ChartDataInfo)

StatisticsRuleWorkerConfig = _reflection.GeneratedProtocolMessageType('StatisticsRuleWorkerConfig', (_message.Message,), {

  'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICSRULEWORKERCONFIG_INPUTSENTRY,
    '__module__' : 'dataWorker_pb2'
    # @@protoc_insertion_point(class_scope:coinlib.StatisticsRuleWorkerConfig.InputsEntry)
    })
  ,
  'DESCRIPTOR' : _STATISTICSRULEWORKERCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticsRuleWorkerConfig)
  })
_sym_db.RegisterMessage(StatisticsRuleWorkerConfig)
_sym_db.RegisterMessage(StatisticsRuleWorkerConfig.InputsEntry)

StatisticsRuleWorkerConfigType = _reflection.GeneratedProtocolMessageType('StatisticsRuleWorkerConfigType', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICSRULEWORKERCONFIGTYPE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticsRuleWorkerConfigType)
  })
_sym_db.RegisterMessage(StatisticsRuleWorkerConfigType)

StatisticsBulkedWorkerConfig = _reflection.GeneratedProtocolMessageType('StatisticsBulkedWorkerConfig', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICSBULKEDWORKERCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticsBulkedWorkerConfig)
  })
_sym_db.RegisterMessage(StatisticsBulkedWorkerConfig)

StatisticFunctionError = _reflection.GeneratedProtocolMessageType('StatisticFunctionError', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICFUNCTIONERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticFunctionError)
  })
_sym_db.RegisterMessage(StatisticFunctionError)

StatisticMethodPartiallyData = _reflection.GeneratedProtocolMessageType('StatisticMethodPartiallyData', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICMETHODPARTIALLYDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticMethodPartiallyData)
  })
_sym_db.RegisterMessage(StatisticMethodPartiallyData)

StatisticRulePartiallyData = _reflection.GeneratedProtocolMessageType('StatisticRulePartiallyData', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICRULEPARTIALLYDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticRulePartiallyData)
  })
_sym_db.RegisterMessage(StatisticRulePartiallyData)

StatisticBulkedPartiallyData = _reflection.GeneratedProtocolMessageType('StatisticBulkedPartiallyData', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICBULKEDPARTIALLYDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticBulkedPartiallyData)
  })
_sym_db.RegisterMessage(StatisticBulkedPartiallyData)

SymbolBrokerError = _reflection.GeneratedProtocolMessageType('SymbolBrokerError', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerError)
  })
_sym_db.RegisterMessage(SymbolBrokerError)

SymbolBrokerMarketData = _reflection.GeneratedProtocolMessageType('SymbolBrokerMarketData', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERMARKETDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerMarketData)
  })
_sym_db.RegisterMessage(SymbolBrokerMarketData)

SymbolBrokerInfo = _reflection.GeneratedProtocolMessageType('SymbolBrokerInfo', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERINFO,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerInfo)
  })
_sym_db.RegisterMessage(SymbolBrokerInfo)

SymbolBrokerOrderbook = _reflection.GeneratedProtocolMessageType('SymbolBrokerOrderbook', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERORDERBOOK,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerOrderbook)
  })
_sym_db.RegisterMessage(SymbolBrokerOrderbook)

SymbolBrokerHistoricalMarketData = _reflection.GeneratedProtocolMessageType('SymbolBrokerHistoricalMarketData', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERHISTORICALMARKETDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerHistoricalMarketData)
  })
_sym_db.RegisterMessage(SymbolBrokerHistoricalMarketData)

SymbolBrokerExchange = _reflection.GeneratedProtocolMessageType('SymbolBrokerExchange', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKEREXCHANGE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerExchange)
  })
_sym_db.RegisterMessage(SymbolBrokerExchange)

SymbolBrokerSymbol = _reflection.GeneratedProtocolMessageType('SymbolBrokerSymbol', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERSYMBOL,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerSymbol)
  })
_sym_db.RegisterMessage(SymbolBrokerSymbol)

SymbolBrokerBrokerInfoConfig = _reflection.GeneratedProtocolMessageType('SymbolBrokerBrokerInfoConfig', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERBROKERINFOCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerBrokerInfoConfig)
  })
_sym_db.RegisterMessage(SymbolBrokerBrokerInfoConfig)

SymbolBrokerConsumeMarketdataConfig = _reflection.GeneratedProtocolMessageType('SymbolBrokerConsumeMarketdataConfig', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERCONSUMEMARKETDATACONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerConsumeMarketdataConfig)
  })
_sym_db.RegisterMessage(SymbolBrokerConsumeMarketdataConfig)

SymbolBrokerConsumeOrderbookConfig = _reflection.GeneratedProtocolMessageType('SymbolBrokerConsumeOrderbookConfig', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERCONSUMEORDERBOOKCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerConsumeOrderbookConfig)
  })
_sym_db.RegisterMessage(SymbolBrokerConsumeOrderbookConfig)

SymbolBrokerGetHistoricalDataConfig = _reflection.GeneratedProtocolMessageType('SymbolBrokerGetHistoricalDataConfig', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERGETHISTORICALDATACONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerGetHistoricalDataConfig)
  })
_sym_db.RegisterMessage(SymbolBrokerGetHistoricalDataConfig)

SymbolBrokerWorkerConfig = _reflection.GeneratedProtocolMessageType('SymbolBrokerWorkerConfig', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERWORKERCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerWorkerConfig)
  })
_sym_db.RegisterMessage(SymbolBrokerWorkerConfig)

SymbolBrokerStopConsumerListener = _reflection.GeneratedProtocolMessageType('SymbolBrokerStopConsumerListener', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERSTOPCONSUMERLISTENER,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerStopConsumerListener)
  })
_sym_db.RegisterMessage(SymbolBrokerStopConsumerListener)

SymbolBrokerStopConsumerCommand = _reflection.GeneratedProtocolMessageType('SymbolBrokerStopConsumerCommand', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERSTOPCONSUMERCOMMAND,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerStopConsumerCommand)
  })
_sym_db.RegisterMessage(SymbolBrokerStopConsumerCommand)

NotificationExtractMessageDataConfig = _reflection.GeneratedProtocolMessageType('NotificationExtractMessageDataConfig', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONEXTRACTMESSAGEDATACONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.NotificationExtractMessageDataConfig)
  })
_sym_db.RegisterMessage(NotificationExtractMessageDataConfig)

NotificationSendMessageDataConfig = _reflection.GeneratedProtocolMessageType('NotificationSendMessageDataConfig', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONSENDMESSAGEDATACONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.NotificationSendMessageDataConfig)
  })
_sym_db.RegisterMessage(NotificationSendMessageDataConfig)

NotificationWorkerConfig = _reflection.GeneratedProtocolMessageType('NotificationWorkerConfig', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONWORKERCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.NotificationWorkerConfig)
  })
_sym_db.RegisterMessage(NotificationWorkerConfig)

NotificationError = _reflection.GeneratedProtocolMessageType('NotificationError', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.NotificationError)
  })
_sym_db.RegisterMessage(NotificationError)

NotificationCallbackExtract = _reflection.GeneratedProtocolMessageType('NotificationCallbackExtract', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONCALLBACKEXTRACT,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.NotificationCallbackExtract)
  })
_sym_db.RegisterMessage(NotificationCallbackExtract)

LogicComponent = _reflection.GeneratedProtocolMessageType('LogicComponent', (_message.Message,), {
  'DESCRIPTOR' : _LOGICCOMPONENT,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicComponent)
  })
_sym_db.RegisterMessage(LogicComponent)

BrokerAccountModel = _reflection.GeneratedProtocolMessageType('BrokerAccountModel', (_message.Message,), {
  'DESCRIPTOR' : _BROKERACCOUNTMODEL,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerAccountModel)
  })
_sym_db.RegisterMessage(BrokerAccountModel)

PortfolioAsset = _reflection.GeneratedProtocolMessageType('PortfolioAsset', (_message.Message,), {
  'DESCRIPTOR' : _PORTFOLIOASSET,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.PortfolioAsset)
  })
_sym_db.RegisterMessage(PortfolioAsset)

CalculatedBaseMoney = _reflection.GeneratedProtocolMessageType('CalculatedBaseMoney', (_message.Message,), {
  'DESCRIPTOR' : _CALCULATEDBASEMONEY,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.CalculatedBaseMoney)
  })
_sym_db.RegisterMessage(CalculatedBaseMoney)

PortfolioModel = _reflection.GeneratedProtocolMessageType('PortfolioModel', (_message.Message,), {
  'DESCRIPTOR' : _PORTFOLIOMODEL,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.PortfolioModel)
  })
_sym_db.RegisterMessage(PortfolioModel)

LogicRunnerLogic = _reflection.GeneratedProtocolMessageType('LogicRunnerLogic', (_message.Message,), {
  'DESCRIPTOR' : _LOGICRUNNERLOGIC,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicRunnerLogic)
  })
_sym_db.RegisterMessage(LogicRunnerLogic)

LogicRunnerOfflineWorkerConfig = _reflection.GeneratedProtocolMessageType('LogicRunnerOfflineWorkerConfig', (_message.Message,), {
  'DESCRIPTOR' : _LOGICRUNNEROFFLINEWORKERCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicRunnerOfflineWorkerConfig)
  })
_sym_db.RegisterMessage(LogicRunnerOfflineWorkerConfig)

LogicRunnerStatistics = _reflection.GeneratedProtocolMessageType('LogicRunnerStatistics', (_message.Message,), {
  'DESCRIPTOR' : _LOGICRUNNERSTATISTICS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicRunnerStatistics)
  })
_sym_db.RegisterMessage(LogicRunnerStatistics)

LogicRunnerOfflineWorkerPartiallyData = _reflection.GeneratedProtocolMessageType('LogicRunnerOfflineWorkerPartiallyData', (_message.Message,), {
  'DESCRIPTOR' : _LOGICRUNNEROFFLINEWORKERPARTIALLYDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicRunnerOfflineWorkerPartiallyData)
  })
_sym_db.RegisterMessage(LogicRunnerOfflineWorkerPartiallyData)

LogicRunnerOfflineWorkerError = _reflection.GeneratedProtocolMessageType('LogicRunnerOfflineWorkerError', (_message.Message,), {
  'DESCRIPTOR' : _LOGICRUNNEROFFLINEWORKERERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicRunnerOfflineWorkerError)
  })
_sym_db.RegisterMessage(LogicRunnerOfflineWorkerError)

LogicRunnerOfflineWorkerFinishedData = _reflection.GeneratedProtocolMessageType('LogicRunnerOfflineWorkerFinishedData', (_message.Message,), {
  'DESCRIPTOR' : _LOGICRUNNEROFFLINEWORKERFINISHEDDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicRunnerOfflineWorkerFinishedData)
  })
_sym_db.RegisterMessage(LogicRunnerOfflineWorkerFinishedData)

WorkerPluginInformation = _reflection.GeneratedProtocolMessageType('WorkerPluginInformation', (_message.Message,), {
  'DESCRIPTOR' : _WORKERPLUGININFORMATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerPluginInformation)
  })
_sym_db.RegisterMessage(WorkerPluginInformation)

WorkerSettings = _reflection.GeneratedProtocolMessageType('WorkerSettings', (_message.Message,), {
  'DESCRIPTOR' : _WORKERSETTINGS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerSettings)
  })
_sym_db.RegisterMessage(WorkerSettings)

WorkerRegistration = _reflection.GeneratedProtocolMessageType('WorkerRegistration', (_message.Message,), {
  'DESCRIPTOR' : _WORKERREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerRegistration)
  })
_sym_db.RegisterMessage(WorkerRegistration)

PluginConfig = _reflection.GeneratedProtocolMessageType('PluginConfig', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.PluginConfig)
  })
_sym_db.RegisterMessage(PluginConfig)

PluginInstallationOutput = _reflection.GeneratedProtocolMessageType('PluginInstallationOutput', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININSTALLATIONOUTPUT,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.PluginInstallationOutput)
  })
_sym_db.RegisterMessage(PluginInstallationOutput)

SimulatorChartConfigIndicator = _reflection.GeneratedProtocolMessageType('SimulatorChartConfigIndicator', (_message.Message,), {

  'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SIMULATORCHARTCONFIGINDICATOR_INPUTSENTRY,
    '__module__' : 'dataWorker_pb2'
    # @@protoc_insertion_point(class_scope:coinlib.SimulatorChartConfigIndicator.InputsEntry)
    })
  ,
  'DESCRIPTOR' : _SIMULATORCHARTCONFIGINDICATOR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SimulatorChartConfigIndicator)
  })
_sym_db.RegisterMessage(SimulatorChartConfigIndicator)
_sym_db.RegisterMessage(SimulatorChartConfigIndicator.InputsEntry)

SimulatorChartConfig = _reflection.GeneratedProtocolMessageType('SimulatorChartConfig', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATORCHARTCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SimulatorChartConfig)
  })
_sym_db.RegisterMessage(SimulatorChartConfig)

SimulatorStatisticChartConfig = _reflection.GeneratedProtocolMessageType('SimulatorStatisticChartConfig', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATORSTATISTICCHARTCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SimulatorStatisticChartConfig)
  })
_sym_db.RegisterMessage(SimulatorStatisticChartConfig)

SimulatorMethodCallChartConfig = _reflection.GeneratedProtocolMessageType('SimulatorMethodCallChartConfig', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATORMETHODCALLCHARTCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SimulatorMethodCallChartConfig)
  })
_sym_db.RegisterMessage(SimulatorMethodCallChartConfig)

SimulatorResponse = _reflection.GeneratedProtocolMessageType('SimulatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATORRESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SimulatorResponse)
  })
_sym_db.RegisterMessage(SimulatorResponse)

SymbolBrokerSimulatorRequest = _reflection.GeneratedProtocolMessageType('SymbolBrokerSimulatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERSIMULATORREQUEST,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerSimulatorRequest)
  })
_sym_db.RegisterMessage(SymbolBrokerSimulatorRequest)

SymbolBrokerSimulatorResponse = _reflection.GeneratedProtocolMessageType('SymbolBrokerSimulatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERSIMULATORRESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerSimulatorResponse)
  })
_sym_db.RegisterMessage(SymbolBrokerSimulatorResponse)

BrokerSimulatorBrokerLoginData = _reflection.GeneratedProtocolMessageType('BrokerSimulatorBrokerLoginData', (_message.Message,), {
  'DESCRIPTOR' : _BROKERSIMULATORBROKERLOGINDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerSimulatorBrokerLoginData)
  })
_sym_db.RegisterMessage(BrokerSimulatorBrokerLoginData)

BrokerSimulatorBrokerData = _reflection.GeneratedProtocolMessageType('BrokerSimulatorBrokerData', (_message.Message,), {
  'DESCRIPTOR' : _BROKERSIMULATORBROKERDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerSimulatorBrokerData)
  })
_sym_db.RegisterMessage(BrokerSimulatorBrokerData)

BrokerSimulatorRequest = _reflection.GeneratedProtocolMessageType('BrokerSimulatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _BROKERSIMULATORREQUEST,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerSimulatorRequest)
  })
_sym_db.RegisterMessage(BrokerSimulatorRequest)

BrokerSimulatorResponse = _reflection.GeneratedProtocolMessageType('BrokerSimulatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _BROKERSIMULATORRESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerSimulatorResponse)
  })
_sym_db.RegisterMessage(BrokerSimulatorResponse)

NotificationSimulatorRequest = _reflection.GeneratedProtocolMessageType('NotificationSimulatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONSIMULATORREQUEST,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.NotificationSimulatorRequest)
  })
_sym_db.RegisterMessage(NotificationSimulatorRequest)

NotificationSimulatorResponse = _reflection.GeneratedProtocolMessageType('NotificationSimulatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONSIMULATORRESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.NotificationSimulatorResponse)
  })
_sym_db.RegisterMessage(NotificationSimulatorResponse)

FeatureSimulatorRequest = _reflection.GeneratedProtocolMessageType('FeatureSimulatorRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESIMULATORREQUEST,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureSimulatorRequest)
  })
_sym_db.RegisterMessage(FeatureSimulatorRequest)

FeatureSimulatorResponse = _reflection.GeneratedProtocolMessageType('FeatureSimulatorResponse', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESIMULATORRESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureSimulatorResponse)
  })
_sym_db.RegisterMessage(FeatureSimulatorResponse)

LogicInput = _reflection.GeneratedProtocolMessageType('LogicInput', (_message.Message,), {
  'DESCRIPTOR' : _LOGICINPUT,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicInput)
  })
_sym_db.RegisterMessage(LogicInput)

LogicTraderRegistration = _reflection.GeneratedProtocolMessageType('LogicTraderRegistration', (_message.Message,), {
  'DESCRIPTOR' : _LOGICTRADERREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicTraderRegistration)
  })
_sym_db.RegisterMessage(LogicTraderRegistration)

LogicAlertRegistration = _reflection.GeneratedProtocolMessageType('LogicAlertRegistration', (_message.Message,), {
  'DESCRIPTOR' : _LOGICALERTREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicAlertRegistration)
  })
_sym_db.RegisterMessage(LogicAlertRegistration)

LogicAdvisorRegistration = _reflection.GeneratedProtocolMessageType('LogicAdvisorRegistration', (_message.Message,), {
  'DESCRIPTOR' : _LOGICADVISORREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicAdvisorRegistration)
  })
_sym_db.RegisterMessage(LogicAdvisorRegistration)

LogicScreenerRegistration = _reflection.GeneratedProtocolMessageType('LogicScreenerRegistration', (_message.Message,), {
  'DESCRIPTOR' : _LOGICSCREENERREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.LogicScreenerRegistration)
  })
_sym_db.RegisterMessage(LogicScreenerRegistration)

WorkspaceLogicRegistration = _reflection.GeneratedProtocolMessageType('WorkspaceLogicRegistration', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACELOGICREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkspaceLogicRegistration)
  })
_sym_db.RegisterMessage(WorkspaceLogicRegistration)

SymbolBrokerOptions = _reflection.GeneratedProtocolMessageType('SymbolBrokerOptions', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKEROPTIONS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerOptions)
  })
_sym_db.RegisterMessage(SymbolBrokerOptions)

SymbolBrokerRegistration = _reflection.GeneratedProtocolMessageType('SymbolBrokerRegistration', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerRegistration)
  })
_sym_db.RegisterMessage(SymbolBrokerRegistration)

BrokerOptions = _reflection.GeneratedProtocolMessageType('BrokerOptions', (_message.Message,), {
  'DESCRIPTOR' : _BROKEROPTIONS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerOptions)
  })
_sym_db.RegisterMessage(BrokerOptions)

BrokerExchange = _reflection.GeneratedProtocolMessageType('BrokerExchange', (_message.Message,), {
  'DESCRIPTOR' : _BROKEREXCHANGE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerExchange)
  })
_sym_db.RegisterMessage(BrokerExchange)

BrokerRegistration = _reflection.GeneratedProtocolMessageType('BrokerRegistration', (_message.Message,), {
  'DESCRIPTOR' : _BROKERREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerRegistration)
  })
_sym_db.RegisterMessage(BrokerRegistration)

BrokerPortfolio = _reflection.GeneratedProtocolMessageType('BrokerPortfolio', (_message.Message,), {
  'DESCRIPTOR' : _BROKERPORTFOLIO,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerPortfolio)
  })
_sym_db.RegisterMessage(BrokerPortfolio)

BrokerPortfolioAsset = _reflection.GeneratedProtocolMessageType('BrokerPortfolioAsset', (_message.Message,), {
  'DESCRIPTOR' : _BROKERPORTFOLIOASSET,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerPortfolioAsset)
  })
_sym_db.RegisterMessage(BrokerPortfolioAsset)

BrokerSessionAccountInfo = _reflection.GeneratedProtocolMessageType('BrokerSessionAccountInfo', (_message.Message,), {
  'DESCRIPTOR' : _BROKERSESSIONACCOUNTINFO,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerSessionAccountInfo)
  })
_sym_db.RegisterMessage(BrokerSessionAccountInfo)

BrokerInfoStartSessionConfig = _reflection.GeneratedProtocolMessageType('BrokerInfoStartSessionConfig', (_message.Message,), {
  'DESCRIPTOR' : _BROKERINFOSTARTSESSIONCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerInfoStartSessionConfig)
  })
_sym_db.RegisterMessage(BrokerInfoStartSessionConfig)

BrokerInfoTestConfig = _reflection.GeneratedProtocolMessageType('BrokerInfoTestConfig', (_message.Message,), {
  'DESCRIPTOR' : _BROKERINFOTESTCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerInfoTestConfig)
  })
_sym_db.RegisterMessage(BrokerInfoTestConfig)

BrokerWorkerConfig = _reflection.GeneratedProtocolMessageType('BrokerWorkerConfig', (_message.Message,), {
  'DESCRIPTOR' : _BROKERWORKERCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerWorkerConfig)
  })
_sym_db.RegisterMessage(BrokerWorkerConfig)

BrokerStopConsumerListener = _reflection.GeneratedProtocolMessageType('BrokerStopConsumerListener', (_message.Message,), {
  'DESCRIPTOR' : _BROKERSTOPCONSUMERLISTENER,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerStopConsumerListener)
  })
_sym_db.RegisterMessage(BrokerStopConsumerListener)

BrokerStopConsumerCommand = _reflection.GeneratedProtocolMessageType('BrokerStopConsumerCommand', (_message.Message,), {
  'DESCRIPTOR' : _BROKERSTOPCONSUMERCOMMAND,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerStopConsumerCommand)
  })
_sym_db.RegisterMessage(BrokerStopConsumerCommand)

BrokerStartSessionInfo = _reflection.GeneratedProtocolMessageType('BrokerStartSessionInfo', (_message.Message,), {
  'DESCRIPTOR' : _BROKERSTARTSESSIONINFO,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerStartSessionInfo)
  })
_sym_db.RegisterMessage(BrokerStartSessionInfo)

BrokerError = _reflection.GeneratedProtocolMessageType('BrokerError', (_message.Message,), {
  'DESCRIPTOR' : _BROKERERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerError)
  })
_sym_db.RegisterMessage(BrokerError)

BrokerCommands = _reflection.GeneratedProtocolMessageType('BrokerCommands', (_message.Message,), {
  'DESCRIPTOR' : _BROKERCOMMANDS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerCommands)
  })
_sym_db.RegisterMessage(BrokerCommands)

BrokerSessionRegistration = _reflection.GeneratedProtocolMessageType('BrokerSessionRegistration', (_message.Message,), {
  'DESCRIPTOR' : _BROKERSESSIONREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerSessionRegistration)
  })
_sym_db.RegisterMessage(BrokerSessionRegistration)

BrokerCommandsAnswer = _reflection.GeneratedProtocolMessageType('BrokerCommandsAnswer', (_message.Message,), {
  'DESCRIPTOR' : _BROKERCOMMANDSANSWER,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerCommandsAnswer)
  })
_sym_db.RegisterMessage(BrokerCommandsAnswer)

BrokerCommandsAnswerError = _reflection.GeneratedProtocolMessageType('BrokerCommandsAnswerError', (_message.Message,), {
  'DESCRIPTOR' : _BROKERCOMMANDSANSWERERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerCommandsAnswerError)
  })
_sym_db.RegisterMessage(BrokerCommandsAnswerError)

BrokerEventData = _reflection.GeneratedProtocolMessageType('BrokerEventData', (_message.Message,), {
  'DESCRIPTOR' : _BROKEREVENTDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerEventData)
  })
_sym_db.RegisterMessage(BrokerEventData)

BrokerCommandRegistration = _reflection.GeneratedProtocolMessageType('BrokerCommandRegistration', (_message.Message,), {
  'DESCRIPTOR' : _BROKERCOMMANDREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerCommandRegistration)
  })
_sym_db.RegisterMessage(BrokerCommandRegistration)

BrokerTestProtocolData = _reflection.GeneratedProtocolMessageType('BrokerTestProtocolData', (_message.Message,), {
  'DESCRIPTOR' : _BROKERTESTPROTOCOLDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerTestProtocolData)
  })
_sym_db.RegisterMessage(BrokerTestProtocolData)

AppWorkerConfig = _reflection.GeneratedProtocolMessageType('AppWorkerConfig', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerConfig)
  })
_sym_db.RegisterMessage(AppWorkerConfig)

AppWorkerInfoStartSessionConfig = _reflection.GeneratedProtocolMessageType('AppWorkerInfoStartSessionConfig', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERINFOSTARTSESSIONCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerInfoStartSessionConfig)
  })
_sym_db.RegisterMessage(AppWorkerInfoStartSessionConfig)

AppWorkerCommandRegistration = _reflection.GeneratedProtocolMessageType('AppWorkerCommandRegistration', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERCOMMANDREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerCommandRegistration)
  })
_sym_db.RegisterMessage(AppWorkerCommandRegistration)

AppWorkerError = _reflection.GeneratedProtocolMessageType('AppWorkerError', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerError)
  })
_sym_db.RegisterMessage(AppWorkerError)

AppWorkerCommands = _reflection.GeneratedProtocolMessageType('AppWorkerCommands', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERCOMMANDS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerCommands)
  })
_sym_db.RegisterMessage(AppWorkerCommands)

AppWorkerSessionRegistration = _reflection.GeneratedProtocolMessageType('AppWorkerSessionRegistration', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERSESSIONREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerSessionRegistration)
  })
_sym_db.RegisterMessage(AppWorkerSessionRegistration)

AppWorkerCommandsAnswer = _reflection.GeneratedProtocolMessageType('AppWorkerCommandsAnswer', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERCOMMANDSANSWER,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerCommandsAnswer)
  })
_sym_db.RegisterMessage(AppWorkerCommandsAnswer)

AppWorkerCommandsAnswerError = _reflection.GeneratedProtocolMessageType('AppWorkerCommandsAnswerError', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERCOMMANDSANSWERERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerCommandsAnswerError)
  })
_sym_db.RegisterMessage(AppWorkerCommandsAnswerError)

AppWorkerEventData = _reflection.GeneratedProtocolMessageType('AppWorkerEventData', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKEREVENTDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerEventData)
  })
_sym_db.RegisterMessage(AppWorkerEventData)

AppWorkerBrokerCommand = _reflection.GeneratedProtocolMessageType('AppWorkerBrokerCommand', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERBROKERCOMMAND,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerBrokerCommand)
  })
_sym_db.RegisterMessage(AppWorkerBrokerCommand)

AppWorkerBrokerCommandAnswer = _reflection.GeneratedProtocolMessageType('AppWorkerBrokerCommandAnswer', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERBROKERCOMMANDANSWER,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerBrokerCommandAnswer)
  })
_sym_db.RegisterMessage(AppWorkerBrokerCommandAnswer)

AppWorkerModuleCommand = _reflection.GeneratedProtocolMessageType('AppWorkerModuleCommand', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERMODULECOMMAND,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerModuleCommand)
  })
_sym_db.RegisterMessage(AppWorkerModuleCommand)

AppWorkerModuleCommandAnswer = _reflection.GeneratedProtocolMessageType('AppWorkerModuleCommandAnswer', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERMODULECOMMANDANSWER,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerModuleCommandAnswer)
  })
_sym_db.RegisterMessage(AppWorkerModuleCommandAnswer)

AppWorkerFinishedStepInfos = _reflection.GeneratedProtocolMessageType('AppWorkerFinishedStepInfos', (_message.Message,), {
  'DESCRIPTOR' : _APPWORKERFINISHEDSTEPINFOS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AppWorkerFinishedStepInfos)
  })
_sym_db.RegisterMessage(AppWorkerFinishedStepInfos)

FeatureInfoStartSessionConfig = _reflection.GeneratedProtocolMessageType('FeatureInfoStartSessionConfig', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREINFOSTARTSESSIONCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureInfoStartSessionConfig)
  })
_sym_db.RegisterMessage(FeatureInfoStartSessionConfig)

FeatureWorkerConfig = _reflection.GeneratedProtocolMessageType('FeatureWorkerConfig', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREWORKERCONFIG,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureWorkerConfig)
  })
_sym_db.RegisterMessage(FeatureWorkerConfig)

FeatureError = _reflection.GeneratedProtocolMessageType('FeatureError', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureError)
  })
_sym_db.RegisterMessage(FeatureError)

FeatureCommands = _reflection.GeneratedProtocolMessageType('FeatureCommands', (_message.Message,), {
  'DESCRIPTOR' : _FEATURECOMMANDS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureCommands)
  })
_sym_db.RegisterMessage(FeatureCommands)

FeatureCommandsAnswer = _reflection.GeneratedProtocolMessageType('FeatureCommandsAnswer', (_message.Message,), {
  'DESCRIPTOR' : _FEATURECOMMANDSANSWER,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureCommandsAnswer)
  })
_sym_db.RegisterMessage(FeatureCommandsAnswer)

FeatureCommandsAnswerError = _reflection.GeneratedProtocolMessageType('FeatureCommandsAnswerError', (_message.Message,), {
  'DESCRIPTOR' : _FEATURECOMMANDSANSWERERROR,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureCommandsAnswerError)
  })
_sym_db.RegisterMessage(FeatureCommandsAnswerError)

FeatureSessionRegistration = _reflection.GeneratedProtocolMessageType('FeatureSessionRegistration', (_message.Message,), {
  'DESCRIPTOR' : _FEATURESESSIONREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureSessionRegistration)
  })
_sym_db.RegisterMessage(FeatureSessionRegistration)

FeatureEventData = _reflection.GeneratedProtocolMessageType('FeatureEventData', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREEVENTDATA,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureEventData)
  })
_sym_db.RegisterMessage(FeatureEventData)

RegistrationInformation = _reflection.GeneratedProtocolMessageType('RegistrationInformation', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRATIONINFORMATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.RegistrationInformation)
  })
_sym_db.RegisterMessage(RegistrationInformation)

SymbolDataRequestInfo = _reflection.GeneratedProtocolMessageType('SymbolDataRequestInfo', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLDATAREQUESTINFO,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolDataRequestInfo)
  })
_sym_db.RegisterMessage(SymbolDataRequestInfo)

SymbolDataResponse = _reflection.GeneratedProtocolMessageType('SymbolDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLDATARESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolDataResponse)
  })
_sym_db.RegisterMessage(SymbolDataResponse)

ExchangeDataRequestInfo = _reflection.GeneratedProtocolMessageType('ExchangeDataRequestInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGEDATAREQUESTINFO,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ExchangeDataRequestInfo)
  })
_sym_db.RegisterMessage(ExchangeDataRequestInfo)

BrokerExchangeSmall = _reflection.GeneratedProtocolMessageType('BrokerExchangeSmall', (_message.Message,), {
  'DESCRIPTOR' : _BROKEREXCHANGESMALL,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.BrokerExchangeSmall)
  })
_sym_db.RegisterMessage(BrokerExchangeSmall)

ExchangeDataResponse = _reflection.GeneratedProtocolMessageType('ExchangeDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGEDATARESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.ExchangeDataResponse)
  })
_sym_db.RegisterMessage(ExchangeDataResponse)

SymbolBrokerSymbolSmall = _reflection.GeneratedProtocolMessageType('SymbolBrokerSymbolSmall', (_message.Message,), {
  'DESCRIPTOR' : _SYMBOLBROKERSYMBOLSMALL,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SymbolBrokerSymbolSmall)
  })
_sym_db.RegisterMessage(SymbolBrokerSymbolSmall)

MarketDataRequest = _reflection.GeneratedProtocolMessageType('MarketDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _MARKETDATAREQUEST,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.MarketDataRequest)
  })
_sym_db.RegisterMessage(MarketDataRequest)

MarketDataResponse = _reflection.GeneratedProtocolMessageType('MarketDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _MARKETDATARESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.MarketDataResponse)
  })
_sym_db.RegisterMessage(MarketDataResponse)

FeatureDataResponse = _reflection.GeneratedProtocolMessageType('FeatureDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREDATARESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureDataResponse)
  })
_sym_db.RegisterMessage(FeatureDataResponse)

FeatureDataRequest = _reflection.GeneratedProtocolMessageType('FeatureDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREDATAREQUEST,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureDataRequest)
  })
_sym_db.RegisterMessage(FeatureDataRequest)

AdditionalDataFeatureRequest = _reflection.GeneratedProtocolMessageType('AdditionalDataFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALDATAFEATUREREQUEST,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AdditionalDataFeatureRequest)
  })
_sym_db.RegisterMessage(AdditionalDataFeatureRequest)

AdditionalDataFeatureInfo = _reflection.GeneratedProtocolMessageType('AdditionalDataFeatureInfo', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALDATAFEATUREINFO,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AdditionalDataFeatureInfo)
  })
_sym_db.RegisterMessage(AdditionalDataFeatureInfo)

AdditionalDataFeatureResponse = _reflection.GeneratedProtocolMessageType('AdditionalDataFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDITIONALDATAFEATURERESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.AdditionalDataFeatureResponse)
  })
_sym_db.RegisterMessage(AdditionalDataFeatureResponse)

NotificationOptions = _reflection.GeneratedProtocolMessageType('NotificationOptions', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONOPTIONS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.NotificationOptions)
  })
_sym_db.RegisterMessage(NotificationOptions)

NotificationRegistration = _reflection.GeneratedProtocolMessageType('NotificationRegistration', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.NotificationRegistration)
  })
_sym_db.RegisterMessage(NotificationRegistration)

FeatureOptions = _reflection.GeneratedProtocolMessageType('FeatureOptions', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREOPTIONS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureOptions)
  })
_sym_db.RegisterMessage(FeatureOptions)

FeatureRegistration = _reflection.GeneratedProtocolMessageType('FeatureRegistration', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.FeatureRegistration)
  })
_sym_db.RegisterMessage(FeatureRegistration)

SimulatorMethodCall = _reflection.GeneratedProtocolMessageType('SimulatorMethodCall', (_message.Message,), {
  'DESCRIPTOR' : _SIMULATORMETHODCALL,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.SimulatorMethodCall)
  })
_sym_db.RegisterMessage(SimulatorMethodCall)

StatisticFunctionInputs = _reflection.GeneratedProtocolMessageType('StatisticFunctionInputs', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICFUNCTIONINPUTS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticFunctionInputs)
  })
_sym_db.RegisterMessage(StatisticFunctionInputs)

StatisticMethodInputs = _reflection.GeneratedProtocolMessageType('StatisticMethodInputs', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICMETHODINPUTS,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticMethodInputs)
  })
_sym_db.RegisterMessage(StatisticMethodInputs)

StatisticMethodRegistration = _reflection.GeneratedProtocolMessageType('StatisticMethodRegistration', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICMETHODREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticMethodRegistration)
  })
_sym_db.RegisterMessage(StatisticMethodRegistration)

StatisticRuleFunctionRegistration = _reflection.GeneratedProtocolMessageType('StatisticRuleFunctionRegistration', (_message.Message,), {
  'DESCRIPTOR' : _STATISTICRULEFUNCTIONREGISTRATION,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.StatisticRuleFunctionRegistration)
  })
_sym_db.RegisterMessage(StatisticRuleFunctionRegistration)

WorkerRegistryRequest = _reflection.GeneratedProtocolMessageType('WorkerRegistryRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKERREGISTRYREQUEST,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerRegistryRequest)
  })
_sym_db.RegisterMessage(WorkerRegistryRequest)

WorkerRegistryResponse = _reflection.GeneratedProtocolMessageType('WorkerRegistryResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKERREGISTRYRESPONSE,
  '__module__' : 'dataWorker_pb2'
  # @@protoc_insertion_point(class_scope:coinlib.WorkerRegistryResponse)
  })
_sym_db.RegisterMessage(WorkerRegistryResponse)


_STATISTICSRULEWORKERCONFIG_INPUTSENTRY._options = None
_SIMULATORCHARTCONFIGINDICATOR_INPUTSENTRY._options = None

_CHARTSWORKER = _descriptor.ServiceDescriptor(
  name='ChartsWorker',
  full_name='coinlib.ChartsWorker',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=23438,
  serialized_end=23684,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='coinlib.ChartsWorker.GetConfig',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=_CHARTSWORKERCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnIndicatorErrorOccured',
    full_name='coinlib.ChartsWorker.OnIndicatorErrorOccured',
    index=1,
    containing_service=None,
    input_type=_INDICATORERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnPartialChartLayout',
    full_name='coinlib.ChartsWorker.OnPartialChartLayout',
    index=2,
    containing_service=None,
    input_type=_CHARTSWORKERPARTIALDATALAYOUT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHARTSWORKER)

DESCRIPTOR.services_by_name['ChartsWorker'] = _CHARTSWORKER


_STATISTICSMETHODWORKER = _descriptor.ServiceDescriptor(
  name='StatisticsMethodWorker',
  full_name='coinlib.StatisticsMethodWorker',
  file=DESCRIPTOR,
  index=1,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=23687,
  serialized_end=23972,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='coinlib.StatisticsMethodWorker.GetConfig',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=_STATISTICSBULKEDWORKERCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnStatisticPartiallyData',
    full_name='coinlib.StatisticsMethodWorker.OnStatisticPartiallyData',
    index=1,
    containing_service=None,
    input_type=_STATISTICBULKEDPARTIALLYDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnStatisticFunctionErrorOccured',
    full_name='coinlib.StatisticsMethodWorker.OnStatisticFunctionErrorOccured',
    index=2,
    containing_service=None,
    input_type=_STATISTICFUNCTIONERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STATISTICSMETHODWORKER)

DESCRIPTOR.services_by_name['StatisticsMethodWorker'] = _STATISTICSMETHODWORKER


_SYMBOLBROKERWORKER = _descriptor.ServiceDescriptor(
  name='SymbolBrokerWorker',
  full_name='coinlib.SymbolBrokerWorker',
  file=DESCRIPTOR,
  index=2,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=23975,
  serialized_end=24606,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='coinlib.SymbolBrokerWorker.GetConfig',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=_SYMBOLBROKERWORKERCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='waitForConsumerStopped',
    full_name='coinlib.SymbolBrokerWorker.waitForConsumerStopped',
    index=1,
    containing_service=None,
    input_type=_SYMBOLBROKERSTOPCONSUMERLISTENER,
    output_type=_SYMBOLBROKERSTOPCONSUMERCOMMAND,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='onHistoricalDataReceived',
    full_name='coinlib.SymbolBrokerWorker.onHistoricalDataReceived',
    index=2,
    containing_service=None,
    input_type=_SYMBOLBROKERHISTORICALMARKETDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='onBrokerSymbolInfoReceived',
    full_name='coinlib.SymbolBrokerWorker.onBrokerSymbolInfoReceived',
    index=3,
    containing_service=None,
    input_type=_SYMBOLBROKERINFO,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='onMarketDataReceived',
    full_name='coinlib.SymbolBrokerWorker.onMarketDataReceived',
    index=4,
    containing_service=None,
    input_type=_SYMBOLBROKERMARKETDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='onOrderbookReceived',
    full_name='coinlib.SymbolBrokerWorker.onOrderbookReceived',
    index=5,
    containing_service=None,
    input_type=_SYMBOLBROKERORDERBOOK,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnSymbolBrokerErrorOccured',
    full_name='coinlib.SymbolBrokerWorker.OnSymbolBrokerErrorOccured',
    index=6,
    containing_service=None,
    input_type=_SYMBOLBROKERERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SYMBOLBROKERWORKER)

DESCRIPTOR.services_by_name['SymbolBrokerWorker'] = _SYMBOLBROKERWORKER


_NOTIFICATIONWORKER = _descriptor.ServiceDescriptor(
  name='NotificationWorker',
  full_name='coinlib.NotificationWorker',
  file=DESCRIPTOR,
  index=3,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=24609,
  serialized_end=24874,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='coinlib.NotificationWorker.GetConfig',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=_NOTIFICATIONWORKERCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnCallbackDataExtracted',
    full_name='coinlib.NotificationWorker.OnCallbackDataExtracted',
    index=1,
    containing_service=None,
    input_type=_NOTIFICATIONCALLBACKEXTRACT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnNotificationErrorOccured',
    full_name='coinlib.NotificationWorker.OnNotificationErrorOccured',
    index=2,
    containing_service=None,
    input_type=_NOTIFICATIONERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NOTIFICATIONWORKER)

DESCRIPTOR.services_by_name['NotificationWorker'] = _NOTIFICATIONWORKER


_LOGICRUNNEROFFLINESERVICE = _descriptor.ServiceDescriptor(
  name='LogicRunnerOfflineService',
  full_name='coinlib.LogicRunnerOfflineService',
  file=DESCRIPTOR,
  index=4,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=24877,
  serialized_end=25270,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='coinlib.LogicRunnerOfflineService.GetConfig',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=_LOGICRUNNEROFFLINEWORKERCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnRunnerPartiallyData',
    full_name='coinlib.LogicRunnerOfflineService.OnRunnerPartiallyData',
    index=1,
    containing_service=None,
    input_type=_LOGICRUNNEROFFLINEWORKERPARTIALLYDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnRunnerErrorOccured',
    full_name='coinlib.LogicRunnerOfflineService.OnRunnerErrorOccured',
    index=2,
    containing_service=None,
    input_type=_LOGICRUNNEROFFLINEWORKERERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnRunnerFinishedComplete',
    full_name='coinlib.LogicRunnerOfflineService.OnRunnerFinishedComplete',
    index=3,
    containing_service=None,
    input_type=_LOGICRUNNEROFFLINEWORKERFINISHEDDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGICRUNNEROFFLINESERVICE)

DESCRIPTOR.services_by_name['LogicRunnerOfflineService'] = _LOGICRUNNEROFFLINESERVICE


_DATAWORKER = _descriptor.ServiceDescriptor(
  name='DataWorker',
  full_name='coinlib.DataWorker',
  file=DESCRIPTOR,
  index=5,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=25273,
  serialized_end=25837,
  methods=[
  _descriptor.MethodDescriptor(
    name='AcceptWorkerJob',
    full_name='coinlib.DataWorker.AcceptWorkerJob',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeclineWorkerJob',
    full_name='coinlib.DataWorker.DeclineWorkerJob',
    index=1,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterWorker',
    full_name='coinlib.DataWorker.RegisterWorker',
    index=2,
    containing_service=None,
    input_type=_WORKER,
    output_type=_WORKERSETTINGS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAllPlugins',
    full_name='coinlib.DataWorker.GetAllPlugins',
    index=3,
    containing_service=None,
    input_type=_WORKER,
    output_type=_WORKERPLUGININFORMATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateWorkerJob',
    full_name='coinlib.DataWorker.UpdateWorkerJob',
    index=4,
    containing_service=None,
    input_type=_WORKERJOBDATARESPONSE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchWorkerJobs',
    full_name='coinlib.DataWorker.WatchWorkerJobs',
    index=5,
    containing_service=None,
    input_type=_WORKERREGISTRATION,
    output_type=_WORKERJOB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FinishedWorkerJob',
    full_name='coinlib.DataWorker.FinishedWorkerJob',
    index=6,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ErroredWorkerJob',
    full_name='coinlib.DataWorker.ErroredWorkerJob',
    index=7,
    containing_service=None,
    input_type=_WORKERJOBERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAWORKER)

DESCRIPTOR.services_by_name['DataWorker'] = _DATAWORKER


_PLUGINWORKER = _descriptor.ServiceDescriptor(
  name='PluginWorker',
  full_name='coinlib.PluginWorker',
  file=DESCRIPTOR,
  index=6,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=25840,
  serialized_end=25999,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='coinlib.PluginWorker.GetConfig',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=_PLUGINCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnInstallationOutput',
    full_name='coinlib.PluginWorker.OnInstallationOutput',
    index=1,
    containing_service=None,
    input_type=_PLUGININSTALLATIONOUTPUT,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PLUGINWORKER)

DESCRIPTOR.services_by_name['PluginWorker'] = _PLUGINWORKER


_SIMULATOR = _descriptor.ServiceDescriptor(
  name='Simulator',
  full_name='coinlib.Simulator',
  file=DESCRIPTOR,
  index=7,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=26002,
  serialized_end=26669,
  methods=[
  _descriptor.MethodDescriptor(
    name='simulateFeature',
    full_name='coinlib.Simulator.simulateFeature',
    index=0,
    containing_service=None,
    input_type=_FEATURESIMULATORREQUEST,
    output_type=_FEATURESIMULATORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='simulateChart',
    full_name='coinlib.Simulator.simulateChart',
    index=1,
    containing_service=None,
    input_type=_SIMULATORCHARTCONFIG,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='simulateStatisticsRule',
    full_name='coinlib.Simulator.simulateStatisticsRule',
    index=2,
    containing_service=None,
    input_type=_SIMULATORSTATISTICCHARTCONFIG,
    output_type=_SIMULATORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='simulateStatisticsMethod',
    full_name='coinlib.Simulator.simulateStatisticsMethod',
    index=3,
    containing_service=None,
    input_type=_SIMULATORMETHODCALLCHARTCONFIG,
    output_type=_SIMULATORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='simulateSymbolBroker',
    full_name='coinlib.Simulator.simulateSymbolBroker',
    index=4,
    containing_service=None,
    input_type=_SYMBOLBROKERSIMULATORREQUEST,
    output_type=_SYMBOLBROKERSIMULATORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='simulateBroker',
    full_name='coinlib.Simulator.simulateBroker',
    index=5,
    containing_service=None,
    input_type=_BROKERSIMULATORREQUEST,
    output_type=_BROKERSIMULATORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='simulateNotification',
    full_name='coinlib.Simulator.simulateNotification',
    index=6,
    containing_service=None,
    input_type=_NOTIFICATIONSIMULATORREQUEST,
    output_type=_NOTIFICATIONSIMULATORRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SIMULATOR)

DESCRIPTOR.services_by_name['Simulator'] = _SIMULATOR


_FUNCTIONS = _descriptor.ServiceDescriptor(
  name='Functions',
  full_name='coinlib.Functions',
  file=DESCRIPTOR,
  index=8,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=26671,
  serialized_end=26780,
  methods=[
  _descriptor.MethodDescriptor(
    name='registerIndicatorFunction',
    full_name='coinlib.Functions.registerIndicatorFunction',
    index=0,
    containing_service=None,
    input_type=_CHARTWORKERINDICATORREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FUNCTIONS)

DESCRIPTOR.services_by_name['Functions'] = _FUNCTIONS


_LOGIC = _descriptor.ServiceDescriptor(
  name='Logic',
  full_name='coinlib.Logic',
  file=DESCRIPTOR,
  index=9,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=26783,
  serialized_end=27116,
  methods=[
  _descriptor.MethodDescriptor(
    name='registerTrader',
    full_name='coinlib.Logic.registerTrader',
    index=0,
    containing_service=None,
    input_type=_LOGICTRADERREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='registerScreener',
    full_name='coinlib.Logic.registerScreener',
    index=1,
    containing_service=None,
    input_type=_LOGICSCREENERREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='registerAdvisor',
    full_name='coinlib.Logic.registerAdvisor',
    index=2,
    containing_service=None,
    input_type=_LOGICADVISORREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='addLogicToWorkspace',
    full_name='coinlib.Logic.addLogicToWorkspace',
    index=3,
    containing_service=None,
    input_type=_WORKSPACELOGICREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGIC)

DESCRIPTOR.services_by_name['Logic'] = _LOGIC


_BROKER = _descriptor.ServiceDescriptor(
  name='Broker',
  full_name='coinlib.Broker',
  file=DESCRIPTOR,
  index=10,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=27118,
  serialized_end=27199,
  methods=[
  _descriptor.MethodDescriptor(
    name='registerBroker',
    full_name='coinlib.Broker.registerBroker',
    index=0,
    containing_service=None,
    input_type=_BROKERREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BROKER)

DESCRIPTOR.services_by_name['Broker'] = _BROKER


_BROKERWORKER = _descriptor.ServiceDescriptor(
  name='BrokerWorker',
  full_name='coinlib.BrokerWorker',
  file=DESCRIPTOR,
  index=11,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=27202,
  serialized_end=27764,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='coinlib.BrokerWorker.GetConfig',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=_BROKERWORKERCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnBrokerErrorOccured',
    full_name='coinlib.BrokerWorker.OnBrokerErrorOccured',
    index=1,
    containing_service=None,
    input_type=_BROKERERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchBrokerCommands',
    full_name='coinlib.BrokerWorker.WatchBrokerCommands',
    index=2,
    containing_service=None,
    input_type=_BROKERCOMMANDREGISTRATION,
    output_type=_BROKERCOMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendCommandAnswer',
    full_name='coinlib.BrokerWorker.SendCommandAnswer',
    index=3,
    containing_service=None,
    input_type=_BROKERCOMMANDSANSWER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendCommandAnswerError',
    full_name='coinlib.BrokerWorker.SendCommandAnswerError',
    index=4,
    containing_service=None,
    input_type=_BROKERCOMMANDSANSWERERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterBrokerSession',
    full_name='coinlib.BrokerWorker.RegisterBrokerSession',
    index=5,
    containing_service=None,
    input_type=_BROKERSESSIONREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnBrokerEvent',
    full_name='coinlib.BrokerWorker.OnBrokerEvent',
    index=6,
    containing_service=None,
    input_type=_BROKEREVENTDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BROKERWORKER)

DESCRIPTOR.services_by_name['BrokerWorker'] = _BROKERWORKER


_APPWORKER = _descriptor.ServiceDescriptor(
  name='AppWorker',
  full_name='coinlib.AppWorker',
  file=DESCRIPTOR,
  index=12,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=27767,
  serialized_end=28812,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='coinlib.AppWorker.GetConfig',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=_APPWORKERCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnAppWorkerErrorOccured',
    full_name='coinlib.AppWorker.OnAppWorkerErrorOccured',
    index=1,
    containing_service=None,
    input_type=_APPWORKERERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchBrokerCommands',
    full_name='coinlib.AppWorker.WatchBrokerCommands',
    index=2,
    containing_service=None,
    input_type=_APPWORKERCOMMANDREGISTRATION,
    output_type=_APPWORKERCOMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunModuleCommand',
    full_name='coinlib.AppWorker.RunModuleCommand',
    index=3,
    containing_service=None,
    input_type=_APPWORKERMODULECOMMAND,
    output_type=_APPWORKERMODULECOMMANDANSWER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunBrokerCommand',
    full_name='coinlib.AppWorker.RunBrokerCommand',
    index=4,
    containing_service=None,
    input_type=_APPWORKERBROKERCOMMAND,
    output_type=_APPWORKERBROKERCOMMANDANSWER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchAppWorkerCommands',
    full_name='coinlib.AppWorker.WatchAppWorkerCommands',
    index=5,
    containing_service=None,
    input_type=_APPWORKERCOMMANDREGISTRATION,
    output_type=_APPWORKERCOMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendCommandAnswer',
    full_name='coinlib.AppWorker.SendCommandAnswer',
    index=6,
    containing_service=None,
    input_type=_APPWORKERCOMMANDSANSWER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendCommandAnswerError',
    full_name='coinlib.AppWorker.SendCommandAnswerError',
    index=7,
    containing_service=None,
    input_type=_APPWORKERCOMMANDSANSWERERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnAppWorkerLogicFinished',
    full_name='coinlib.AppWorker.OnAppWorkerLogicFinished',
    index=8,
    containing_service=None,
    input_type=_APPWORKERFINISHEDSTEPINFOS,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterAppWorkerSession',
    full_name='coinlib.AppWorker.RegisterAppWorkerSession',
    index=9,
    containing_service=None,
    input_type=_APPWORKERSESSIONREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnAppWorkerEvent',
    full_name='coinlib.AppWorker.OnAppWorkerEvent',
    index=10,
    containing_service=None,
    input_type=_APPWORKEREVENTDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnBrokerTestResult',
    full_name='coinlib.AppWorker.OnBrokerTestResult',
    index=11,
    containing_service=None,
    input_type=_BROKERTESTPROTOCOLDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APPWORKER)

DESCRIPTOR.services_by_name['AppWorker'] = _APPWORKER


_FEATUREWORKER = _descriptor.ServiceDescriptor(
  name='FeatureWorker',
  full_name='coinlib.FeatureWorker',
  file=DESCRIPTOR,
  index=13,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=28815,
  serialized_end=29361,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetConfig',
    full_name='coinlib.FeatureWorker.GetConfig',
    index=0,
    containing_service=None,
    input_type=_WORKERJOB,
    output_type=_FEATUREWORKERCONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnErrorOccured',
    full_name='coinlib.FeatureWorker.OnErrorOccured',
    index=1,
    containing_service=None,
    input_type=_FEATUREERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchCommands',
    full_name='coinlib.FeatureWorker.WatchCommands',
    index=2,
    containing_service=None,
    input_type=_FEATURECOMMANDS,
    output_type=_FEATURECOMMANDS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendCommandAnswer',
    full_name='coinlib.FeatureWorker.SendCommandAnswer',
    index=3,
    containing_service=None,
    input_type=_FEATURECOMMANDSANSWER,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendCommandAnswerError',
    full_name='coinlib.FeatureWorker.SendCommandAnswerError',
    index=4,
    containing_service=None,
    input_type=_FEATURECOMMANDSANSWERERROR,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RegisterSession',
    full_name='coinlib.FeatureWorker.RegisterSession',
    index=5,
    containing_service=None,
    input_type=_FEATURESESSIONREGISTRATION,
    output_type=_REGISTRATIONINFORMATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OnEvent',
    full_name='coinlib.FeatureWorker.OnEvent',
    index=6,
    containing_service=None,
    input_type=_FEATUREEVENTDATA,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEATUREWORKER)

DESCRIPTOR.services_by_name['FeatureWorker'] = _FEATUREWORKER


_SYMBOL = _descriptor.ServiceDescriptor(
  name='Symbol',
  full_name='coinlib.Symbol',
  file=DESCRIPTOR,
  index=14,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=29363,
  serialized_end=29456,
  methods=[
  _descriptor.MethodDescriptor(
    name='registerSymbolBroker',
    full_name='coinlib.Symbol.registerSymbolBroker',
    index=0,
    containing_service=None,
    input_type=_SYMBOLBROKERREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SYMBOL)

DESCRIPTOR.services_by_name['Symbol'] = _SYMBOL


_DATALOADERWORKER = _descriptor.ServiceDescriptor(
  name='DataLoaderWorker',
  full_name='coinlib.DataLoaderWorker',
  file=DESCRIPTOR,
  index=15,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=29459,
  serialized_end=29908,
  methods=[
  _descriptor.MethodDescriptor(
    name='getAllSymbols',
    full_name='coinlib.DataLoaderWorker.getAllSymbols',
    index=0,
    containing_service=None,
    input_type=_SYMBOLDATAREQUESTINFO,
    output_type=_SYMBOLDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getAllExchanges',
    full_name='coinlib.DataLoaderWorker.getAllExchanges',
    index=1,
    containing_service=None,
    input_type=_EXCHANGEDATAREQUESTINFO,
    output_type=_EXCHANGEDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getMarketData',
    full_name='coinlib.DataLoaderWorker.getMarketData',
    index=2,
    containing_service=None,
    input_type=_MARKETDATAREQUEST,
    output_type=_MARKETDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getFeatureData',
    full_name='coinlib.DataLoaderWorker.getFeatureData',
    index=3,
    containing_service=None,
    input_type=_FEATUREDATAREQUEST,
    output_type=_FEATUREDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getAdditionalDataFeatures',
    full_name='coinlib.DataLoaderWorker.getAdditionalDataFeatures',
    index=4,
    containing_service=None,
    input_type=_ADDITIONALDATAFEATUREREQUEST,
    output_type=_ADDITIONALDATAFEATURERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATALOADERWORKER)

DESCRIPTOR.services_by_name['DataLoaderWorker'] = _DATALOADERWORKER


_NOTIFICATION = _descriptor.ServiceDescriptor(
  name='Notification',
  full_name='coinlib.Notification',
  file=DESCRIPTOR,
  index=16,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=29910,
  serialized_end=30009,
  methods=[
  _descriptor.MethodDescriptor(
    name='registerNotification',
    full_name='coinlib.Notification.registerNotification',
    index=0,
    containing_service=None,
    input_type=_NOTIFICATIONREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NOTIFICATION)

DESCRIPTOR.services_by_name['Notification'] = _NOTIFICATION


_FEATURES = _descriptor.ServiceDescriptor(
  name='Features',
  full_name='coinlib.Features',
  file=DESCRIPTOR,
  index=17,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=30011,
  serialized_end=30096,
  methods=[
  _descriptor.MethodDescriptor(
    name='registerFeature',
    full_name='coinlib.Features.registerFeature',
    index=0,
    containing_service=None,
    input_type=_FEATUREREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FEATURES)

DESCRIPTOR.services_by_name['Features'] = _FEATURES


_STATISTICS = _descriptor.ServiceDescriptor(
  name='Statistics',
  full_name='coinlib.Statistics',
  file=DESCRIPTOR,
  index=18,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=30099,
  serialized_end=30305,
  methods=[
  _descriptor.MethodDescriptor(
    name='registerStatisticRuleFunction',
    full_name='coinlib.Statistics.registerStatisticRuleFunction',
    index=0,
    containing_service=None,
    input_type=_STATISTICRULEFUNCTIONREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='registerStatisticMethod',
    full_name='coinlib.Statistics.registerStatisticMethod',
    index=1,
    containing_service=None,
    input_type=_STATISTICMETHODREGISTRATION,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STATISTICS)

DESCRIPTOR.services_by_name['Statistics'] = _STATISTICS


_DATAWORKERREGISTRY = _descriptor.ServiceDescriptor(
  name='DataWorkerRegistry',
  full_name='coinlib.DataWorkerRegistry',
  file=DESCRIPTOR,
  index=19,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=30308,
  serialized_end=30502,
  methods=[
  _descriptor.MethodDescriptor(
    name='getAllDataWorkerServer',
    full_name='coinlib.DataWorkerRegistry.getAllDataWorkerServer',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='getDataWorkerServerEndpoint',
    full_name='coinlib.DataWorkerRegistry.getDataWorkerServerEndpoint',
    index=1,
    containing_service=None,
    input_type=_WORKERREGISTRYREQUEST,
    output_type=_WORKERREGISTRYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAWORKERREGISTRY)

DESCRIPTOR.services_by_name['DataWorkerRegistry'] = _DATAWORKERREGISTRY

# @@protoc_insertion_point(module_scope)
